#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""SpaceChem test data. Dict of test levels and lists of solutions."""

# Custom levels used for certain tests
test_levels = {
    "TestWallCollisionsPositive": '''H4sIAJHvNl8A/42PwWrDMBBE/2XPNkg2mCIf/QM9FAopPajOOhYoWqNdFVLjf6/klNKkPfQysM
O8YXYFF5Yk9QcFZDArqCK7l8+XFc7kcUwewcBg4xuFfuhb3Sndt2rXZte2U6pvVKcVVDBSCgJG
N9vrVoH+T2PuuiczSkl+j/uL1/qWV4WeLdfexhPW1x4wk/WMFWTmiLH+Cj9ck4yBKX5nijUlxl
uHF+9E7kxBjwvFn7ZclrIvIqON45yXBXsuzhOyPFvvB/LesaPAj8RO3DvmjE0ylwlwcKd8Ht00
ufypXMCo7RN/jMGDqgEAAA==''',
    "TestMoleculeCollisions": '''H4sIAJvYOV8A/42PvQ7CMAyE38VzK6UMCIWxMxsTiCG0Lo0U4ip2hlL13UkoQvwsLJb8+c4+T2
D9EKW8kUcGPYHK5cFSe5zgSg6b6BA01CacyW/rbVWtlYICGopeQFer+TTPBVCU31X/+FV294ZL
Z8IFy2UP6M44xgKSp8VQPsWbRcnomcJLk1EXGT8JD86KfEFBhwOFdyzjkPMFZDSh6VMyb66Z7J
Fl93ygJucsW/Kc5iZKn8/DwV5S29qus0kkI2g13wHxuQPmVAEAAA==''',
    "TestWallCollisionsNegative": '''H4sIADc8OF8A/22QzWqFMBBG32XWCkkEF7p031Wh0NJF6h01MDeRzKRwK757Ey3l9mczMIcvZz
6ygfNrkvojeGToNlBlHCyvLxtcA+GYCKGDwca34Puhb3SrdN+oY5pjNq1SvVGtVlDBGJIX6LTZ
X/e9gpDk74n/vLq8L5ZsNIfXnN5y786rinWxXJONM9anH7rJEmMF2XXBWH+F1Zlk9Bzid6agKT
H+JLySE/kFBQnXEO+x3NbSOyKjjeOSm3l7LeQRWZ4s0RCIHLvg+QFnK+4dc8YmWUoFeHZzXi9u
mlz+Abnlkvsnw2Alo4gBAAA=''',
    "CE Research Test": '''H4sIAOfS6V8A/41SsW7DIBD9lehmkIzTyRmrSpmrTK0yUPvsIGFwuUOpG/nfC3GSOs3SBem9d3
fce3AC44bI8ts7JKhOUOTjzCX4foLeW6yjRahgOzbBd+g2241SqihAQO2jY6hUOe2nSYCP/Djs
fxOK3H/QJK0OHcp5ElSttoQCPrxrMMhLcXkjBhvpke2Nu6PzWEJHPkDFIeLMtJHwjqDBGuZ7jt
Hi4MOC/YzacezlUVtL8is7VCmpQihR7qe/+pj1ddJLsRYq6zwOOYqAhDrUh7Rm30dneJTYGDbe
yTLF4nSfq55fVq+XwtUOiZOiIx+yEXgzXYKNaVuT4uV0UyFgtnn1/iTg7HKRxdXkgvr1uOhrDC
UD/oiNNI6S9Trvlv8EnLEMnjVj2mCGNLr6Bth3XXrw/fQD3ajvml8CAAA=''',
    "CE Production Test": '''H4sIADh87F8A/+1Vy27bMBD8FYNnE5CUoEXlgw9BAR9yKIL20iIIaGklEeVD5aOOELjf3qUeti
QrLfo6NUfNcmeHMxT5RAxTuZaUq9o7mmlZawXKWZJ+eiJSC8i8gOkXScmuyY0uQW12mziOo4is
Saa9ciSNk+P9eiC1ADlJozWpjc595rhWNAfBGly3Jtq7MLPmdTuAEGx0TR34c8NKysyeO8NM04
nDGY8kfbMm2P0qDEHS0jApIV9Wbx0zjquSjrdBbrmruJebW47Sr1rpOxAB2QEiSYdc7u/3+oIX
UAO71LEw4pJvaei/67tfCir5eVDzIMZJxVGIqmeYBdSjGFMJeHSeOWHfoiQojqNNMj1q19Fxqs
NKJgQdbaFnbuUk8UhPzaylrjLalxVt6cB0mhbFfFCflT6ozXa7nY2fW3M38qYwAIU2chjQ6Yhf
j3ScDaEHjIx2dGNzlkw/E3vr8DczwDKnDY37CcnYeVeBmRs/Ns1A1mRiUJdEXW9oRTP1ATMd6E
NXK+VH87sgwp+HY/vCCcZbYa8f5/AXz5TzJ5qwUclOq2x7kpDNMK7ay2Q6tduRYjLs6KYtre66
0ioIYjX+fngfZaGuv4I5aCPyh777oZeKCytm6V47N1yGJC2YsDApDPn0lb1WeetueyCiE1ALby
9RydUEtqCsHncX3k7YbC24cxPIgYBamymYcztkxZV1pjv9wRi0cnD3gEssxYiVF2IONx18XD/n
ZPJnTqKmZSO7wv/j49WLj3/Fx+sXH3/Fx/PbMXod8VGQXnHXUMh5QNCqwe23q3enhav3YMMjyr
yr8HpOyUdehrubFwXHB9LhkOj4Hdp2SZRJCgAA''',
    "Fastest Puzzle": '''H4sIAChPL2AA/42Pu07EMBBFfwVNHUsJUGV7tCU1iGKwZ4Ol+KHxWNrsKv/O5IHYpaLzvO45vg
JjdCkYH3MVY1PIKVKUAv37FUIaydaR7ivo4Tg5TgPFw/HQdV3bQgM21SjQd4/zR/MTWogc9G0D
mZOrVnyKxtGIk+5pN1VZoNnnlQCglzLlBeAYB4P86YWRp81OIec1Tc+fF8p+/0d67wryQCr0X+
/5nl0CjqO58d7zVoenX4eAZ8OEVhKXVU6IGX3c3lvgTYq6hhq9TIacXzoaGDEsWy9YhIo8vNbL
RWUbwCpfiXXy5gctnT+dvP5DFN3O3xxQYjq5AQAA''',
    "Suddenly, Welding?": '''H4sIAKJi918A/+1WXW/aMBT9K5GfieQY2jLyMLXVqj2tVTuJh6mqTHKBSImd+WMUVey379pOgN
AW0bKPlz0QKze+vuccH1/zRBQXuaziQtTWxJmsailAGE1G355IJUvIbAndNzIiY25ApZ9/Unad
JskwSdKEJZSmLMEn6ZFMWmHIKGGr+15bQQPkZER7pFYyt5kppIhzKPkS5/WItMYBqIvaVyMEE8
2ydsVyxWcxV5PCKK6WASnWeCSjkx7B7JNVbw/UK8UzYxXk0U0BGaRXgIjZKXWQw9DH4T2g6TtR
M486OdsL+y6bA5SFgfSSj69/0gGiPhug0JQy6vSmQ8ROUXuKRIZe++E/oPHBVcFVZ4pXFeQv+e
h+XWDHXk3UcDUDRNzhf65mUqTnCml3eQ3pqgtOV7ws4y1izXoeZDLYEntfva9WzLQBEX3CkMHF
IB17yZ1DaBhYGPo4bAFibwLETg8ENIYy3zUt7jtrvEv9m/MuGoB5C6csGJrRtb2DX/wQ0mkT9H
lHcghbz7WOzVxJO5vHfjVQYXdfZRVdAM+RUhRHY/whtz0YW9s3hPuBWz+o0A+8+w1v5meyRhMa
3pJGKHyjjSY7vPe4f6oAplJVLbOuqfpOgI2n40Vh5nFYrbG9mYN6dhhQWbnAo6IAO5NUsavlC2
+qWW3w1LYTGJZ97Vvi0Fb8sQ1o3xURquKFICNE2k0IeyN45ZvMgtfxHQgN0W34jJV4XQPHvpG5
GfIHqIVUZf7Q5D98t1wYW+HEOdfxRBrT3h5kZJSFTrwVI3yYSJF7Pbz2g3WgLq1uo3QdrQrRCW
vEKdfZ2H2mVm9WcxNq7JemEzJQQi3VVhDz8kK3W1AIjdC8w5vNaejFC5yiY9xsYctyN7wMYXeE
GyW/2KxE1aI7W2OtC8/gcE01dumJfDxe0+FRmtIdTZPnmiYvaUr/jKaX3ritilH/AB2x54RTeq
SO9LfqeKg3/46Og/86vkXHzWWwdRtiS6+sKMwyhrxwEZSq7ak2z0GUy17k7rpCzD46va2ZYyMY
kVv/f+wGn9xdv3kxnRZ4NRqsRle/AD7f1uKNCwAA''',
    "as54": '''H4sIAIqTrFcA/22STW7bMBCFrxJw0ZUUzB8tyVwlbXqBLoMs1FpODESWIctA0iB375tRkE0DAS
Q1nPe94ZBvae6Pu2msD8fTZan/TsfhnLZv71XaH16G3f/h0zw9zv04fu6dl35e0vaeKq6k0sqq
jM+wEkTo4QvJPJyG3jWGDEW2VBTZq/pLzTg9D38uz1FGorRNXDdX364s+9CWmyLExEVjZMJciI
2pCGeMyo3HeYM1rZliLWFbDPupSgxmW7M5z8lZyy1kLVKFO8+kzG6QwwBs57Fgh5h15bJbiTUB
zhpg8WJzLezkjZOlfHeC46DZ+MTceK0rVsnCNWzVLdxKmAK+WeEScAVcpJbOuVx+ACjilZEoO0
MaXrviZYofHySLjkicjSQsRbqVy8E1cJVqjU5QuYNKXUXsLIj1o89uJqQaLuoIjh8ijXaJfjSD
yLnZuW1t0eYo2spPb20AxCzqNI061S8IHl2cBD1Bit+p000+z4Ur7FA0HufyehpgcMaT/j29wO
7Yjx64uf51DScE+svyNM0I3S14Xf0yILY77PcHvK3lNW3p/R+VB2OpEgMAAA==''',
    "Overbond test": '''H4sIAAWs9GAA/5XQwWrDMAwG4FcZOidg+5i8QG+7b+zgJkpicGxjyYU0pM9eu+3Cup56EejD/J
K8gnEhcX32DgmaFUQpN8vt9wqzt9gli9DAYemjH9G1h4tQrZRSiVZJKQRU0PnkGBqptp9tq8An
fk19M6rkTJpqq+OI9T0RmkFbwgqO3vUY68dbtUOwiX5V7Dob98QlltCRj3tgoSERPgsFa5j/Ia
PF4ONf5iWUsyIS6thN+Qqn5yKfJ4xliQ9G4sw68VSmwpcZc9ubYTD5T3jJe21XNIfUb40BAAA=''',
    "Head or Tails?": """H4sIAB1Qg2AA/3WRTU7DMBCFr1J53UhjG6IqWbCokFix6gYhFqadEEuOHflnUapyDk7FmfBPkg
IVmyfl6c2bb5wTkXoMvno3Gh1pTgSSZC9+Pp/IYBTug0LSkK2wr0a325bRGoCsyd4E7UlD2fnl
vCb0/8l7hQNqv9r16EX79RkbGMBVRywxwV/j/Gh6Qic9ttsP2LSUpRLaAq1pVJY0F1NoKa+jsq
y0LGs5q2Oa06QszaY8pCmalfOSA146AEqGQ95zgYX52h9gj2bhYpmHT3Qsc9HCONNlDzIdh8wz
7aITA+d1IoFy2cQ6cfHpHnrNFcF64Sol7BtW5S1J0wnlcE3ivzugrabsZjFGFdzswuIOUv+yU6
1D7YwljbcBi9MFh3bZkDOjkt7/MT0qHI3Ndhn2xzG9mkWHwu77eIMWQ3IeUBxWxq52Qip3F30R
fJ+WEsr4za1ExGgeZNfJ+PL+mOEu/TMxO38DQQr/TtoCAAA=""",
    "Continuous Flow Test": """H4sIAI+KBGIA/+1WTW/bMAz9K4HOEeC4RbAmxwFDz0FPG4pCsRlbmCW6+lhqFN1vHyXbi50EBb
IWCQYkh3yQ5uPjE0nllRmhc1Rc6to7nqGqUYN2li1+vDKFFWS+gvEvtmD3TW6wAL28/52kyxm9
kmVKbwmbsgy9dmwxS98epz26BcjZIpmy2mDuMydR8xwq0dBzU4beheS1rGMmtloxCnVNHVLlRh
RcmLV0Rpim5UlZXiiSQgkgeZtejOkpPO/+E56U5oNE50OAw5A0hqR7IedplpuQh3ALI5SC/Hjb
WyeMk7rgQxHeKTxQhxrEiTH/WN4++1F9UccOY6+qzkq1FUCKn3qo1BUjGlaJquKDGjrgls2XXc
ufNe/doIXPmni+20UXyDu/UN52nIS13JUGfVHyCAambbmPUDkYhMEcbAzABo3qs3WcbrumewxA
fe/zrXQlb9GGc3AUuC3cIX0A1at/jpDbBYyuBDMeLrKSVrilkTQgMornAbBzKfHSm23ca8TYCK
nj98xTOjXwE0MtVCDzNbomq9Y1mREXUdOaoTWZBT/+ArNFU+VPXfRTXFxRjlJYvkbn+pudLZzx
MLL3krSONeo8lhUPIPlrqCtvD61K6pHZgrY4jN54O0KzdSWdG5kcVFCjGRtzaXslpbZELbZeJ+
SzF9p5xbf0iOV0LtpX1b65ac1hII7rmF51/BQdb646foqOt1cdT9Fxt6wHVxNtY+W1dA2HXAYL
SdWrjZr+l3n0dvKNCEwewIY7THhXoiH/d1mwwG+zkXRBuXiJ/wEgoJnQFg0AAA==""",
}

valid_solutions = [
    r'''

SOLUTION:Of Pancakes and Spaceships,Zig,107-1-7,empty lines

COMPONENT:'custom-research-reactor',2,0,''

MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0

MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-output',-1,0,128,5,1,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0

PIPE:0,4,1

PIPE:1,4,2
''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,107-1-7,No pipes
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-output',-1,0,128,5,1,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0''',
    r"""SOLUTION:Of Pancakes and Spaceships,Zig,115-1-6,Symbols
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-output',-1,0,32,0,1,0,0""",
    r"""SOLUTION:Of Pancakes and Spaceships,Zig,115-1-7,Start vs arrow
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,1,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-output',-1,0,32,0,1,0,0""",
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,45-1-14,Cycles
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,2,5,0,0
MEMBER:'instr-start',-90,0,32,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',180,0,16,6,1,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-output',-1,0,32,3,1,0,0
MEMBER:'instr-input',-1,0,32,4,1,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-rotate',-1,0,32,5,1,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0
MEMBER:'instr-output',-1,0,128,5,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,69-1-18,rotate_out_of_way
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,6,2,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,0,0,0
MEMBER:'instr-input',-1,0,32,1,2,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-rotate',-1,0,128,3,0,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-rotate',-1,1,128,4,0,0,0
MEMBER:'instr-grab',-1,2,128,6,0,0,0
MEMBER:'instr-grab',-1,2,32,7,1,0,0
MEMBER:'instr-output',-1,0,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,6,0,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-arrow',-90,0,64,1,1,0,0
MEMBER:'instr-arrow',90,0,16,7,1,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-arrow',-90,0,16,1,2,0,0
MEMBER:'instr-output',-1,0,32,7,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,45-1-14,Ignorable pipe modifications
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,2,5,0,0
MEMBER:'instr-start',-90,0,32,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',180,0,16,6,1,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-output',-1,0,32,3,1,0,0
MEMBER:'instr-input',-1,0,32,4,1,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-rotate',-1,0,32,5,1,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0
MEMBER:'instr-output',-1,0,128,5,1,0,0
PIPE:0,4,1
PIPE:0,4,0
PIPE:1,4,2''',
    r'''SOLUTION:An Introduction to Bonding,Zig,154-1-10,Symbols
COMPONENT:'tutorial-research-reactor-2',2,0,''
MEMBER:'instr-start',180,0,128,3,5,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-input',-1,1,128,2,5,0,0
MEMBER:'instr-bond',-1,0,128,1,2,0,0
MEMBER:'instr-output',-1,0,32,0,6,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:An Introduction to Bonding,Zig,74-1-40,Cycles
COMPONENT:'tutorial-research-reactor-2',2,0,''
MEMBER:'instr-start',-90,0,128,1,7,0,0
MEMBER:'instr-start',0,0,32,0,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-grab',-1,1,32,1,4,0,0
MEMBER:'instr-arrow',90,0,16,1,4,0,0
MEMBER:'instr-arrow',-90,0,16,3,5,0,0
MEMBER:'instr-arrow',180,0,16,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,4,4,0,0
MEMBER:'instr-grab',-1,1,128,4,4,0,0
MEMBER:'instr-rotate',-1,0,128,5,3,0,0
MEMBER:'instr-grab',-1,2,32,3,4,0,0
MEMBER:'instr-rotate',-1,1,32,3,5,0,0
MEMBER:'instr-arrow',90,0,16,2,3,0,0
MEMBER:'instr-arrow',180,0,16,2,4,0,0
MEMBER:'instr-bond',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',0,0,64,4,3,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-input',-1,1,32,2,3,0,0
MEMBER:'instr-input',-1,0,32,1,0,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-bond',-1,0,128,1,2,0,0
MEMBER:'instr-input',-1,1,128,5,4,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-bond',-1,0,128,5,2,0,0
MEMBER:'instr-input',-1,1,128,1,6,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-bond',-1,0,32,1,2,0,0
MEMBER:'instr-bond',-1,0,32,1,3,0,0
MEMBER:'instr-input',-1,0,128,1,4,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-arrow',180,0,16,1,2,0,0
MEMBER:'instr-arrow',90,0,16,0,2,0,0
MEMBER:'instr-arrow',0,0,16,0,3,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-bond',-1,0,32,2,4,0,0
MEMBER:'instr-input',-1,0,128,4,3,0,0
MEMBER:'instr-input',-1,0,128,4,2,0,0
MEMBER:'instr-output',-1,0,32,2,5,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:An Introduction to Bonding,Zig,138-1-45,Input Island
COMPONENT:'tutorial-research-reactor-2',2,0,''
MEMBER:'instr-start',90,0,128,2,3,0,0
MEMBER:'instr-start',0,0,32,0,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'instr-input',-1,1,128,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-grab',-1,2,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',180,0,64,1,5,0,0
MEMBER:'instr-arrow',-90,0,64,0,5,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-bond',-1,0,128,1,2,0,0
MEMBER:'instr-grab',-1,2,128,1,3,0,0
MEMBER:'instr-bond',-1,1,128,1,4,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-input',-1,1,128,0,5,0,0
MEMBER:'instr-sync',-1,0,128,0,4,0,0
MEMBER:'instr-input',-1,0,128,0,3,0,0
MEMBER:'instr-bond',-1,1,128,0,2,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,3,5,0,0
MEMBER:'instr-input',-1,0,32,3,5,0,0
MEMBER:'instr-arrow',180,0,16,3,4,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-arrow',-90,0,16,0,4,0,0
MEMBER:'instr-arrow',0,0,16,0,3,0,0
MEMBER:'instr-arrow',-90,0,16,1,3,0,0
MEMBER:'instr-arrow',180,0,16,1,2,0,0
MEMBER:'instr-arrow',-90,0,16,0,2,0,0
MEMBER:'instr-arrow',0,0,16,0,0,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-arrow',90,0,16,3,1,0,0
MEMBER:'instr-arrow',180,0,16,3,2,0,0
MEMBER:'instr-arrow',-90,0,16,2,2,0,0
MEMBER:'instr-arrow',180,0,16,2,0,0,0
MEMBER:'instr-grab',-1,1,32,1,3,0,0
MEMBER:'instr-rotate',-1,0,32,0,1,0,0
MEMBER:'instr-grab',-1,1,32,1,0,0,0
MEMBER:'instr-grab',-1,2,32,2,0,0,0
MEMBER:'instr-sync',-1,0,32,1,1,0,0
MEMBER:'instr-bond',-1,0,32,2,1,0,0
MEMBER:'instr-output',-1,0,32,3,1,0,0
MEMBER:'instr-rotate',-1,1,32,2,2,0,0
MEMBER:'instr-rotate',-1,0,32,3,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Double Bonds,Zig,60-1-20,Cycles
COMPONENT:'drag-starter-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,6,0,0
MEMBER:'instr-start',0,0,32,0,1,0,0
MEMBER:'feature-bonder',-1,0,1,3,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-bond',-1,0,32,2,1,0,0
MEMBER:'instr-rotate',-1,0,32,3,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-arrow',180,0,16,6,1,0,0
MEMBER:'instr-output',-1,0,32,4,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,1,4,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-input',-1,0,128,4,1,0,0
MEMBER:'instr-rotate',-1,0,128,5,1,0,0
MEMBER:'instr-input',-1,0,128,1,5,0,0
MEMBER:'instr-bond',-1,0,32,5,1,0,0
MEMBER:'instr-bond',-1,0,128,1,3,0,0
MEMBER:'instr-bond',-1,0,128,3,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:An Introduction to Pipelines,Zig,867-0-0,Max cycles
COMPONENT:'drag-silo-input',8,12,''
PIPE:0,5,2
PIPE:0,5,3
PIPE:0,5,4
PIPE:0,5,5
PIPE:0,5,6
PIPE:0,4,6
PIPE:0,4,5
PIPE:0,3,5
PIPE:0,3,6
PIPE:0,2,6
PIPE:0,2,5
PIPE:0,1,5
PIPE:0,1,6
PIPE:0,0,6
PIPE:0,0,5
PIPE:0,-1,5
PIPE:0,-1,6
PIPE:0,-2,6
PIPE:0,-3,6
PIPE:0,-4,6
PIPE:0,-5,6
PIPE:0,-6,6
PIPE:0,-6,5
PIPE:0,-6,4
PIPE:0,-5,4
PIPE:0,-5,5
PIPE:0,-4,5
PIPE:0,-4,4
PIPE:0,-3,4
PIPE:0,-3,5
PIPE:0,-2,5
PIPE:0,-2,4
PIPE:0,-1,4
PIPE:0,-1,3
PIPE:0,-1,2
PIPE:0,-2,2
PIPE:0,-2,3
PIPE:0,-3,3
PIPE:0,-3,2
PIPE:0,-4,2
PIPE:0,-4,3
PIPE:0,-5,3
PIPE:0,-5,2
PIPE:0,-6,2
PIPE:0,-6,1
PIPE:0,-7,1
PIPE:0,-7,0
PIPE:0,-7,-1
PIPE:0,-7,-2
PIPE:0,-7,-3
PIPE:0,-7,-4
PIPE:0,-7,-5
PIPE:0,-7,-6
PIPE:0,-7,-7
PIPE:0,-8,-7
PIPE:0,-8,-6
PIPE:0,-8,-5
PIPE:0,-8,-4
PIPE:0,-8,-3
PIPE:0,-8,-2
PIPE:0,-8,-1
PIPE:0,-8,0
PIPE:0,-8,1
PIPE:0,-8,2
PIPE:0,-7,2
PIPE:0,-7,3
PIPE:0,-8,3
PIPE:0,-8,4
PIPE:0,-7,4
PIPE:0,-7,5
PIPE:0,-8,5
PIPE:0,-8,6
PIPE:0,-7,6
PIPE:0,-7,7
PIPE:0,-7,8
PIPE:0,-7,9
PIPE:0,-6,9
PIPE:0,-5,9
PIPE:0,-4,9
PIPE:0,-3,9
PIPE:0,-2,9
PIPE:0,-1,9
PIPE:0,0,9
PIPE:0,1,9
PIPE:0,2,9
PIPE:0,3,9
PIPE:0,4,9
PIPE:0,5,9
PIPE:0,5,8
PIPE:0,4,8
PIPE:0,3,8
PIPE:0,2,8
PIPE:0,1,8
PIPE:0,0,8
PIPE:0,-1,8
PIPE:0,-2,8
PIPE:0,-3,8
PIPE:0,-3,7
PIPE:0,-2,7
PIPE:0,-1,7
PIPE:0,0,7
PIPE:0,1,7
PIPE:0,2,7
PIPE:0,3,7
PIPE:0,4,7
PIPE:0,5,7
PIPE:0,6,7
PIPE:0,6,8
PIPE:0,6,9
PIPE:0,7,9
PIPE:0,7,8
PIPE:0,8,8
PIPE:0,8,9
PIPE:0,9,9
PIPE:0,10,9
PIPE:0,11,9
PIPE:0,12,9
PIPE:0,13,9
PIPE:0,13,8
PIPE:0,14,8
PIPE:0,14,9
PIPE:0,15,9
PIPE:0,15,8
PIPE:0,16,8
PIPE:0,16,9
PIPE:0,17,9
PIPE:0,17,8
PIPE:0,18,8
PIPE:0,18,9
PIPE:0,19,9
PIPE:0,19,8
PIPE:0,20,8
PIPE:0,20,9
PIPE:0,21,9
PIPE:0,21,8
PIPE:0,22,8
PIPE:0,22,9
PIPE:0,23,9
PIPE:0,23,8
PIPE:0,23,7
PIPE:0,22,7
PIPE:0,21,7
PIPE:0,21,6
PIPE:0,20,6
PIPE:0,20,7
PIPE:0,19,7
PIPE:0,19,6
PIPE:0,18,6
PIPE:0,18,7
PIPE:0,17,7
PIPE:0,17,6
PIPE:0,16,6
PIPE:0,16,7
PIPE:0,15,7
PIPE:0,14,7
PIPE:0,14,6
PIPE:0,15,6
PIPE:0,15,5
PIPE:0,14,5
PIPE:0,14,4
PIPE:0,15,4
PIPE:0,15,3
PIPE:0,16,3
PIPE:0,16,4
PIPE:0,16,5
PIPE:0,17,5
PIPE:0,18,5
PIPE:0,19,5
PIPE:0,20,5
PIPE:0,20,4
PIPE:0,19,4
PIPE:0,18,4
PIPE:0,17,4
PIPE:0,17,3
PIPE:0,18,3
PIPE:0,19,3
PIPE:0,20,3
PIPE:0,20,2
PIPE:0,19,2
PIPE:0,18,2
PIPE:0,17,2
PIPE:0,17,1
PIPE:0,18,1
PIPE:0,19,1
PIPE:0,20,1
PIPE:0,20,0
PIPE:0,21,0
PIPE:0,22,0
PIPE:0,23,0
PIPE:0,23,-1
PIPE:0,22,-1
PIPE:0,21,-1
PIPE:0,20,-1
PIPE:0,19,-1
PIPE:0,19,0
PIPE:0,18,0
PIPE:0,17,0
PIPE:0,17,-1
PIPE:0,18,-1
PIPE:0,18,-2
PIPE:0,17,-2
PIPE:0,17,-3
PIPE:0,18,-3
PIPE:0,19,-3
PIPE:0,19,-2
PIPE:0,20,-2
PIPE:0,21,-2
PIPE:0,22,-2
PIPE:0,23,-2
PIPE:0,23,-3
PIPE:0,22,-3
PIPE:0,21,-3
PIPE:0,20,-3
PIPE:0,20,-4
PIPE:0,19,-4
PIPE:0,18,-4
PIPE:0,17,-4
PIPE:0,17,-5
PIPE:0,18,-5
PIPE:0,19,-5
PIPE:0,20,-5
PIPE:0,21,-5
PIPE:0,21,-4
PIPE:0,22,-4
PIPE:0,23,-4
PIPE:0,23,-5
PIPE:0,22,-5
PIPE:0,22,-6
PIPE:0,23,-6
PIPE:0,23,-7
PIPE:0,22,-7
PIPE:0,21,-7
PIPE:0,21,-6
PIPE:0,20,-6
PIPE:0,19,-6
PIPE:0,18,-6
PIPE:0,17,-6
PIPE:0,17,-7
PIPE:0,18,-7
PIPE:0,19,-7
PIPE:0,20,-7
PIPE:0,20,-8
PIPE:0,19,-8
PIPE:0,19,-9
PIPE:0,18,-9
PIPE:0,18,-8
PIPE:0,17,-8
PIPE:0,16,-8
PIPE:0,16,-7
PIPE:0,15,-7
PIPE:0,15,-8
PIPE:0,14,-8
PIPE:0,13,-8
PIPE:0,12,-8
PIPE:0,11,-8
PIPE:0,10,-8
PIPE:0,9,-8
PIPE:0,8,-8
PIPE:0,7,-8
PIPE:0,6,-8
PIPE:0,6,-9
PIPE:0,7,-9
PIPE:0,8,-9
PIPE:0,9,-9
PIPE:0,10,-9
PIPE:0,11,-9
PIPE:0,12,-9
PIPE:0,13,-9
PIPE:0,14,-9
PIPE:0,15,-9
PIPE:0,16,-9
PIPE:0,17,-9
PIPE:0,17,-10
PIPE:0,16,-10
PIPE:0,15,-10
PIPE:0,14,-10
PIPE:0,13,-10
PIPE:0,12,-10
PIPE:0,11,-10
PIPE:0,10,-10
PIPE:0,9,-10
PIPE:0,8,-10
PIPE:0,7,-10
PIPE:0,6,-10
PIPE:0,6,-11
PIPE:0,7,-11
PIPE:0,8,-11
PIPE:0,9,-11
PIPE:0,10,-11
PIPE:0,11,-11
PIPE:0,12,-11
PIPE:0,13,-11
PIPE:0,14,-11
PIPE:0,15,-11
PIPE:0,16,-11
PIPE:0,17,-11
PIPE:0,17,-12
PIPE:0,16,-12
PIPE:0,15,-12
PIPE:0,14,-12
PIPE:0,13,-12
PIPE:0,12,-12
PIPE:0,11,-12
PIPE:0,10,-12
PIPE:0,9,-12
PIPE:0,8,-12
PIPE:0,7,-12
PIPE:0,6,-12
PIPE:0,5,-12
PIPE:0,5,-11
PIPE:0,5,-10
PIPE:0,5,-9
PIPE:0,4,-9
PIPE:0,4,-10
PIPE:0,4,-11
PIPE:0,4,-12
PIPE:0,3,-12
PIPE:0,3,-11
PIPE:0,3,-10
PIPE:0,3,-9
PIPE:0,2,-9
PIPE:0,2,-10
PIPE:0,1,-10
PIPE:0,1,-9
PIPE:0,0,-9
PIPE:0,0,-8
PIPE:0,0,-7
PIPE:0,-1,-7
PIPE:0,-2,-7
PIPE:0,-3,-7
PIPE:0,-4,-7
PIPE:0,-5,-7
PIPE:0,-6,-7
PIPE:0,-6,-6
PIPE:0,-6,-5
PIPE:0,-6,-4
PIPE:0,-5,-4
PIPE:0,-5,-5
PIPE:0,-5,-6
PIPE:0,-4,-6
PIPE:0,-4,-5
PIPE:0,-3,-5
PIPE:0,-3,-6
PIPE:0,-2,-6
PIPE:0,-1,-6
PIPE:0,0,-6
PIPE:0,0,-5
PIPE:0,-1,-5
PIPE:0,-2,-5
PIPE:0,-2,-4
PIPE:0,-1,-4
PIPE:0,0,-4
PIPE:0,0,-3
PIPE:0,1,-3
PIPE:0,2,-3
PIPE:0,3,-3
PIPE:0,4,-3
PIPE:0,5,-3
PIPE:0,5,-2
PIPE:0,4,-2
PIPE:0,3,-2
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,0,-2
PIPE:0,0,-1
PIPE:0,1,-1
PIPE:0,2,-1
PIPE:0,3,-1
PIPE:0,4,-1
PIPE:0,5,-1
PIPE:0,5,0
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,6,0
PIPE:0,6,-1
PIPE:0,6,-2
PIPE:0,6,-3
PIPE:0,6,-4
PIPE:0,6,-5
PIPE:0,6,-6
PIPE:0,6,-7
PIPE:0,7,-7
PIPE:0,7,-6
PIPE:0,7,-5
PIPE:0,7,-4
PIPE:0,7,-3
PIPE:0,7,-2
PIPE:0,7,-1
PIPE:0,7,0
PIPE:0,7,1
PIPE:0,7,2
PIPE:0,6,2
PIPE:0,6,3
PIPE:0,6,4
PIPE:0,7,4
PIPE:0,7,3
PIPE:0,8,3
PIPE:0,8,4
PIPE:0,9,4
PIPE:0,9,3
PIPE:0,9,2
PIPE:0,8,2
PIPE:0,8,1
PIPE:0,8,0
PIPE:0,8,-1
PIPE:0,8,-2
PIPE:0,8,-3
PIPE:0,8,-4
PIPE:0,8,-5
PIPE:0,8,-6
PIPE:0,8,-7
PIPE:0,9,-7
PIPE:0,10,-7
PIPE:0,11,-7
PIPE:0,11,-6
PIPE:0,11,-5
PIPE:0,10,-5
PIPE:0,9,-5
PIPE:0,9,-4
PIPE:0,10,-4
PIPE:0,11,-4
PIPE:0,11,-3
PIPE:0,10,-3
PIPE:0,9,-3
PIPE:0,9,-2
PIPE:0,10,-2
PIPE:0,11,-2
PIPE:0,11,-1
PIPE:0,10,-1
PIPE:0,9,-1
PIPE:0,9,0
PIPE:0,10,0
PIPE:0,11,0
PIPE:0,11,1
PIPE:0,11,2
PIPE:0,10,2
PIPE:0,10,3
PIPE:0,11,3
PIPE:0,12,3
PIPE:0,12,2
PIPE:0,12,1
PIPE:0,12,0
PIPE:0,13,0
PIPE:0,13,1
PIPE:0,13,2
PIPE:0,13,3
PIPE:0,14,3
PIPE:0,14,2
PIPE:0,14,1
PIPE:0,14,0
PIPE:0,14,-1
PIPE:0,15,-1
PIPE:0,16,-1
PIPE:0,16,-2
PIPE:0,16,-3
PIPE:0,15,-3
PIPE:0,15,-2
PIPE:0,14,-2
PIPE:0,13,-2
PIPE:0,13,-1
PIPE:0,12,-1
PIPE:0,12,-2
PIPE:0,12,-3
PIPE:0,12,-4
PIPE:0,12,-5
PIPE:0,12,-6
PIPE:0,12,-7
PIPE:0,13,-7
PIPE:0,14,-7
PIPE:0,14,-6
PIPE:0,13,-6
PIPE:0,13,-5
PIPE:0,13,-4
PIPE:0,13,-3
PIPE:0,14,-3
PIPE:0,14,-4
PIPE:0,14,-5
COMPONENT:'drag-silo-input',9,4,''
PIPE:0,5,2
PIPE:0,6,2
PIPE:0,7,2
PIPE:0,8,2
PIPE:0,9,2
PIPE:0,9,3
PIPE:0,9,4
PIPE:0,9,5
PIPE:0,9,6
PIPE:0,9,7
PIPE:0,9,8
PIPE:0,9,9
PIPE:0,10,9
PIPE:0,11,9
PIPE:0,12,9
PIPE:0,13,9
''',
    r'''SOLUTION:There's Something in the Fishcake,Zig,647-1-10,Symbols
COMPONENT:'drag-starter-reactor',13,6,''
MEMBER:'instr-start',180,0,128,3,5,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-input',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-output',-1,0,32,0,6,0,0
MEMBER:'instr-bond',-1,0,128,1,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:1,4,1
PIPE:1,4,0
COMPONENT:'drag-silo-input',7,16,''
PIPE:0,5,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,5,-2
PIPE:0,5,-3
PIPE:0,5,-4
PIPE:0,5,-5
PIPE:0,5,-6
PIPE:0,5,-7
PIPE:0,5,-8
PIPE:0,5,-9
COMPONENT:'drag-silo-input',6,8,''
PIPE:0,5,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,6,0''',
    r'''SOLUTION:Split Before Bonding,Zig,73-1-24,Cycles
COMPONENT:'drag-starter-reactor',2,0,''
MEMBER:'instr-start',90,0,128,6,4,0,0
MEMBER:'instr-start',180,0,32,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'instr-input',-1,1,128,4,5,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-bond',-1,0,32,2,2,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
MEMBER:'instr-bond',-1,1,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-grab',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-arrow',90,0,16,6,2,0,0
MEMBER:'instr-arrow',180,0,16,6,5,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-grab',-1,2,32,6,2,0,0
MEMBER:'instr-input',-1,1,128,6,5,0,0
MEMBER:'instr-bond',-1,1,128,3,5,0,0
MEMBER:'instr-input',-1,0,32,2,3,0,0
MEMBER:'instr-output',-1,0,32,5,5,0,0
MEMBER:'instr-bond',-1,0,32,5,2,0,0
MEMBER:'instr-rotate',-1,0,32,4,2,0,0
MEMBER:'instr-rotate',-1,0,128,4,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Settling into the Routine,Zig,1628-3-33,Symbols + wrong assembly output
COMPONENT:'drag-disassembly-reactor',12,2,''
MEMBER:'instr-start',-90,0,128,2,3,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'feature-bonder-minus',-1,0,1,8,1,0,0
MEMBER:'feature-bonder-minus',-1,0,1,9,1,0,0
MEMBER:'feature-bonder-minus',-1,0,1,8,7,0,0
MEMBER:'feature-bonder-minus',-1,0,1,9,6,0,0
MEMBER:'instr-bond',-1,1,128,9,1,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-grab',-1,2,128,9,4,0,0
MEMBER:'instr-arrow',90,0,64,9,1,0,0
MEMBER:'instr-arrow',180,0,64,9,4,0,0
MEMBER:'instr-arrow',-90,0,64,2,4,0,0
MEMBER:'instr-output',-1,1,128,8,4,0,0
MEMBER:'instr-output',-1,0,32,0,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,5,3
PIPE:1,5,4
PIPE:1,5,5
PIPE:1,5,6
PIPE:1,5,7
PIPE:1,5,8
PIPE:1,5,9
PIPE:1,5,10
PIPE:1,5,11
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,4,4
PIPE:0,4,5
PIPE:0,4,6
PIPE:0,4,7
PIPE:0,4,8
PIPE:0,4,9
PIPE:0,4,10
PIPE:0,4,11
PIPE:0,4,12
PIPE:0,4,13
PIPE:0,4,14
PIPE:0,4,15
PIPE:0,4,16
PIPE:0,4,17
PIPE:0,5,17
ANNOTATION:0,1,220,-63,'2,2:0,1;2,1:0,6;2,0:0,1;1,1:0,1;\n2,1,0:1;1,1,1:1;2,0,0:1;\r\n\r\n\r'
ANNOTATION:1,1,218,67,'3,0:0,1;\n\r\n\r\n\r'
COMPONENT:'drag-assembly-reactor',18,12,''
MEMBER:'instr-start',180,0,128,9,0,0,0
MEMBER:'instr-start',0,0,32,0,0,0,0
MEMBER:'feature-bonder-plus',-1,0,1,3,0,0,0
MEMBER:'feature-bonder-plus',-1,0,1,4,0,0,0
MEMBER:'feature-bonder-plus',-1,0,1,8,7,0,0
MEMBER:'feature-bonder-plus',-1,0,1,9,7,0,0
MEMBER:'instr-input',-1,0,128,4,0,0,0
MEMBER:'instr-grab',-1,1,128,3,0,0,0
MEMBER:'instr-arrow',0,0,64,3,0,0,0
MEMBER:'instr-arrow',180,0,64,7,0,0,0
MEMBER:'instr-grab',-1,2,128,7,0,0,0
MEMBER:'instr-bond',-1,0,32,8,7,0,0
MEMBER:'instr-output',-1,0,128,6,0,0,0
MEMBER:'instr-grab',-1,1,32,3,0,0,0
MEMBER:'instr-input',-1,0,32,1,0,0,0
MEMBER:'instr-sync',-1,0,32,2,0,0,0
MEMBER:'instr-sync',-1,0,128,8,0,0,0
MEMBER:'instr-arrow',90,0,16,8,0,0,0
MEMBER:'instr-grab',-1,2,32,8,4,0,0
MEMBER:'instr-output',-1,1,32,8,5,0,0
PIPE:0,4,1
COMPONENT:'drag-assembly-reactor',18,18,''
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'instr-start',-90,0,128,9,2,0,0
MEMBER:'feature-bonder-plus',-1,0,1,2,1,0,0
MEMBER:'feature-bonder-plus',-1,0,1,3,1,0,0
MEMBER:'feature-bonder-plus',-1,0,1,8,7,0,0
MEMBER:'feature-bonder-plus',-1,0,1,9,7,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',180,0,64,9,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,9,1,0,0
MEMBER:'instr-rotate',-1,0,128,2,1,0,0
MEMBER:'instr-output',-1,0,128,8,1,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
MEMBER:'instr-rotate',-1,0,128,3,1,0,0
MEMBER:'instr-input',-1,0,128,4,1,0,0
PIPE:0,4,1
COMPONENT:'drag-oceanic-input',8,3,''
PIPE:0,2,0
PIPE:0,3,0''',
    r"""SOLUTION:Challenge: In-Place Swap,12345ieee,437-3-67
COMPONENT:'drag-oceanic-input',1,16,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,3,-3
PIPE:0,4,-3
PIPE:0,5,-3
PIPE:0,6,-3
COMPONENT:'drag-atmospheric-input',5,4,''
PIPE:0,2,0
PIPE:0,2,1
PIPE:0,2,2
PIPE:0,2,3
PIPE:0,2,4
PIPE:0,2,5
PIPE:0,2,6
PIPE:0,2,7
PIPE:0,2,8
COMPONENT:'drag-starter-reactor',8,11,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-input',-1,1,128,3,1,0,0
MEMBER:'instr-bond',-1,1,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-grab',-1,0,128,7,4,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-rotate',-1,0,128,1,3,0,0
MEMBER:'instr-bond',-1,0,32,7,1,0,0
MEMBER:'instr-output',-1,1,128,7,3,0,0
MEMBER:'instr-bond',-1,0,32,7,2,0,0
MEMBER:'instr-input',-1,0,32,2,1,0,0
MEMBER:'instr-grab',-1,0,32,1,1,0,0
MEMBER:'instr-input',-1,1,32,3,1,0,0
MEMBER:'instr-bond',-1,1,32,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-grab',-1,0,32,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,1,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-rotate',-1,0,32,1,3,0,0
MEMBER:'instr-output',-1,1,32,7,3,0,0
MEMBER:'instr-bond',-1,0,128,7,2,0,0
MEMBER:'instr-bond',-1,0,128,7,1,0,0
MEMBER:'instr-bond',-1,1,32,1,4,0,0
MEMBER:'instr-bond',-1,1,128,1,4,0,0
PIPE:0,4,1
PIPE:1,4,2
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,-84,135,'1,2:0,6;0,2:0,1;1,3:0,1;2,2:0,1;1,1:0,7;1,0:0,7;0,0:0,1;\n0,2,1:1;1,2,0:1;1,2,1:1;1,1,0:1;1,0,0:2;0,0,1:1;\r\n\r\n\r'
COMPONENT:'drag-starter-reactor',13,11,''
MEMBER:'instr-start',180,0,128,2,5,0,0
MEMBER:'instr-start',180,0,32,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,8,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'instr-input',-1,1,128,1,5,0,0
MEMBER:'instr-grab',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-rotate',-1,1,128,2,4,0,0
MEMBER:'instr-bond',-1,0,32,7,4,0,0
MEMBER:'instr-grab',-1,0,32,7,5,0,0
MEMBER:'instr-arrow',180,0,16,7,5,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
MEMBER:'instr-rotate',-1,0,32,5,4,0,0
MEMBER:'instr-arrow',90,0,16,7,4,0,0
MEMBER:'instr-sync',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',90,0,64,4,4,0,0
MEMBER:'instr-arrow',180,0,64,4,5,0,0
MEMBER:'instr-grab',-1,0,128,4,4,0,0
MEMBER:'instr-bond',-1,1,128,4,5,0,0
MEMBER:'instr-arrow',-90,0,16,4,5,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-grab',-1,0,32,4,4,0,0
MEMBER:'instr-sync',-1,0,32,4,5,0,0
PIPE:0,4,1
PIPE:1,4,2
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,-44,121,'1,1:0,7;1,0:0,1;0,1:0,1;2,1:0,1;1,3:0,6;1,2:0,7;0,3:0,1;\n1,0,0:1;0,1,1:1;1,1,1:1;1,1,0:2;1,2,0:1;0,3,1:1;\r\n\r\n\r'
COMPONENT:'drag-starter-reactor',18,12,''
MEMBER:'instr-start',-90,0,128,1,4,0,0
MEMBER:'instr-start',180,0,32,9,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-grab',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-grab',-1,0,32,5,2,0,0
MEMBER:'instr-arrow',0,0,16,5,2,0,0
MEMBER:'instr-arrow',-90,0,16,5,5,0,0
MEMBER:'instr-output',-1,1,32,7,5,0,0
MEMBER:'instr-arrow',180,0,16,7,5,0,0
MEMBER:'instr-bond',-1,1,32,7,2,0,0
MEMBER:'instr-grab',-1,0,32,7,4,0,0
MEMBER:'instr-bond',-1,0,128,2,2,0,0
MEMBER:'instr-bond',-1,0,32,5,5,0,0
MEMBER:'instr-output',-1,0,32,7,3,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-arrow',90,0,64,5,2,0,0
MEMBER:'instr-arrow',180,0,64,5,3,0,0
MEMBER:'instr-arrow',-90,0,64,1,3,0,0
MEMBER:'instr-grab',-1,0,128,5,2,0,0
MEMBER:'instr-bond',-1,1,128,4,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7""",
    r'''SOLUTION:An Introduction to Sensing,Zig,136-1-32,Cycles
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,0,3,0,0
MEMBER:'instr-start',0,0,32,0,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-sensor',-1,0,1,2,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-output',-1,0,32,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-sensor',90,0,128,2,1,0,18
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-output',-1,1,128,5,4,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-arrow',180,0,16,6,2,0,0
MEMBER:'instr-arrow',-90,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-sensor',90,0,32,2,1,0,18
MEMBER:'instr-arrow',0,0,16,2,3,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,4,0,0
MEMBER:'instr-arrow',-90,0,16,1,4,0,0
MEMBER:'instr-output',-1,1,32,5,4,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,2,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-input',-1,0,32,1,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:An Introduction to Sensing,Zig,295-1-11,Symbols
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,0,2,0,0
MEMBER:'instr-start',180,0,32,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-sensor',-1,0,1,5,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-arrow',0,0,64,5,4,0,0
MEMBER:'instr-sensor',90,0,128,5,1,0,18
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-output',-1,1,128,6,3,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
MEMBER:'instr-output',-1,0,32,0,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Prelude to a Migraine,Zig,153-1-7,Symbols
COMPONENT:'drag-advanced-reactor',2,0,''
MEMBER:'instr-start',180,0,32,2,1,0,0
MEMBER:'instr-start',180,0,128,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-sensor',-1,0,1,8,7,0,0
MEMBER:'instr-input',-1,0,32,0,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-bond',-1,1,128,0,2,0,0
MEMBER:'instr-arrow',0,0,16,0,1,0,0
MEMBER:'instr-arrow',180,0,16,6,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-output',-1,0,32,5,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:No Ordinary Headache,Zig,3609-1-18,Symbols (1R)
COMPONENT:'drag-advanced-reactor',14,16,''
MEMBER:'instr-start',-90,0,32,7,1,0,0
MEMBER:'instr-start',90,0,128,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-sensor',-1,0,1,4,5,0,0
MEMBER:'instr-output',-1,0,32,7,2,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-sensor',-90,0,32,7,7,0,7
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-output',-1,1,128,8,4,0,0
MEMBER:'instr-arrow',-90,0,64,8,5,0,0
MEMBER:'instr-sensor',90,0,32,7,0,0,8
MEMBER:'instr-grab',-1,2,128,8,3,0,0
MEMBER:'instr-grab',-1,0,32,7,5,0,0
MEMBER:'instr-bond',-1,0,128,5,5,0,0
MEMBER:'instr-grab',-1,1,128,8,5,0,0
MEMBER:'instr-arrow',180,0,64,8,3,0,0
MEMBER:'instr-arrow',90,0,64,1,3,0,0
MEMBER:'instr-bond',-1,1,32,7,4,0,0
MEMBER:'instr-bond',-1,1,32,7,3,0,0
MEMBER:'instr-bond',-1,1,128,7,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,9,2
PIPE:1,10,2
PIPE:1,10,1
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,8,0
PIPE:0,8,-1
PIPE:0,8,-2
PIPE:0,8,-3
PIPE:0,8,-4
PIPE:0,8,-5
PIPE:0,8,-6
PIPE:0,8,-7
PIPE:0,8,-8
PIPE:0,8,-9
PIPE:0,8,-10
PIPE:0,8,-11
PIPE:0,8,-12
PIPE:0,8,-13
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-atmospheric-input',8,18,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0''',
    r'''SOLUTION:No Thanks Necessary,Zig,2726-4-51,Symbols
COMPONENT:'drag-oceanic-input',7,18,''
PIPE:0,2,0
COMPONENT:'drag-atmospheric-input',4,5,''
PIPE:0,2,0
COMPONENT:'drag-advanced-reactor',16,16,''
MEMBER:'instr-start',180,0,128,2,4,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,0,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-sensor',-1,0,1,6,2,0,0
MEMBER:'instr-output',-1,1,128,5,4,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-grab',-1,1,128,0,4,0,0
MEMBER:'instr-arrow',-90,0,64,0,4,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-sensor',-90,0,128,6,3,0,11
MEMBER:'instr-grab',-1,0,128,6,2,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-output',-1,0,128,4,4,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,5,-2
PIPE:0,5,-3
PIPE:0,5,-4
PIPE:0,5,-5
PIPE:0,5,-6
PIPE:0,5,-7
PIPE:0,5,-8
COMPONENT:'drag-advanced-reactor',13,3,''
MEMBER:'instr-start',180,0,128,1,0,0,0
MEMBER:'instr-start',180,0,32,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-sensor',-1,0,1,6,4,0,0
MEMBER:'instr-grab',-1,1,32,2,3,0,0
MEMBER:'instr-grab',-1,1,32,3,3,0,0
MEMBER:'instr-input',-1,0,32,4,3,0,0
MEMBER:'instr-bond',-1,0,128,0,0,0,0
MEMBER:'instr-input',-1,1,32,1,4,0,0
MEMBER:'instr-arrow',180,0,16,7,3,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-sensor',-90,0,32,7,4,0,8
MEMBER:'instr-rotate',-1,1,32,6,4,0,0
MEMBER:'instr-bond',-1,1,32,3,5,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-arrow',90,0,16,1,3,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,7,5,0,0
MEMBER:'instr-arrow',90,0,16,1,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,4,4
PIPE:0,4,5
PIPE:0,4,6
PIPE:0,4,7
PIPE:0,3,7
PIPE:0,2,7
PIPE:0,2,8
PIPE:0,2,9
PIPE:0,2,10
PIPE:0,2,11
PIPE:0,2,12
PIPE:0,2,13
PIPE:0,2,14
ANNOTATION:0,1,-44,192,'0,3:0,8;1,2:0,8;2,3:0,8;1,3:0,7;\n1,2,0:1;1,3,1:1;0,3,1:2;\r\n\r\n\r'
ANNOTATION:1,1,-313,98,'\n\r\n\r\n\r'
COMPONENT:'drag-advanced-reactor',7,3,''
MEMBER:'instr-start',180,0,128,1,6,0,0
MEMBER:'instr-start',90,0,32,0,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,5,0,0
MEMBER:'feature-bonder',-1,0,1,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,5,0,0
MEMBER:'feature-sensor',-1,0,1,5,5,0,0
MEMBER:'instr-input',-1,1,32,0,5,0,0
MEMBER:'instr-bond',-1,1,128,0,6,0,0
MEMBER:'instr-arrow',0,0,16,0,5,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,8,5,0,0
MEMBER:'instr-sensor',-90,0,32,5,5,0,7
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-arrow',180,0,16,8,5,0,0
MEMBER:'instr-grab',-1,2,32,8,3,0,0
MEMBER:'instr-output',-1,0,32,7,5,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
MEMBER:'instr-arrow',90,0,16,8,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,5,1
PIPE:1,5,7
PIPE:1,5,6
PIPE:1,5,5
PIPE:1,5,4
PIPE:1,5,3
PIPE:1,5,2
ANNOTATION:0,0,0,0,'\n\r2,3:0,7;\n\r3,3:0,7;\n\r'
ANNOTATION:1,0,0,0,'\n\r2,1:0,8;\n\r3,1:0,8;\n\r'
COMPONENT:'drag-advanced-reactor',10,16,''
MEMBER:'instr-start',180,0,128,1,1,0,0
MEMBER:'instr-start',90,0,32,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-sensor',-1,0,1,0,0,0,0
MEMBER:'instr-grab',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',90,0,16,2,2,0,0
MEMBER:'instr-output',-1,0,32,6,2,0,0
MEMBER:'instr-arrow',-90,0,16,7,5,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
MEMBER:'instr-input',-1,1,32,2,4,0,0
MEMBER:'instr-arrow',0,0,16,2,5,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-bond',-1,1,128,0,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,4,-4
PIPE:0,5,-4
PIPE:0,6,-4
PIPE:0,7,-4
PIPE:0,8,-4
PIPE:0,9,-4
PIPE:0,10,-4
PIPE:0,11,-4
PIPE:0,12,-4
PIPE:0,13,-4
PIPE:0,14,-4
PIPE:0,15,-4
PIPE:0,15,-5
PIPE:0,15,-6
PIPE:0,15,-7
PIPE:0,15,-8
PIPE:0,15,-9
PIPE:0,15,-10
PIPE:0,15,-11
PIPE:0,15,-12
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,-11,23,'0,0:0,1;\n\r0,0:0,11;\n\r\n\r'
''',
    r'''SOLUTION:Challenge: Going Green,Zig,3578-1-103,1R Cycles (precog)
COMPONENT:'drag-powerplant-input',-7,4,''
PIPE:0,14,7
PIPE:0,14,6
PIPE:0,14,5
PIPE:0,14,4
COMPONENT:'drag-advanced-reactor',8,7,''
MEMBER:'instr-start',-90,0,128,2,5,0,0
MEMBER:'instr-start',0,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-sensor',-1,0,1,2,1,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,2,4,0,0
MEMBER:'instr-sensor',180,0,128,2,3,0,6
MEMBER:'instr-arrow',90,0,64,1,3,0,0
MEMBER:'instr-arrow',0,0,64,1,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-grab',-1,0,128,1,3,0,0
MEMBER:'instr-grab',-1,0,128,1,4,0,0
MEMBER:'instr-grab',-1,0,128,1,5,0,0
MEMBER:'instr-grab',-1,0,128,1,6,0,0
MEMBER:'instr-grab',-1,0,128,1,7,0,0
MEMBER:'instr-grab',-1,2,128,4,7,0,0
MEMBER:'instr-sensor',0,0,128,2,7,0,6
MEMBER:'instr-arrow',-90,0,64,4,7,0,0
MEMBER:'instr-arrow',180,0,64,4,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,2,0,0
MEMBER:'instr-grab',-1,1,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,3,2,0,0
MEMBER:'instr-sensor',0,0,128,3,2,0,1
MEMBER:'instr-arrow',180,0,64,3,4,0,0
MEMBER:'instr-bond',-1,0,128,3,3,0,0
MEMBER:'instr-bond',-1,0,128,4,2,0,0
MEMBER:'instr-sync',-1,0,128,5,2,0,0
MEMBER:'instr-rotate',-1,1,128,6,2,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-arrow',0,0,64,6,3,0,0
MEMBER:'instr-arrow',90,0,64,7,3,0,0
MEMBER:'instr-arrow',0,0,64,7,4,0,0
MEMBER:'instr-sensor',90,0,128,9,4,0,8
MEMBER:'instr-arrow',180,0,64,9,7,0,0
MEMBER:'instr-arrow',-90,0,64,5,7,0,0
MEMBER:'instr-arrow',0,0,64,5,4,0,0
MEMBER:'instr-arrow',90,0,64,6,4,0,0
MEMBER:'instr-arrow',0,0,64,6,5,0,0
MEMBER:'instr-arrow',90,0,64,7,5,0,0
MEMBER:'instr-arrow',0,0,64,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,6,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-bond',-1,1,128,0,0,0,0
MEMBER:'instr-bond',-1,1,128,0,1,0,0
MEMBER:'instr-sensor',180,0,128,3,0,0,8
MEMBER:'instr-arrow',-90,0,64,3,0,0,0
MEMBER:'instr-bond',-1,1,128,9,7,0,0
MEMBER:'instr-bond',-1,1,128,8,7,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-bond',-1,0,128,7,4,0,0
MEMBER:'instr-grab',-1,2,128,8,4,0,0
MEMBER:'instr-rotate',-1,1,128,8,5,0,0
MEMBER:'instr-rotate',-1,1,128,7,5,0,0
MEMBER:'instr-grab',-1,1,128,6,5,0,0
MEMBER:'instr-sync',-1,0,128,7,6,0,0
MEMBER:'instr-bond',-1,0,128,5,5,0,0
MEMBER:'instr-input',-1,0,32,3,0,0,0
MEMBER:'instr-sync',-1,0,32,2,0,0,0
MEMBER:'instr-arrow',90,0,16,3,0,0,0
MEMBER:'instr-arrow',0,0,16,3,1,0,0
MEMBER:'instr-grab',-1,0,32,3,1,0,0
MEMBER:'instr-sensor',0,0,32,4,1,0,8
MEMBER:'instr-arrow',90,0,16,4,1,0,0
MEMBER:'instr-rotate',-1,1,32,5,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-arrow',180,0,16,6,2,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,4,0,0
MEMBER:'instr-arrow',90,0,16,5,4,0,0
MEMBER:'instr-arrow',0,0,16,5,5,0,0
MEMBER:'instr-arrow',90,0,16,6,5,0,0
MEMBER:'instr-arrow',180,0,16,6,7,0,0
MEMBER:'instr-arrow',180,0,16,4,6,0,0
MEMBER:'instr-arrow',180,0,16,4,2,0,0
MEMBER:'instr-sensor',90,0,32,4,2,0,6
MEMBER:'instr-arrow',-90,0,16,2,2,0,0
MEMBER:'instr-arrow',180,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-sensor',0,0,32,2,1,0,6
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-grab',-1,2,32,0,1,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-bond',-1,0,32,6,1,0,0
MEMBER:'instr-bond',-1,1,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,5,2,0,0
MEMBER:'instr-bond',-1,0,32,5,3,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-bond',-1,0,32,5,4,0,0
MEMBER:'instr-grab',-1,2,32,6,5,0,0
MEMBER:'instr-output',-1,1,32,6,6,0,0
MEMBER:'instr-arrow',-90,0,16,3,7,0,0
MEMBER:'instr-arrow',-90,0,16,3,6,0,0
MEMBER:'instr-sync',-1,0,32,4,7,0,0
MEMBER:'instr-grab',-1,1,32,3,7,0,0
MEMBER:'instr-grab',-1,0,32,3,6,0,0
MEMBER:'instr-grab',-1,0,32,3,5,0,0
MEMBER:'instr-grab',-1,0,32,3,4,0,0
MEMBER:'instr-grab',-1,0,32,3,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,14,1
PIPE:0,14,2
PIPE:0,14,3
PIPE:0,14,4
PIPE:0,14,5
PIPE:0,14,6
PIPE:0,14,7
PIPE:0,14,8
PIPE:0,14,9
PIPE:0,14,10
PIPE:0,14,11
PIPE:0,14,12
PIPE:1,4,1
PIPE:1,4,0
PIPE:1,4,-1
PIPE:1,4,-2
PIPE:1,4,-3
PIPE:1,4,-4
PIPE:1,5,-4
PIPE:1,6,-4
PIPE:1,7,-4
PIPE:1,8,-4
PIPE:1,9,-4
PIPE:1,10,-4
PIPE:1,11,-4
PIPE:1,12,-4
PIPE:1,13,-4
PIPE:1,14,-4
''',
    r'''SOLUTION:Ice to Meet You,Zig,176-1-10,Symbols
COMPONENT:'drag-fusion-reactor',2,0,''
MEMBER:'instr-start',180,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,0,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-fuser',-1,0,1,5,3,0,0
MEMBER:'instr-output',-1,0,32,0,7,0,0
MEMBER:'instr-input',-1,1,128,0,4,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',-90,0,64,5,5,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,0,1,0,0
MEMBER:'instr-arrow',180,0,64,5,1,0,0
MEMBER:'instr-bond',-1,0,128,0,5,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-fuse',-1,0,128,5,3,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r"""SOLUTION:Challenge: Applied Fusion,12345ieee,2055-5-125
COMPONENT:'drag-oceanic-input',4,11,''
PIPE:0,2,0
COMPONENT:'drag-fusion-reactor',17,14,''
MEMBER:'instr-start',180,0,128,3,0,0,0
MEMBER:'instr-start',90,0,32,0,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,2,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,0,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-fuser',-1,0,1,1,2,0,0
MEMBER:'instr-input',-1,1,32,1,6,0,0
MEMBER:'instr-grab',-1,0,32,1,5,0,0
MEMBER:'instr-input',-1,0,32,0,6,0,0
MEMBER:'instr-fuse',-1,0,32,1,3,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-grab',-1,0,32,3,3,0,0
MEMBER:'instr-rotate',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-arrow',0,0,16,0,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,6,0,0
MEMBER:'instr-sync',-1,0,128,2,0,0,0
MEMBER:'instr-arrow',-90,0,16,3,3,0,0
MEMBER:'instr-arrow',180,0,16,3,1,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-fuse',-1,0,32,0,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-bond',-1,0,128,2,1,0,0
MEMBER:'instr-grab',-1,0,32,2,1,0,0
MEMBER:'instr-arrow',180,0,64,2,2,0,0
MEMBER:'instr-sync',-1,0,32,0,4,0,0
MEMBER:'instr-arrow',90,0,64,0,2,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-arrow',-90,0,64,6,3,0,0
MEMBER:'instr-arrow',180,0,64,6,0,0,0
MEMBER:'instr-grab',-1,0,128,6,3,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-sync',-1,0,128,6,1,0,0
MEMBER:'instr-grab',-1,0,32,0,3,0,0
MEMBER:'instr-sync',-1,0,32,0,1,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-bond',-1,0,128,0,2,0,0
MEMBER:'instr-rotate',-1,1,128,5,3,0,0
PIPE:0,4,1
PIPE:1,4,2
ANNOTATION:0,1,91,-303,'1,2:0,13;0,2:0,8;2,2:0,8;1,3:0,8;0,3:0,1;2,3:0,1;2,1:0,1;\n0,2,1:1;2,1,0:1;1,2,0:1;0,2,0:1;1,3,1:1;1,2,1:1;\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-fusion-reactor',22,13,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,2,6,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-fuser',-1,0,1,2,2,0,0
MEMBER:'instr-input',-1,1,32,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,0,6,0,0
MEMBER:'instr-grab',-1,0,32,0,6,0,0
MEMBER:'instr-rotate',-1,1,32,1,3,0,0
MEMBER:'instr-arrow',0,0,16,0,3,0,0
MEMBER:'instr-sync',-1,0,32,2,3,0,0
MEMBER:'instr-sync',-1,0,128,3,1,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-fuse',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,0,32,3,3,0,0
MEMBER:'instr-grab',-1,0,128,2,3,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-fuse',-1,0,128,3,3,0,0
MEMBER:'instr-arrow',90,0,64,4,3,0,0
MEMBER:'instr-grab',-1,0,128,4,3,0,0
MEMBER:'instr-bond',-1,0,128,4,4,0,0
MEMBER:'instr-arrow',0,0,64,4,6,0,0
MEMBER:'instr-bond',-1,0,128,4,5,0,0
MEMBER:'instr-grab',-1,0,128,8,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,6,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-output',-1,1,128,8,5,0,0
MEMBER:'instr-arrow',90,0,16,3,3,0,0
MEMBER:'instr-arrow',180,0,16,3,6,0,0
MEMBER:'instr-sync',-1,0,32,3,6,0,0
MEMBER:'instr-sync',-1,0,128,8,4,0,0
MEMBER:'instr-grab',-1,0,128,1,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,0,5
PIPE:1,0,6
COMPONENT:'drag-fusion-reactor',7,9,''
MEMBER:'instr-start',90,0,128,2,2,0,0
MEMBER:'instr-start',90,0,32,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-fuser',-1,0,1,4,2,0,0
MEMBER:'instr-grab',-1,0,32,2,5,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,5,0,0
MEMBER:'instr-arrow',180,0,64,7,2,0,0
MEMBER:'instr-input',-1,1,128,2,4,0,0
MEMBER:'instr-grab',-1,0,128,7,2,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-grab',-1,0,128,2,5,0,0
MEMBER:'instr-grab',-1,0,32,8,5,0,0
MEMBER:'instr-output',-1,1,32,8,4,0,0
MEMBER:'instr-input',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,8,5,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:0,4,0
ANNOTATION:0,1,-349,-268,'1,2:0,8;0,2:0,1;1,3:0,1;\n0,2,1:1;1,2,0:1;\r0,2:0,1;1,3:0,1;1,2:0,8;\n1,2,0:1;0,2,1:1;\r0,2:0,1;1,3:0,1;1,2:0,8;\n1,2,0:1;0,2,1:1;\r'
ANNOTATION:1,1,-349,-173,'1,1:0,1;2,2:0,1;2,1:0,8;\n2,1,0:1;1,1,1:1;\r1,1:0,1;2,2:0,1;2,1:0,8;\n2,1,0:1;1,1,1:1;\r\n\r'
COMPONENT:'drag-fusion-reactor',12,8,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,3,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-fuser',-1,0,1,4,2,0,0
MEMBER:'instr-grab',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',90,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,8,5,0,0
MEMBER:'instr-arrow',180,0,16,8,2,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-grab',-1,0,32,8,5,0,0
MEMBER:'instr-output',-1,1,32,8,4,0,0
MEMBER:'instr-grab',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',-90,0,64,7,2,0,0
MEMBER:'instr-grab',-1,0,128,7,2,0,0
MEMBER:'instr-output',-1,0,128,7,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-sync',-1,0,32,1,3,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-sync',-1,0,128,3,1,0,0
MEMBER:'instr-rotate',-1,1,128,5,2,0,0
MEMBER:'instr-rotate',-1,1,128,6,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,9,2
PIPE:0,9,3
PIPE:0,9,4
PIPE:0,9,5
PIPE:1,4,7
PIPE:0,9,6
ANNOTATION:0,1,-208,-226,'1,2:0,8;2,2:0,1;1,1:0,1;\n1,1,0:1;1,2,1:1;\r\n\r\n\r'
ANNOTATION:1,1,-92,-259,'1,1:0,1;2,2:0,1;2,1:0,8;\n2,1,0:1;1,1,1:1;\r1,1:0,1;2,2:0,1;2,1:0,8;\n2,1,0:1;1,1,1:1;\r\n\r'
COMPONENT:'drag-fusion-reactor',12,15,''
MEMBER:'instr-start',0,0,128,0,0,0,0
MEMBER:'instr-start',180,0,32,8,0,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-fuser',-1,0,1,1,2,0,0
MEMBER:'instr-grab',-1,0,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,2,2,0,0
MEMBER:'instr-rotate',-1,0,128,2,2,0,0
MEMBER:'instr-grab',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',90,0,64,2,0,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-fuse',-1,0,32,4,0,0,0
MEMBER:'instr-fuse',-1,0,32,5,0,0,0
MEMBER:'instr-arrow',-90,0,16,8,1,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-fuse',-1,0,32,2,0,0,0
MEMBER:'instr-grab',-1,0,32,2,1,0,0
MEMBER:'instr-arrow',90,0,16,2,0,0,0
MEMBER:'instr-arrow',-90,0,64,0,2,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-grab',-1,0,32,7,1,0,0
MEMBER:'instr-output',-1,0,32,8,1,0,0
MEMBER:'instr-sync',-1,0,128,2,0,0,0
MEMBER:'instr-sync',-1,0,128,0,1,0,0
MEMBER:'instr-sync',-1,0,32,7,0,0,0
MEMBER:'instr-sync',-1,0,32,3,0,0,0
MEMBER:'instr-rotate',-1,1,32,3,1,0,0
MEMBER:'instr-rotate',-1,1,32,4,1,0,0
PIPE:0,4,1
PIPE:1,4,2
ANNOTATION:0,1,33,47,'1,1:0,8;2,1:0,1;1,0:0,11;\n1,0,0:1;1,1,1:1;\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'""",
    r'''SOLUTION:The Plot Thickens,Zig,1327-1-14,Symbols
COMPONENT:'drag-largeoutput-reactor',2,0,''
MEMBER:'instr-start',180,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,6,0,0
MEMBER:'feature-sensor',-1,0,1,9,7,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,6,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,2,128,2,6,0,0
MEMBER:'instr-arrow',-90,0,64,7,6,0,0
MEMBER:'instr-input',-1,1,128,1,6,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-grab',-1,1,128,7,6,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-output',-1,0,128,6,1,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-rotate',-1,1,128,7,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:The Plot Thickens,Zig,447-1-37,Cycles
COMPONENT:'drag-largeoutput-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,3,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,6,0,0
MEMBER:'feature-sensor',-1,0,1,7,6,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,6,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,2,128,2,6,0,0
MEMBER:'instr-input',-1,1,128,1,6,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-bond',-1,0,32,1,6,0,0
MEMBER:'instr-arrow',-90,0,64,2,3,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-arrow',-90,0,64,2,6,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-input',-1,1,128,1,2,0,0
MEMBER:'instr-sensor',0,0,128,2,5,0,6
MEMBER:'instr-arrow',-90,0,64,3,5,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,3,0,0
MEMBER:'instr-input',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',0,0,16,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-arrow',180,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-bond',-1,0,32,2,5,0,0
MEMBER:'instr-grab',-1,2,32,2,6,0,0
MEMBER:'instr-bond',-1,0,32,2,3,0,0
MEMBER:'instr-sensor',0,0,32,1,2,0,1
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-arrow',180,0,16,5,3,0,0
MEMBER:'instr-arrow',90,0,16,1,3,0,0
MEMBER:'instr-output',-1,0,32,5,2,0,0
MEMBER:'instr-rotate',-1,1,32,5,3,0,0
MEMBER:'instr-grab',-1,1,128,3,5,0,0
MEMBER:'instr-rotate',-1,1,128,3,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:The Plot Thickens,Zig,3350-1-70,Input Island
COMPONENT:'drag-largeoutput-reactor',2,0,''
MEMBER:'instr-start',90,0,128,2,5,0,0
MEMBER:'instr-start',180,0,32,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-sensor',-1,0,1,7,7,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-bond',-1,0,32,1,2,0,0
MEMBER:'instr-bond',-1,0,32,1,3,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-bond',-1,0,32,3,0,0,0
MEMBER:'instr-bond',-1,1,32,3,1,0,0
MEMBER:'instr-arrow',180,0,16,3,1,0,0
MEMBER:'instr-arrow',0,0,16,0,0,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-arrow',180,0,64,1,2,0,0
MEMBER:'instr-bond',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',-90,0,64,0,2,0,0
MEMBER:'instr-rotate',-1,0,128,0,2,0,0
MEMBER:'instr-rotate',-1,0,128,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-grab',-1,0,128,1,0,0,0
MEMBER:'instr-grab',-1,1,32,0,4,0,0
MEMBER:'instr-arrow',90,0,16,3,0,0,0
MEMBER:'instr-grab',-1,2,32,2,2,0,0
MEMBER:'instr-rotate',-1,0,128,2,0,0,0
MEMBER:'instr-bond',-1,0,32,1,5,0,0
MEMBER:'instr-rotate',-1,0,128,2,3,0,0
MEMBER:'instr-grab',-1,2,128,3,4,0,0
MEMBER:'instr-input',-1,0,128,2,7,0,0
MEMBER:'instr-input',-1,0,128,3,6,0,0
MEMBER:'instr-input',-1,0,128,2,6,0,0
MEMBER:'instr-input',-1,0,128,3,7,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-grab',-1,2,128,2,1,0,0
MEMBER:'instr-grab',-1,1,128,2,2,0,0
MEMBER:'instr-rotate',-1,0,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,0,7,0,0
MEMBER:'instr-sync',-1,0,128,3,5,0,0
MEMBER:'instr-input',-1,0,128,0,7,0,0
MEMBER:'instr-input',-1,1,128,1,7,0,0
MEMBER:'instr-arrow',90,0,64,2,0,0,0
MEMBER:'instr-arrow',180,0,64,3,5,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-arrow',-90,0,64,3,7,0,0
MEMBER:'instr-grab',-1,0,128,1,6,0,0
MEMBER:'instr-arrow',180,0,64,3,6,0,0
MEMBER:'instr-arrow',0,0,64,2,7,0,0
MEMBER:'instr-arrow',90,0,64,0,6,0,0
MEMBER:'instr-arrow',-90,0,64,1,7,0,0
MEMBER:'instr-rotate',-1,0,128,0,6,0,0
MEMBER:'instr-grab',-1,2,32,1,6,0,0
MEMBER:'instr-input',-1,1,32,0,2,0,0
MEMBER:'instr-bond',-1,0,32,3,2,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-arrow',-90,0,16,0,4,0,0
MEMBER:'instr-input',-1,0,32,0,0,0,0
MEMBER:'instr-arrow',180,0,16,1,7,0,0
MEMBER:'instr-arrow',90,0,16,3,2,0,0
MEMBER:'instr-arrow',180,0,16,3,4,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-arrow',0,0,16,0,5,0,0
MEMBER:'instr-arrow',90,0,16,3,5,0,0
MEMBER:'instr-arrow',180,0,16,3,7,0,0
MEMBER:'instr-arrow',-90,0,16,2,7,0,0
MEMBER:'instr-grab',-1,1,32,2,6,0,0
MEMBER:'instr-sync',-1,0,32,0,6,0,0
MEMBER:'instr-input',-1,1,32,0,7,0,0
MEMBER:'instr-sync',-1,0,32,1,7,0,0
MEMBER:'instr-sync',-1,0,32,0,3,0,0
MEMBER:'instr-sensor',0,0,128,1,4,0,6
MEMBER:'instr-arrow',180,0,64,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-output',-1,0,128,2,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Gas Works Park,Zig,822-5-148,Cycles
COMPONENT:'drag-advanced-reactor',5,6,''
MEMBER:'instr-start',180,0,128,6,7,0,0
MEMBER:'instr-start',-90,0,32,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-sensor',-1,0,1,1,1,0,0
MEMBER:'instr-input',-1,0,128,5,7,0,0
MEMBER:'instr-grab',-1,1,128,2,2,0,0
MEMBER:'instr-grab',-1,1,32,2,3,0,0
MEMBER:'instr-grab',-1,1,32,2,2,0,0
MEMBER:'instr-rotate',-1,0,32,3,3,0,0
MEMBER:'instr-output',-1,0,32,4,3,0,0
MEMBER:'instr-output',-1,0,32,5,3,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-arrow',90,0,16,9,3,0,0
MEMBER:'instr-output',-1,0,128,0,5,0,0
MEMBER:'instr-arrow',180,0,16,9,5,0,0
MEMBER:'instr-output',-1,1,32,6,6,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-bond',-1,1,128,1,7,0,0
MEMBER:'instr-bond',-1,1,128,2,7,0,0
MEMBER:'instr-bond',-1,1,128,0,7,0,0
MEMBER:'instr-arrow',-90,0,64,0,7,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-arrow',90,0,64,6,1,0,0
MEMBER:'instr-bond',-1,1,128,7,2,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-arrow',90,0,64,8,2,0,0
MEMBER:'instr-arrow',180,0,64,8,4,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-sensor',-90,0,128,1,2,0,6
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',180,0,64,6,6,0,0
MEMBER:'instr-output',-1,1,128,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,1,6,0,0
MEMBER:'instr-grab',-1,2,128,8,4,0,0
MEMBER:'instr-rotate',-1,1,128,8,3,0,0
MEMBER:'instr-output',-1,1,128,7,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-rotate',-1,1,128,8,2,0,0
MEMBER:'instr-arrow',-90,0,16,1,4,0,0
MEMBER:'instr-arrow',0,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-arrow',180,0,16,6,6,0,0
MEMBER:'instr-arrow',180,0,16,8,4,0,0
MEMBER:'instr-arrow',90,0,16,8,2,0,0
MEMBER:'instr-sensor',-90,0,32,1,2,0,6
MEMBER:'instr-rotate',-1,1,32,8,2,0,0
MEMBER:'instr-rotate',-1,1,32,8,3,0,0
MEMBER:'instr-grab',-1,2,32,6,5,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
MEMBER:'instr-grab',-1,2,32,8,4,0,0
MEMBER:'instr-arrow',-90,0,16,1,6,0,0
MEMBER:'instr-arrow',0,0,16,2,3,0,0
MEMBER:'instr-input',-1,0,32,1,3,0,0
MEMBER:'instr-arrow',-90,0,16,1,5,0,0
MEMBER:'instr-output',-1,0,32,1,4,0,0
MEMBER:'instr-bond',-1,1,128,2,6,0,0
MEMBER:'instr-output',-1,0,32,6,2,0,0
MEMBER:'instr-bond',-1,1,128,6,2,0,0
MEMBER:'instr-output',-1,0,32,2,6,0,0
MEMBER:'instr-output',-1,0,32,1,6,0,0
MEMBER:'instr-bond',-1,1,128,1,6,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-output',-1,0,32,7,2,0,0
MEMBER:'instr-output',-1,0,32,4,4,0,0
MEMBER:'instr-output',-1,0,32,3,4,0,0
MEMBER:'instr-bond',-1,1,128,4,4,0,0
MEMBER:'instr-bond',-1,1,128,3,4,0,0
MEMBER:'instr-bond',-1,1,128,1,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,5,3
PIPE:1,5,4
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-2,4
PIPE:1,-3,4
PIPE:1,-4,4
PIPE:1,-5,4
PIPE:1,-5,5
PIPE:1,-4,5
PIPE:1,-3,5
PIPE:1,-2,5
PIPE:1,-1,5
PIPE:1,0,5
PIPE:1,1,5
PIPE:1,2,5
PIPE:1,3,5
PIPE:1,4,5
PIPE:1,5,5
PIPE:1,5,6
PIPE:1,4,6
PIPE:1,3,6
PIPE:1,2,6
PIPE:1,1,6
PIPE:1,0,6
PIPE:1,-1,6
PIPE:1,-2,6
PIPE:1,-3,6
PIPE:1,-4,6
PIPE:1,-5,6
PIPE:1,-5,7
PIPE:1,-4,7
PIPE:1,-3,7
PIPE:1,-2,7
PIPE:1,-1,7
PIPE:1,0,7
PIPE:1,1,7
PIPE:1,2,7
PIPE:1,3,7
PIPE:1,4,7
PIPE:1,5,7
PIPE:1,5,8
PIPE:1,4,8
PIPE:1,3,8
PIPE:1,2,8
PIPE:1,1,8
PIPE:1,0,8
PIPE:1,-1,8
PIPE:1,-2,8
PIPE:1,-3,8
PIPE:1,-3,9
PIPE:1,-2,9
PIPE:1,-1,9
PIPE:1,0,9
PIPE:1,1,9
PIPE:1,2,9
PIPE:1,3,9
PIPE:1,4,9
PIPE:1,5,9
PIPE:1,6,9
PIPE:1,6,8
PIPE:1,6,7
PIPE:1,6,6
PIPE:1,7,6
PIPE:1,8,6
PIPE:1,9,6
PIPE:1,10,6
PIPE:1,11,6
PIPE:1,12,6
PIPE:1,13,6
PIPE:1,14,6
PIPE:1,15,6
PIPE:1,16,6
PIPE:1,17,6
PIPE:1,18,6
PIPE:1,19,6
PIPE:1,20,6
PIPE:1,21,6
PIPE:1,22,6
PIPE:1,23,6
PIPE:1,24,6
PIPE:1,25,6
PIPE:1,26,6
PIPE:1,26,5
PIPE:1,26,4
PIPE:1,26,3
PIPE:1,26,2
PIPE:1,26,1
PIPE:1,26,0
PIPE:1,26,-1
PIPE:1,25,-1
PIPE:1,25,0
PIPE:1,25,1
PIPE:1,25,2
PIPE:1,25,3
PIPE:1,25,4
PIPE:1,25,5
PIPE:1,24,5
PIPE:1,24,4
PIPE:1,24,3
PIPE:1,24,2
PIPE:1,24,1
PIPE:1,24,0
PIPE:1,24,-1
PIPE:1,23,-1
PIPE:1,23,0
PIPE:1,23,1
PIPE:1,23,2
PIPE:1,23,3
PIPE:1,23,4
PIPE:1,23,5
PIPE:1,22,5
PIPE:1,22,4
PIPE:1,22,3
PIPE:1,22,2
PIPE:1,22,1
PIPE:1,22,0
PIPE:1,22,-1
PIPE:1,21,-1
PIPE:1,21,0
PIPE:1,21,1
PIPE:1,21,2
PIPE:1,21,3
PIPE:1,21,4
PIPE:1,21,5
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,5,3
ANNOTATION:0,1,130,-209,'1,3:0,6;\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-superbonder-reactor',9,18,''
MEMBER:'instr-start',-90,0,128,2,3,0,0
MEMBER:'instr-start',90,0,32,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,2,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,6,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-bonder',-1,0,1,8,1,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-output',-1,0,32,8,1,0,0
MEMBER:'instr-arrow',90,0,16,9,1,0,0
MEMBER:'instr-grab',-1,2,32,8,4,0,0
MEMBER:'instr-arrow',180,0,16,9,4,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,2,4,0,0
MEMBER:'instr-input',-1,0,128,9,3,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,9,1,0,0
MEMBER:'instr-arrow',180,0,64,9,4,0,0
MEMBER:'instr-bond',-1,1,128,4,4,0,0
MEMBER:'instr-grab',-1,2,128,8,4,0,0
MEMBER:'instr-output',-1,1,32,4,1,0,0
MEMBER:'instr-arrow',-90,0,64,2,4,0,0
MEMBER:'instr-bond',-1,1,128,8,1,0,0
MEMBER:'instr-output',-1,0,32,3,4,0,0
MEMBER:'instr-bond',-1,1,128,7,1,0,0
MEMBER:'instr-output',-1,0,32,7,1,0,0
MEMBER:'instr-bond',-1,1,128,5,4,0,0
MEMBER:'instr-output',-1,0,32,2,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:0,5,1
PIPE:1,8,2
PIPE:1,8,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,7,0
PIPE:0,7,-1
PIPE:0,7,-2
PIPE:0,7,-3
PIPE:0,7,-4
PIPE:0,7,-5
PIPE:0,7,-6
PIPE:0,7,-7
PIPE:0,7,-8
PIPE:0,7,-9
PIPE:0,7,-10
PIPE:0,7,-11
PIPE:0,7,-12
PIPE:0,7,-13
PIPE:0,7,-14
PIPE:0,7,-15
PIPE:0,8,-15
ANNOTATION:0,0,-194,-3,'1,1:0,1;\n\r2,2:0,1;\n\r\n\r'
ANNOTATION:1,0,-290,-25,'2,0:0,8;\n\r\n\r\n\r'
COMPONENT:'drag-silo-input',3,17,''
PIPE:0,5,2
COMPONENT:'drag-superbonder-reactor',18,17,''
MEMBER:'instr-start',180,0,128,3,5,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-input',-1,1,128,2,5,0,0
MEMBER:'instr-grab',-1,1,128,2,4,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-bond',-1,0,128,3,3,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-arrow',90,0,64,4,3,0,0
MEMBER:'instr-arrow',0,0,64,4,4,0,0
MEMBER:'instr-input',-1,1,128,4,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-arrow',90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-rotate',-1,1,128,5,4,0,0
MEMBER:'instr-output',-1,1,128,6,5,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-advanced-reactor',11,8,''
MEMBER:'instr-start',90,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-sensor',-1,0,1,5,7,0,0
MEMBER:'instr-grab',-1,1,32,1,3,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,7,0,0
MEMBER:'instr-arrow',0,0,16,0,3,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-input',-1,0,32,0,3,0,0
MEMBER:'instr-arrow',90,0,64,7,3,0,0
MEMBER:'instr-arrow',180,0,64,7,6,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
MEMBER:'instr-output',-1,0,32,6,6,0,0
MEMBER:'instr-input',-1,0,128,0,3,0,0
MEMBER:'instr-grab',-1,1,128,1,3,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-arrow',-90,0,64,0,6,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,6,2
PIPE:1,4,1
PIPE:1,4,0
PIPE:1,4,-1
PIPE:1,4,-2
PIPE:1,4,-3
PIPE:1,4,-4
PIPE:0,6,3
PIPE:0,6,4
PIPE:0,6,5
PIPE:0,6,6
PIPE:0,6,7
PIPE:0,6,8
PIPE:0,6,9
PIPE:0,6,10
PIPE:1,5,-4
PIPE:1,6,-4
ANNOTATION:0,1,145,21,'1,3:0,6;\n\r\n\r\n\r'
ANNOTATION:1,1,249,-55,'1,0:0,6;\n\r\n\r\n\r'
COMPONENT:'drag-superbonder-reactor',18,2,''
MEMBER:'instr-start',180,0,128,8,2,0,0
MEMBER:'instr-start',180,0,32,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,0,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,0,1,0,0
MEMBER:'instr-grab',-1,1,32,0,4,0,0
MEMBER:'instr-arrow',180,0,64,7,2,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-input',-1,1,32,1,4,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-bond',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',90,0,16,8,2,0,0
MEMBER:'instr-grab',-1,2,32,2,2,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-arrow',-90,0,16,0,4,0,0
MEMBER:'instr-arrow',180,0,16,8,4,0,0
MEMBER:'instr-bond',-1,0,32,8,3,0,0
MEMBER:'instr-output',-1,0,32,4,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,7,2,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-bond',-1,0,32,8,2,0,0
MEMBER:'instr-input',-1,0,32,0,2,0,0
MEMBER:'instr-bond',-1,0,128,6,2,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-mining-input',1,7,''
PIPE:0,3,0''',
    r"""SOLUTION:Challenge: KOHCTPYKTOP,12345ieee,4559-5-201
COMPONENT:'drag-advanced-reactor',8,14,''
MEMBER:'instr-start',180,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-sensor',-1,0,1,4,2,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-grab',-1,0,128,7,4,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-sync',-1,0,128,7,2,0,0
MEMBER:'instr-input',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,1,5,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-grab',-1,0,32,1,5,0,0
MEMBER:'instr-grab',-1,0,32,7,4,0,0
MEMBER:'instr-arrow',90,0,16,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,5,0,0
MEMBER:'instr-sync',-1,0,32,3,5,0,0
MEMBER:'instr-output',-1,1,128,7,3,0,0
MEMBER:'instr-output',-1,1,32,7,5,0,0
MEMBER:'instr-sync',-1,0,32,6,5,0,0
MEMBER:'instr-sync',-1,0,128,4,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,9,2
PIPE:1,9,1
PIPE:1,9,0
PIPE:1,9,-1
PIPE:1,9,-2
PIPE:1,9,-3
PIPE:1,9,-4
PIPE:1,9,-5
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,174,-27,'1,0:0,33;\n\r1,0:0,5;\n\r\n\r'
COMPONENT:'drag-silo-input',2,17,''
PIPE:0,5,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
COMPONENT:'drag-silo-input',2,10,''
PIPE:0,5,2
PIPE:0,5,3
PIPE:0,5,4
PIPE:0,5,5
COMPONENT:'drag-superbonder-reactor',5,6,''
MEMBER:'instr-start',-90,0,128,2,4,0,0
MEMBER:'instr-start',-90,0,32,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,0,0,0
MEMBER:'feature-bonder',-1,0,1,9,0,0,0
MEMBER:'feature-bonder',-1,0,1,7,0,0,0
MEMBER:'feature-bonder',-1,0,1,9,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,1,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-grab',-1,0,128,2,2,0,0
MEMBER:'instr-output',-1,0,128,5,3,0,0
MEMBER:'instr-bond',-1,1,128,5,2,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-arrow',90,0,64,5,2,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-output',-1,0,128,6,4,0,0
MEMBER:'instr-grab',-1,0,128,7,5,0,0
MEMBER:'instr-output',-1,1,128,7,6,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-arrow',0,0,64,6,4,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,7,4,0,0
MEMBER:'instr-arrow',180,0,64,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,2,6,0,0
MEMBER:'instr-rotate',-1,1,128,3,2,0,0
MEMBER:'instr-rotate',-1,1,128,4,2,0,0
MEMBER:'instr-output',-1,0,32,5,3,0,0
MEMBER:'instr-bond',-1,1,32,5,2,0,0
MEMBER:'instr-bond',-1,1,32,6,3,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-output',-1,0,32,6,4,0,0
MEMBER:'instr-grab',-1,0,32,7,5,0,0
MEMBER:'instr-output',-1,1,32,7,6,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',0,0,16,6,4,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-arrow',90,0,16,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,6,0,0
MEMBER:'instr-rotate',-1,1,32,3,2,0,0
MEMBER:'instr-rotate',-1,1,32,4,2,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-input',-1,0,32,2,3,0,0
MEMBER:'instr-grab',-1,0,32,2,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,4,-4
PIPE:0,4,-5
PIPE:0,4,-6
PIPE:0,5,-6
PIPE:0,6,-6
PIPE:0,7,-6
PIPE:0,8,-6
PIPE:0,9,-6
PIPE:0,10,-6
PIPE:0,11,-6
PIPE:0,12,-6
PIPE:0,13,-6
PIPE:0,14,-6
PIPE:0,15,-6
PIPE:0,16,-6
PIPE:0,17,-6
PIPE:0,18,-6
PIPE:0,19,-6
PIPE:0,20,-6
PIPE:0,20,-5
PIPE:0,20,-4
PIPE:0,20,-3
PIPE:0,20,-2
PIPE:0,20,-1
PIPE:0,20,0
PIPE:0,20,1
PIPE:0,20,2
PIPE:0,20,3
PIPE:0,20,4
PIPE:0,20,5
PIPE:0,20,6
PIPE:0,20,7
PIPE:0,20,8
PIPE:0,20,9
PIPE:0,20,10
PIPE:0,20,11
PIPE:0,20,12
ANNOTATION:1,0,47,-189,'1,2:0,8;3,3:0,14;2,2:0,14;1,1:0,14;2,3:0,8;\n2,2,0:1;1,2,1:1;2,3,1:1;1,1,0:1;\r\n\r\n\r'
ANNOTATION:0,0,-46,-179,'1,3:0,8;\n\r\n\r\n\r'
COMPONENT:'drag-mining-input',3,3,''
PIPE:0,3,0
PIPE:0,3,1
PIPE:0,3,2
PIPE:0,2,2
PIPE:0,1,2
PIPE:0,1,3
PIPE:0,1,4
COMPONENT:'drag-superbonder-reactor',15,2,''
MEMBER:'instr-start',90,0,128,4,2,0,0
MEMBER:'instr-start',0,0,32,0,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-grab',-1,0,128,2,3,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',-90,0,64,0,3,0,0
MEMBER:'instr-bond',-1,0,32,3,7,0,0
MEMBER:'instr-sync',-1,0,128,1,3,0,0
MEMBER:'instr-sync',-1,0,128,0,3,0,0
MEMBER:'instr-sync',-1,0,128,0,2,0,0
MEMBER:'instr-sync',-1,0,128,0,1,0,0
MEMBER:'instr-sync',-1,0,128,1,1,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-arrow',0,0,16,1,2,0,0
MEMBER:'instr-input',-1,0,32,4,7,0,0
MEMBER:'instr-sync',-1,0,32,2,7,0,0
MEMBER:'instr-input',-1,0,32,9,6,0,0
MEMBER:'instr-bond',-1,0,32,9,7,0,0
MEMBER:'instr-sync',-1,0,32,8,7,0,0
MEMBER:'instr-input',-1,0,32,1,7,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-bond',-1,0,32,2,6,0,0
MEMBER:'instr-sync',-1,0,32,3,6,0,0
MEMBER:'instr-input',-1,0,32,1,6,0,0
MEMBER:'instr-sync',-1,0,32,0,6,0,0
MEMBER:'instr-input',-1,0,32,3,5,0,0
MEMBER:'instr-input',-1,0,32,6,4,0,0
MEMBER:'instr-bond',-1,0,32,9,4,0,0
MEMBER:'instr-sync',-1,0,32,9,5,0,0
MEMBER:'instr-input',-1,0,32,7,7,0,0
MEMBER:'instr-bond',-1,0,32,6,7,0,0
MEMBER:'instr-grab',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',180,0,16,3,4,0,0
MEMBER:'instr-sync',-1,0,32,5,7,0,0
MEMBER:'instr-grab',-1,0,32,2,4,0,0
MEMBER:'instr-grab',-1,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,7,2,0,0
MEMBER:'instr-arrow',180,0,64,4,3,0,0
MEMBER:'instr-sync',-1,0,128,4,3,0,0
MEMBER:'instr-arrow',90,0,16,9,0,0,0
MEMBER:'instr-sync',-1,0,32,3,2,0,0
MEMBER:'instr-input',-1,0,32,4,1,0,0
MEMBER:'instr-bond',-1,0,32,6,1,0,0
MEMBER:'instr-sync',-1,0,32,5,1,0,0
MEMBER:'instr-input',-1,0,32,9,0,0,0
MEMBER:'instr-bond',-1,0,32,4,0,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-input',-1,0,32,6,0,0,0
MEMBER:'instr-bond',-1,0,32,7,0,0,0
MEMBER:'instr-sync',-1,0,32,8,0,0,0
MEMBER:'instr-input',-1,0,32,5,2,0,0
MEMBER:'instr-bond',-1,0,32,8,2,0,0
MEMBER:'instr-sync',-1,0,32,9,2,0,0
MEMBER:'instr-input',-1,0,32,7,1,0,0
MEMBER:'instr-bond',-1,0,32,9,1,0,0
MEMBER:'instr-sync',-1,0,32,8,1,0,0
MEMBER:'instr-input',-1,0,32,9,3,0,0
MEMBER:'instr-bond',-1,0,32,8,3,0,0
MEMBER:'instr-sync',-1,0,32,7,3,0,0
MEMBER:'instr-input',-1,0,32,6,3,0,0
MEMBER:'instr-bond',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,0,32,4,3,0,0
MEMBER:'instr-grab',-1,0,32,7,4,0,0
MEMBER:'instr-output',-1,1,32,8,4,0,0
MEMBER:'instr-sync',-1,0,32,4,4,0,0
MEMBER:'instr-grab',-1,0,32,1,4,0,0
MEMBER:'instr-arrow',90,0,16,4,3,0,0
MEMBER:'instr-input',-1,0,32,1,3,0,0
MEMBER:'instr-grab',-1,0,32,2,2,0,0
MEMBER:'instr-bond',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',180,0,16,9,3,0,0
MEMBER:'instr-arrow',180,0,16,9,7,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-arrow',90,0,16,9,4,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,4,2,0,0
MEMBER:'instr-rotate',-1,1,32,5,4,0,0
MEMBER:'instr-rotate',-1,1,32,4,2,0,0
MEMBER:'instr-arrow',-90,0,16,3,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,4,0,0
MEMBER:'instr-arrow',-90,0,16,8,2,0,0
MEMBER:'instr-arrow',0,0,16,0,6,0,0
MEMBER:'instr-arrow',180,0,16,8,1,0,0
MEMBER:'instr-arrow',-90,0,16,4,1,0,0
MEMBER:'instr-arrow',0,0,16,4,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:0,5,1
PIPE:0,6,1
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,2,5
PIPE:1,2,6
PIPE:0,7,1
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,74,-16,'0,2:0,14;2,2:0,14;0,1:0,14;2,1:0,14;1,2:0,14;0,0:0,14;2,0:0,14;1,0:0,14;\n0,1,0:1;2,1,0:1;0,2,1:1;0,0,0:1;2,0,0:1;1,0,1:1;1,2,1:1;0,0,1:1;\r\n\r\n\r'
COMPONENT:'drag-superbonder-reactor',18,7,''
MEMBER:'instr-start',180,0,128,2,0,0,0
MEMBER:'instr-start',180,0,32,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,0,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-grab',-1,0,128,0,0,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-bond',-1,0,32,6,7,0,0
MEMBER:'instr-input',-1,1,128,0,3,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-grab',-1,0,128,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,2,0,0
MEMBER:'instr-grab',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-input',-1,1,128,2,5,0,0
MEMBER:'instr-output',-1,1,128,6,2,0,0
MEMBER:'instr-grab',-1,0,128,8,3,0,0
MEMBER:'instr-output',-1,0,128,8,2,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-input',-1,0,128,3,2,0,0
MEMBER:'instr-arrow',0,0,64,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,8,5,0,0
MEMBER:'instr-sync',-1,0,128,0,1,0,0
MEMBER:'instr-sync',-1,0,32,8,7,0,0
MEMBER:'instr-sync',-1,0,128,2,3,0,0
MEMBER:'instr-arrow',0,0,16,6,7,0,0
MEMBER:'instr-arrow',180,0,16,8,7,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
COMPONENT:'drag-superbonder-reactor',10,8,''
MEMBER:'instr-start',-90,0,128,1,5,0,0
MEMBER:'instr-start',180,0,32,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,4,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-bond',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-output',-1,0,32,3,4,0,0
MEMBER:'instr-bond',-1,1,128,7,2,0,0
MEMBER:'instr-arrow',0,0,64,7,3,0,0
MEMBER:'instr-grab',-1,0,128,8,3,0,0
MEMBER:'instr-grab',-1,0,32,1,1,0,0
MEMBER:'instr-input',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-bond',-1,1,128,3,4,0,0
MEMBER:'instr-arrow',90,0,16,7,1,0,0
MEMBER:'instr-arrow',0,0,16,7,3,0,0
MEMBER:'instr-grab',-1,0,32,8,3,0,0
MEMBER:'instr-output',-1,0,32,1,4,0,0
MEMBER:'instr-output',-1,1,128,1,3,0,0
MEMBER:'instr-arrow',-90,0,16,1,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-sync',-1,0,32,4,4,0,0
MEMBER:'instr-sync',-1,0,128,5,1,0,0
MEMBER:'instr-arrow',90,0,64,8,3,0,0
MEMBER:'instr-arrow',180,0,64,8,4,0,0
MEMBER:'instr-arrow',90,0,16,8,3,0,0
MEMBER:'instr-arrow',180,0,16,8,4,0,0
MEMBER:'instr-output',-1,1,128,7,3,0,0
MEMBER:'instr-bond',-1,1,32,1,3,0,0
MEMBER:'instr-output',-1,0,32,8,4,0,0
MEMBER:'instr-output',-1,0,128,8,4,0,0
MEMBER:'instr-output',-1,1,128,7,4,0,0
MEMBER:'instr-output',-1,0,32,6,1,0,0
MEMBER:'instr-bond',-1,1,128,1,4,0,0
MEMBER:'instr-output',-1,0,32,7,2,0,0
MEMBER:'instr-bond',-1,1,32,7,3,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,4,12
PIPE:1,5,12
PIPE:1,6,12
PIPE:1,7,12
PIPE:1,8,12
PIPE:1,9,12
PIPE:1,10,12
PIPE:1,11,12
PIPE:1,12,12
PIPE:1,13,12
PIPE:1,14,12
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,4,-4
PIPE:0,4,-5
PIPE:1,15,12
ANNOTATION:0,1,-126,-203,'2,3:0,14;\n\r\n\r\n\r'
ANNOTATION:1,0,225,118,'1,0:0,8;1,1:0,8;\n\r\n\r\n\r'""",
    r'''SOLUTION:No Employment Record Found,Zig,344-1-77,Cycles
COMPONENT:'drag-advancedfusion-reactor',2,0,''
MEMBER:'instr-start',180,0,128,2,0,0,0
MEMBER:'instr-start',180,0,32,8,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-fuser',-1,0,1,1,5,0,0
MEMBER:'feature-sensor',-1,0,1,3,4,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-bond',-1,0,128,2,4,0,0
MEMBER:'instr-input',-1,1,128,3,5,0,0
MEMBER:'instr-input',-1,1,128,4,5,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-arrow',180,0,16,3,5,0,0
MEMBER:'instr-arrow',90,0,16,2,4,0,0
MEMBER:'instr-sensor',180,0,32,3,4,0,14
MEMBER:'instr-arrow',180,0,16,2,5,0,0
MEMBER:'instr-input',-1,1,32,3,5,0,0
MEMBER:'instr-grab',-1,2,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,1,5,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,2,3,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-arrow',90,0,64,7,3,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-fuse',-1,0,32,1,4,0,0
MEMBER:'instr-fuse',-1,0,32,1,3,0,0
MEMBER:'instr-fuse',-1,0,128,7,3,0,0
MEMBER:'instr-sensor',-90,0,128,5,3,0,5
MEMBER:'instr-input',-1,1,128,8,2,0,0
MEMBER:'instr-input',-1,1,128,9,4,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-fuse',-1,0,32,2,2,0,0
MEMBER:'instr-arrow',0,0,64,5,2,0,0
MEMBER:'instr-arrow',90,0,64,9,2,0,0
MEMBER:'instr-arrow',180,0,64,9,6,0,0
MEMBER:'instr-input',-1,1,128,7,2,0,0
MEMBER:'instr-arrow',180,0,64,7,5,0,0
MEMBER:'instr-input',-1,1,128,6,5,0,0
MEMBER:'instr-input',-1,1,128,9,5,0,0
MEMBER:'instr-input',-1,1,128,9,6,0,0
MEMBER:'instr-input',-1,1,128,7,6,0,0
MEMBER:'instr-grab',-1,1,32,3,2,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,2,128,3,2,0,0
MEMBER:'instr-arrow',-90,0,64,2,6,0,0
MEMBER:'instr-arrow',-90,0,16,2,3,0,0
MEMBER:'instr-arrow',180,0,16,2,2,0,0
MEMBER:'instr-arrow',-90,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-output',-1,0,32,2,4,0,0
MEMBER:'instr-fuse',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',-90,0,64,5,4,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-arrow',90,0,16,3,2,0,0
MEMBER:'instr-sensor',90,0,32,3,1,0,17
MEMBER:'instr-arrow',90,0,16,7,1,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-grab',-1,2,128,9,3,0,0
MEMBER:'instr-input',-1,0,128,4,4,0,0
MEMBER:'instr-input',-1,1,128,7,4,0,0
MEMBER:'instr-output',-1,0,128,5,4,0,0
MEMBER:'instr-fuse',-1,0,128,6,2,0,0
MEMBER:'instr-input',-1,1,128,9,2,0,0
MEMBER:'instr-fuse',-1,0,128,8,6,0,0
MEMBER:'instr-fuse',-1,0,128,6,6,0,0
MEMBER:'instr-input',-1,1,32,4,1,0,0
MEMBER:'instr-input',-1,1,32,5,1,0,0
MEMBER:'instr-input',-1,1,32,6,1,0,0
MEMBER:'instr-input',-1,1,32,7,1,0,0
MEMBER:'instr-fuse',-1,0,128,5,6,0,0
MEMBER:'instr-fuse',-1,0,128,4,6,0,0
MEMBER:'instr-fuse',-1,0,128,3,6,0,0
MEMBER:'instr-fuse',-1,0,128,2,6,0,0
MEMBER:'instr-fuse',-1,0,32,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,3,2,0,0
MEMBER:'instr-arrow',180,0,64,4,5,0,0
MEMBER:'instr-input',-1,1,128,4,3,0,0
MEMBER:'instr-input',-1,1,32,7,2,0,0
MEMBER:'instr-arrow',90,0,64,4,0,0,0
MEMBER:'instr-toggle',0,0,128,3,0,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Right All Along,Zig,708-1-57,Cycles
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,6,3,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-sensor',-1,0,1,7,6,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-bond',-1,0,32,1,5,0,0
MEMBER:'instr-bond',-1,0,32,1,6,0,0
MEMBER:'instr-bond',-1,0,128,1,5,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-input',-1,1,128,2,3,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-arrow',180,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-grab',-1,2,32,2,4,0,0
MEMBER:'instr-bond',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,2,3,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,5,3,0,0
MEMBER:'instr-arrow',0,0,64,1,6,0,0
MEMBER:'instr-arrow',-90,0,64,2,6,0,0
MEMBER:'instr-sensor',0,0,128,2,6,0,6
MEMBER:'instr-input',-1,1,128,1,6,0,0
MEMBER:'instr-grab',-1,2,128,2,4,0,0
MEMBER:'instr-arrow',180,0,64,6,3,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-sensor',0,0,32,2,6,0,6
MEMBER:'instr-rotate',-1,1,32,3,6,0,0
MEMBER:'instr-arrow',90,0,16,3,6,0,0
MEMBER:'instr-arrow',180,0,16,3,7,0,0
MEMBER:'instr-grab',-1,2,32,1,7,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-arrow',0,0,16,0,1,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-arrow',-90,0,64,3,6,0,0
MEMBER:'instr-bond',-1,0,32,2,1,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-input',-1,1,128,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,6,5,0,0
MEMBER:'instr-arrow',0,0,64,3,1,0,0
MEMBER:'instr-arrow',90,0,64,8,1,0,0
MEMBER:'instr-input',-1,1,128,3,2,0,0
MEMBER:'instr-input',-1,1,128,8,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,6,0,0
MEMBER:'instr-toggle',0,0,128,5,5,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-grab',-1,1,128,6,6,0,0
MEMBER:'instr-input',-1,1,128,8,6,0,0
MEMBER:'instr-arrow',180,0,64,5,5,0,0
MEMBER:'instr-arrow',180,0,64,8,6,0,0
MEMBER:'instr-bond',-1,0,128,0,5,0,0
MEMBER:'instr-output',-1,0,32,0,3,0,0
MEMBER:'instr-sync',-1,0,128,4,5,0,0
MEMBER:'instr-sync',-1,0,32,2,7,0,0
MEMBER:'instr-sync',-1,0,32,0,5,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Accidents Happen,Zig,275-1-88,Cycles
COMPONENT:'drag-advanced-reactor',2,0,''
MEMBER:'instr-start',0,0,128,4,1,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,6,0,0
MEMBER:'feature-sensor',-1,0,1,1,1,0,0
MEMBER:'instr-arrow',180,0,64,1,4,0,0
MEMBER:'instr-arrow',90,0,64,0,4,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-grab',-1,1,128,0,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-grab',-1,2,128,1,4,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,7,4,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-bond',-1,1,128,7,2,0,0
MEMBER:'instr-bond',-1,0,128,6,2,0,0
MEMBER:'instr-bond',-1,0,128,3,2,0,0
MEMBER:'instr-bond',-1,0,128,4,3,0,0
MEMBER:'instr-rotate',-1,0,128,2,4,0,0
MEMBER:'instr-grab',-1,2,128,2,3,0,0
MEMBER:'instr-grab',-1,1,128,3,4,0,0
MEMBER:'instr-sensor',90,0,128,4,2,0,14
MEMBER:'instr-arrow',180,0,64,7,2,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,5,0,0
MEMBER:'instr-arrow',0,0,64,1,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-sensor',0,0,128,2,5,0,14
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,3,0,0
MEMBER:'instr-sync',-1,0,128,4,4,0,0
MEMBER:'instr-rotate',-1,1,128,6,4,0,0
MEMBER:'instr-bond',-1,0,128,2,7,0,0
MEMBER:'instr-bond',-1,0,128,1,6,0,0
MEMBER:'instr-input',-1,1,128,1,7,0,0
MEMBER:'instr-input',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-sensor',0,0,32,2,5,0,15
MEMBER:'instr-sensor',180,0,32,4,5,0,14
MEMBER:'instr-bond',-1,1,32,3,5,0,0
MEMBER:'instr-arrow',180,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-bond',-1,0,32,2,6,0,0
MEMBER:'instr-input',-1,1,128,5,4,0,0
MEMBER:'instr-input',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',0,0,16,0,1,0,0
MEMBER:'instr-arrow',-90,0,16,0,5,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,0,5,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-input',-1,1,128,5,2,0,0
MEMBER:'instr-bond',-1,1,32,1,6,0,0
MEMBER:'instr-grab',-1,2,32,2,4,0,0
MEMBER:'instr-sync',-1,0,32,2,3,0,0
MEMBER:'instr-bond',-1,1,32,4,6,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-arrow',-90,0,16,7,5,0,0
MEMBER:'instr-toggle',0,0,32,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,9,4,0,0
MEMBER:'instr-arrow',180,0,16,9,2,0,0
MEMBER:'instr-arrow',90,0,16,4,4,0,0
MEMBER:'instr-input',-1,1,32,6,4,0,0
MEMBER:'instr-arrow',180,0,64,4,3,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-bond',-1,0,32,4,4,0,0
MEMBER:'instr-arrow',-90,0,16,3,7,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-grab',-1,1,32,4,3,0,0
MEMBER:'instr-arrow',180,0,16,4,7,0,0
MEMBER:'instr-rotate',-1,0,32,5,3,0,0
MEMBER:'instr-arrow',90,0,16,7,3,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-bond',-1,0,32,9,3,0,0
MEMBER:'instr-sensor',90,0,32,3,2,0,15
MEMBER:'instr-bond',-1,1,32,8,2,0,0
MEMBER:'instr-bond',-1,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,1,3,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-input',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-arrow',-90,0,64,2,2,0,0
MEMBER:'instr-bond',-1,1,32,5,4,0,0
MEMBER:'instr-output',-1,0,128,0,4,0,0
MEMBER:'instr-arrow',-90,0,16,2,2,0,0
MEMBER:'instr-output',-1,1,32,2,2,0,0
MEMBER:'instr-output',-1,1,128,2,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Ω-Pseudoethyne,Zig,1258-2-144,Ignorable pipe modifications
COMPONENT:'drag-advanced-reactor',11,7,''
MEMBER:'instr-start',-90,0,128,0,4,0,0
MEMBER:'instr-start',-90,0,32,0,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-sensor',-1,0,1,1,3,0,0
MEMBER:'instr-input',-1,0,128,0,3,0,0
MEMBER:'instr-grab',-1,2,32,4,4,0,0
MEMBER:'instr-bond',-1,0,32,1,6,0,0
MEMBER:'instr-arrow',90,0,16,2,2,0,0
MEMBER:'instr-bond',-1,0,32,2,3,0,0
MEMBER:'instr-grab',-1,2,128,5,3,0,0
MEMBER:'instr-sync',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-arrow',180,0,16,6,0,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-arrow',0,0,64,2,6,0,0
MEMBER:'instr-arrow',90,0,64,3,6,0,0
MEMBER:'instr-arrow',180,0,64,3,7,0,0
MEMBER:'instr-arrow',-90,0,64,1,7,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',90,0,64,2,4,0,0
MEMBER:'instr-toggle',0,0,128,3,6,0,0
MEMBER:'instr-arrow',-90,0,64,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,5,6,0,0
MEMBER:'instr-toggle',0,0,128,5,6,0,0
MEMBER:'instr-toggle',-90,0,128,5,5,0,0
MEMBER:'instr-arrow',0,0,64,5,5,0,0
MEMBER:'instr-arrow',-90,0,64,6,5,0,0
MEMBER:'instr-arrow',180,0,64,5,3,0,0
MEMBER:'instr-grab',-1,1,128,4,3,0,0
MEMBER:'instr-rotate',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,6,2,0,0
MEMBER:'instr-arrow',90,0,64,8,2,0,0
MEMBER:'instr-arrow',180,0,64,8,4,0,0
MEMBER:'instr-arrow',90,0,64,4,4,0,0
MEMBER:'instr-arrow',0,0,64,4,5,0,0
MEMBER:'instr-grab',-1,1,128,4,4,0,0
MEMBER:'instr-input',-1,1,128,4,5,0,0
MEMBER:'instr-bond',-1,0,128,5,4,0,0
MEMBER:'instr-grab',-1,1,128,1,3,0,0
MEMBER:'instr-bond',-1,1,128,2,4,0,0
MEMBER:'instr-bond',-1,0,128,2,5,0,0
MEMBER:'instr-bond',-1,1,128,2,6,0,0
MEMBER:'instr-input',-1,1,128,3,7,0,0
MEMBER:'instr-sync',-1,0,128,2,7,0,0
MEMBER:'instr-bond',-1,1,128,1,7,0,0
MEMBER:'instr-bond',-1,0,128,1,6,0,0
MEMBER:'instr-output',-1,0,128,1,5,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-sensor',90,0,128,1,0,0,6
MEMBER:'instr-toggle',180,0,128,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,4,2,0,0
MEMBER:'instr-arrow',180,0,64,4,0,0,0
MEMBER:'instr-arrow',-90,0,64,4,1,0,0
MEMBER:'instr-grab',-1,1,128,3,1,0,0
MEMBER:'instr-grab',-1,2,128,4,1,0,0
MEMBER:'instr-input',-1,0,128,2,0,0,0
MEMBER:'instr-grab',-1,1,128,0,1,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-rotate',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-sync',-1,0,128,1,2,0,0
MEMBER:'instr-grab',-1,2,128,6,6,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-bond',-1,0,128,8,3,0,0
MEMBER:'instr-input',-1,1,128,7,4,0,0
MEMBER:'instr-bond',-1,1,128,6,4,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-arrow',0,0,16,0,0,0,0
MEMBER:'instr-arrow',-90,0,16,3,0,0,0
MEMBER:'instr-toggle',90,0,32,3,0,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,5,0,0
MEMBER:'instr-arrow',-90,0,16,5,5,0,0
MEMBER:'instr-arrow',180,0,16,5,2,0,0
MEMBER:'instr-arrow',180,0,16,2,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,6,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-arrow',90,0,16,2,3,0,0
MEMBER:'instr-toggle',90,0,32,2,4,0,0
MEMBER:'instr-toggle',0,0,32,2,6,0,0
MEMBER:'instr-rotate',-1,1,32,4,6,0,0
MEMBER:'instr-grab',-1,1,32,6,6,0,0
MEMBER:'instr-arrow',0,0,16,6,6,0,0
MEMBER:'instr-arrow',90,0,16,6,7,0,0
MEMBER:'instr-toggle',-90,0,32,6,7,0,0
MEMBER:'instr-arrow',180,0,16,8,7,0,0
MEMBER:'instr-arrow',-90,0,16,7,6,0,0
MEMBER:'instr-arrow',0,0,16,7,2,0,0
MEMBER:'instr-arrow',90,0,16,8,2,0,0
MEMBER:'instr-toggle',-90,0,32,8,2,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-arrow',90,0,16,4,0,0,0
MEMBER:'instr-arrow',0,0,16,4,1,0,0
MEMBER:'instr-arrow',-90,0,16,6,1,0,0
MEMBER:'instr-sensor',180,0,32,4,0,0,6
MEMBER:'instr-grab',-1,1,32,4,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-output',-1,0,32,6,0,0,0
MEMBER:'instr-rotate',-1,1,32,5,1,0,0
MEMBER:'instr-bond',-1,0,32,7,3,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-sync',-1,0,32,7,4,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-input',-1,1,32,6,5,0,0
MEMBER:'instr-sync',-1,0,32,5,5,0,0
MEMBER:'instr-bond',-1,0,32,5,4,0,0
MEMBER:'instr-bond',-1,0,32,5,3,0,0
MEMBER:'instr-bond',-1,0,32,5,2,0,0
MEMBER:'instr-rotate',-1,1,32,4,2,0,0
MEMBER:'instr-bond',-1,1,32,3,2,0,0
MEMBER:'instr-bond',-1,1,32,1,3,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-arrow',90,0,16,2,5,0,0
MEMBER:'instr-rotate',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',90,0,16,4,4,0,0
MEMBER:'instr-arrow',180,0,16,4,5,0,0
MEMBER:'instr-arrow',0,0,16,2,4,0,0
MEMBER:'instr-grab',-1,1,32,3,5,0,0
MEMBER:'instr-bond',-1,1,32,3,4,0,0
MEMBER:'instr-output',-1,0,32,4,5,0,0
MEMBER:'instr-grab',-1,1,32,3,3,0,0
MEMBER:'instr-sync',-1,0,32,4,3,0,0
MEMBER:'instr-input',-1,1,32,8,3,0,0
MEMBER:'instr-sync',-1,0,32,8,4,0,0
MEMBER:'instr-bond',-1,0,32,8,5,0,0
MEMBER:'instr-bond',-1,0,32,8,7,0,0
MEMBER:'instr-sync',-1,0,128,5,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,6,0
PIPE:1,4,3
PIPE:1,3,3
ANNOTATION:0,1,-200,218,'1,2:0,6;1,1:0,201;1,3:0,1;2,1:0,1;0,1:0,1;1,0:0,1;\n0,1,1:1;1,0,0:1;1,2,0:1;1,1,1:1;1,1,0:3;\r0,3:0,6;1,1:0,6;0,1:0,201;0,2:0,201;\n0,1,1:2;0,2,0:1;0,1,0:1;\r1,2:0,201;0,0:0,6;0,1:0,201;1,1:0,6;\n0,0,0:2;1,1,0:2;0,1,1:2;\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-advanced-reactor',18,5,''
MEMBER:'instr-start',90,0,128,1,3,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'feature-bonder',-1,0,1,3,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-sensor',-1,0,1,3,5,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-grab',-1,2,128,7,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,5,0,0
MEMBER:'instr-sensor',-90,0,128,3,5,0,6
MEMBER:'instr-arrow',0,0,64,3,1,0,0
MEMBER:'instr-bond',-1,1,128,3,1,0,0
MEMBER:'instr-bond',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-arrow',90,0,64,1,2,0,0
MEMBER:'instr-arrow',180,0,64,7,4,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-arrow',90,0,64,1,4,0,0
MEMBER:'instr-toggle',180,0,128,7,2,0,0
MEMBER:'instr-output',-1,1,32,0,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,5,-2
PIPE:0,4,-2
PIPE:0,3,-2
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,0,-2
PIPE:0,-1,-2
PIPE:0,-2,-2
PIPE:0,-2,-1
PIPE:0,-2,0
PIPE:0,-2,1
PIPE:0,-1,1
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8''',
    r'''SOLUTION:Σ-Ethylene,Zig,2028-2-102,Cycles
COMPONENT:'drag-fusion-reactor',12,10,''
MEMBER:'instr-start',180,0,128,9,4,0,0
MEMBER:'instr-start',-90,0,32,0,6,0,0
MEMBER:'feature-bonder',-1,0,1,6,0,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,0,0,0
MEMBER:'feature-fuser',-1,0,1,1,1,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-fuse',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
MEMBER:'instr-fuse',-1,0,128,1,1,0,0
MEMBER:'instr-toggle',0,0,128,4,1,0,0
MEMBER:'instr-toggle',0,0,128,3,1,0,0
MEMBER:'instr-arrow',180,0,64,3,2,0,0
MEMBER:'instr-arrow',180,0,64,4,1,0,0
MEMBER:'instr-arrow',90,0,64,3,1,0,0
MEMBER:'instr-arrow',180,0,16,3,2,0,0
MEMBER:'instr-arrow',-90,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-arrow',90,0,16,3,1,0,0
MEMBER:'instr-toggle',0,0,32,3,1,0,0
MEMBER:'instr-toggle',0,0,32,4,1,0,0
MEMBER:'instr-arrow',180,0,16,4,1,0,0
MEMBER:'instr-arrow',0,0,64,2,0,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-fuse',-1,0,32,1,2,0,0
MEMBER:'instr-fuse',-1,0,32,1,1,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-sync',-1,0,128,5,2,0,0
MEMBER:'instr-grab',-1,2,128,5,1,0,0
MEMBER:'instr-arrow',90,0,64,5,1,0,0
MEMBER:'instr-arrow',180,0,64,5,3,0,0
MEMBER:'instr-arrow',-90,0,64,2,3,0,0
MEMBER:'instr-sync',-1,0,128,3,3,0,0
MEMBER:'instr-bond',-1,1,128,6,0,0,0
MEMBER:'instr-bond',-1,0,128,5,3,0,0
MEMBER:'instr-bond',-1,0,128,4,3,0,0
MEMBER:'instr-bond',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',90,0,64,6,0,0,0
MEMBER:'instr-rotate',-1,1,128,6,3,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-sync',-1,0,128,5,0,0,0
MEMBER:'instr-arrow',-90,0,64,3,5,0,0
MEMBER:'instr-sync',-1,0,128,3,5,0,0
MEMBER:'instr-bond',-1,0,128,3,4,0,0
MEMBER:'instr-toggle',0,0,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-arrow',180,0,64,7,4,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-input',-1,1,128,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,4,4,0,0
MEMBER:'instr-input',-1,0,128,8,4,0,0
MEMBER:'instr-sync',-1,0,32,5,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-grab',-1,1,32,3,5,0,0
MEMBER:'instr-toggle',180,0,32,4,4,0,0
MEMBER:'instr-arrow',-90,0,16,1,4,0,0
MEMBER:'instr-arrow',180,0,16,4,5,0,0
MEMBER:'instr-arrow',0,0,16,3,5,0,0
MEMBER:'instr-arrow',90,0,16,4,2,0,0
MEMBER:'instr-bond',-1,0,32,4,3,0,0
MEMBER:'instr-sync',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',-90,0,16,2,3,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-rotate',-1,1,32,6,2,0,0
MEMBER:'instr-arrow',0,0,16,2,0,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-bond',-1,0,32,6,0,0,0
MEMBER:'instr-arrow',90,0,16,7,0,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-rotate',-1,1,32,7,0,0,0
MEMBER:'instr-grab',-1,2,32,5,2,0,0
MEMBER:'instr-sync',-1,0,32,4,2,0,0
MEMBER:'instr-sync',-1,0,32,5,3,0,0
MEMBER:'instr-arrow',180,0,64,4,2,0,0
MEMBER:'instr-sync',-1,0,128,3,2,0,0
MEMBER:'instr-sync',-1,0,128,4,5,0,0
MEMBER:'instr-sync',-1,0,128,5,5,0,0
MEMBER:'instr-arrow',180,0,64,3,3,0,0
MEMBER:'instr-toggle',0,0,32,4,5,0,0
MEMBER:'instr-arrow',-90,0,16,8,5,0,0
MEMBER:'instr-output',-1,1,32,5,5,0,0
MEMBER:'instr-output',-1,0,32,3,4,0,0
MEMBER:'instr-arrow',180,0,16,8,1,0,0
MEMBER:'instr-sync',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',0,0,16,0,1,0,0
MEMBER:'instr-input',-1,0,32,1,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,7,0
PIPE:0,7,-1
PIPE:0,7,-2
PIPE:0,8,-2
PIPE:0,9,-2
PIPE:1,5,2
PIPE:1,5,3
PIPE:1,5,4
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-1,5
PIPE:1,-1,6
PIPE:1,-1,7
PIPE:1,0,7
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,120,-26,'2,0:0,1;0,0:0,1;1,1:0,6;1,0:0,6;0,1:0,1;2,1:0,1;\n1,0,1:1;0,1,1:1;0,0,1:1;1,1,1:1;1,0,0:2;\r\n\r\n\r'
COMPONENT:'drag-fusion-reactor',13,16,''
MEMBER:'instr-start',-90,0,128,2,3,0,0
MEMBER:'instr-start',180,0,32,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-fuser',-1,0,1,6,7,0,0
MEMBER:'instr-input',-1,1,32,3,5,0,0
MEMBER:'instr-grab',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,9,1,0,0
MEMBER:'instr-arrow',180,0,16,9,5,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-grab',-1,2,32,9,1,0,0
MEMBER:'instr-output',-1,0,32,9,2,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-sync',-1,0,32,5,5,0,0
MEMBER:'instr-arrow',90,0,64,8,1,0,0
MEMBER:'instr-sync',-1,0,128,3,1,0,0
MEMBER:'instr-grab',-1,2,128,8,5,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-output',-1,1,128,7,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,4,-1
PIPE:0,3,-1
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-3,-1
PIPE:0,-3,-2
PIPE:0,-3,-3
PIPE:0,-3,-4
PIPE:0,-2,-4
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,7,1
PIPE:1,7,0
PIPE:1,8,0
PIPE:1,9,0
ANNOTATION:0,1,-336,-149,'2,1:0,202;3,1:0,202;\n2,1,1:1;\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
''',
    r"""SOLUTION:Σ-Ethylene,gensek,2014-2-79,cloggy pipes
COMPONENT:'drag-ancient-input',5,10,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,6,1
COMPONENT:'drag-ancient-input',6,19,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,3,-1
PIPE:0,4,-1
PIPE:0,5,-1
PIPE:0,6,-1
COMPONENT:'drag-fusion-reactor',12,10,''
MEMBER:'instr-start',0,0,128,0,0,0,0
MEMBER:'instr-start',90,0,32,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-fuser',-1,0,1,3,1,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-arrow',-90,0,64,0,2,0,0
MEMBER:'instr-toggle',90,0,128,0,2,0,0
MEMBER:'instr-bond',-1,1,128,0,3,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,2,128,1,2,0,0
MEMBER:'instr-arrow',180,0,64,2,0,0,0
MEMBER:'instr-fuse',-1,0,128,2,1,0,0
MEMBER:'instr-bond',-1,0,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,6,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
MEMBER:'instr-toggle',0,0,128,3,0,0,0
MEMBER:'instr-arrow',-90,0,64,3,1,0,0
MEMBER:'instr-fuse',-1,0,128,3,1,0,0
MEMBER:'instr-sync',-1,0,128,3,2,0,0
MEMBER:'instr-sync',-1,0,128,3,5,0,0
MEMBER:'instr-arrow',180,0,64,4,0,0,0
MEMBER:'instr-toggle',90,0,128,4,0,0,0
MEMBER:'instr-grab',-1,1,128,4,1,0,0
MEMBER:'instr-arrow',180,0,64,4,2,0,0
MEMBER:'instr-grab',-1,1,128,4,5,0,0
MEMBER:'instr-rotate',-1,0,128,5,5,0,0
MEMBER:'instr-arrow',90,0,64,7,5,0,0
MEMBER:'instr-arrow',180,0,64,7,6,0,0
MEMBER:'instr-grab',-1,2,128,7,6,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-grab',-1,1,32,0,2,0,0
MEMBER:'instr-input',-1,0,32,0,3,0,0
MEMBER:'instr-arrow',-90,0,16,0,5,0,0
MEMBER:'instr-sync',-1,0,32,0,5,0,0
MEMBER:'instr-arrow',0,0,16,1,2,0,0
MEMBER:'instr-bond',-1,0,32,1,2,0,0
MEMBER:'instr-bond',-1,1,32,1,3,0,0
MEMBER:'instr-arrow',-90,0,16,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,4,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-bond',-1,0,32,2,2,0,0
MEMBER:'instr-arrow',-90,0,16,2,3,0,0
MEMBER:'instr-bond',-1,1,32,2,3,0,0
MEMBER:'instr-output',-1,1,32,2,4,0,0
MEMBER:'instr-rotate',-1,1,32,3,3,0,0
MEMBER:'instr-input',-1,0,32,3,4,0,0
MEMBER:'instr-arrow',90,0,16,4,2,0,0
MEMBER:'instr-toggle',0,0,32,4,2,0,0
MEMBER:'instr-arrow',180,0,16,4,3,0,0
MEMBER:'instr-rotate',-1,1,32,4,3,0,0
MEMBER:'instr-input',-1,1,32,4,4,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-toggle',0,0,32,5,2,0,0
MEMBER:'instr-sync',-1,0,32,5,3,0,0
MEMBER:'instr-arrow',180,0,16,5,4,0,0
MEMBER:'instr-grab',-1,2,32,5,4,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-output',-1,0,32,7,3,0,0
MEMBER:'instr-arrow',180,0,16,7,5,0,0
MEMBER:'instr-sync',-1,0,32,7,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,7,0
PIPE:0,7,-1
PIPE:0,7,-2
PIPE:0,8,-2
PIPE:0,9,-2
PIPE:1,5,2
PIPE:1,5,3
PIPE:1,5,4
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-1,5
PIPE:1,-1,6
PIPE:1,-1,7
PIPE:1,0,7
COMPONENT:'drag-fusion-reactor',13,16,''
MEMBER:'instr-start',180,0,128,5,3,0,0
MEMBER:'instr-start',90,0,32,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,0,0,0
MEMBER:'feature-bonder',-1,0,1,3,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-fuser',-1,0,1,8,7,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-grab',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-input',-1,0,128,4,3,0,0
MEMBER:'instr-rotate',-1,1,128,6,4,0,0
MEMBER:'instr-arrow',180,0,64,7,3,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-grab',-1,2,128,7,4,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-input',-1,1,32,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',0,0,16,1,7,0,0
MEMBER:'instr-output',-1,0,32,6,0,0,0
MEMBER:'instr-grab',-1,2,32,7,0,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-output',-1,1,32,8,3,0,0
MEMBER:'instr-arrow',-90,0,16,8,7,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,4,-1
PIPE:0,3,-1
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-3,-1
PIPE:0,-3,-2
PIPE:0,-3,-3
PIPE:0,-3,-4
PIPE:0,-2,-4
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,7,1
PIPE:1,7,0
PIPE:1,8,0
PIPE:1,9,0""",
    r'''SOLUTION:Moustachium 608,Zig,511-1-45,Input Island
COMPONENT:'drag-starter-reactor',2,0,''
MEMBER:'instr-start',0,0,128,1,4,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',-90,0,16,2,1,0,0
MEMBER:'instr-rotate',-1,1,32,2,0,0,0
MEMBER:'instr-arrow',90,0,16,3,0,0,0
MEMBER:'instr-arrow',180,0,16,3,2,0,0
MEMBER:'instr-bond',-1,0,32,2,2,0,0
MEMBER:'instr-sync',-1,0,32,0,1,0,0
MEMBER:'instr-rotate',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',-90,0,16,0,2,0,0
MEMBER:'instr-arrow',-90,0,64,3,7,0,0
MEMBER:'instr-arrow',0,0,64,2,7,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',-90,0,64,1,7,0,0
MEMBER:'instr-arrow',0,0,64,0,7,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-sync',-1,0,128,0,6,0,0
MEMBER:'instr-arrow',0,0,16,2,0,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
MEMBER:'instr-grab',-1,2,32,3,1,0,0
MEMBER:'instr-grab',-1,1,32,3,2,0,0
MEMBER:'instr-grab',-1,2,32,0,2,0,0
MEMBER:'instr-arrow',0,0,16,0,1,0,0
MEMBER:'instr-bond',-1,0,32,2,1,0,0
MEMBER:'instr-sync',-1,0,128,3,6,0,0
MEMBER:'instr-input',-1,0,128,3,4,0,0
MEMBER:'instr-sync',-1,0,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-input',-1,0,128,0,0,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-bond',-1,0,128,3,2,0,0
MEMBER:'instr-bond',-1,1,128,1,3,0,0
MEMBER:'instr-bond',-1,0,128,1,5,0,0
MEMBER:'instr-bond',-1,0,128,2,7,0,0
MEMBER:'instr-bond',-1,0,128,3,0,0,0
MEMBER:'instr-bond',-1,0,128,3,7,0,0
MEMBER:'instr-bond',-1,0,128,3,3,0,0
MEMBER:'instr-input',-1,0,32,3,0,0,0
MEMBER:'instr-arrow',-90,0,64,3,4,0,0
MEMBER:'instr-bond',-1,0,128,0,1,0,0
MEMBER:'instr-output',-1,0,128,1,2,0,0
MEMBER:'instr-sync',-1,0,128,2,0,0,0
MEMBER:'instr-bond',-1,0,128,0,3,0,0
MEMBER:'instr-bond',-1,0,128,0,4,0,0
MEMBER:'instr-input',-1,0,128,1,7,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:QT-1,Zig,15-1-14,Cycles
COMPONENT:'drag-quantum-reactor-x',2,0,''
MEMBER:'instr-start',90,0,128,0,0,0,0
MEMBER:'instr-start',90,0,32,0,2,0,0
MEMBER:'feature-tunnel',-1,0,1,1,1,0,0
MEMBER:'feature-tunnel',-1,0,1,7,5,0,0
MEMBER:'instr-swap',-1,0,32,3,3,0,0
MEMBER:'instr-arrow',0,0,16,0,3,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-swap',-1,0,128,0,3,0,0
MEMBER:'instr-swap',-1,0,32,0,3,0,0
MEMBER:'instr-swap',-1,0,128,3,3,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-output',-1,1,32,2,3,0,0
MEMBER:'instr-arrow',180,0,16,3,3,0,0
MEMBER:'instr-output',-1,1,32,1,3,0,0
MEMBER:'instr-arrow',180,0,64,3,3,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r"""SOLUTION:QT-4,Zig,510-1-30,Quantum walls + rotates
COMPONENT:'drag-quantum-reactor-s',2,0,''
MEMBER:'instr-start',180,0,128,6,5,0,0
MEMBER:'instr-start',180,0,32,9,6,0,0
MEMBER:'feature-tunnel',-1,0,1,1,5,0,0
MEMBER:'feature-tunnel',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-sensor',-1,0,1,1,4,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-bond',-1,0,32,6,5,0,0
MEMBER:'instr-grab',-1,1,32,8,5,0,0
MEMBER:'instr-arrow',90,0,16,8,5,0,0
MEMBER:'instr-rotate',-1,1,32,8,6,0,0
MEMBER:'instr-arrow',90,0,16,6,4,0,0
MEMBER:'instr-arrow',0,0,16,6,5,0,0
MEMBER:'instr-input',-1,1,128,5,5,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',90,0,64,4,4,0,0
MEMBER:'instr-sensor',-90,0,128,2,4,0,1
MEMBER:'instr-rotate',-1,1,128,2,3,0,0
MEMBER:'instr-swap',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',180,0,16,8,6,0,0
MEMBER:'instr-arrow',-90,0,16,7,6,0,0
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,4,7,0,0
MEMBER:'instr-swap',-1,0,128,1,5,0,0
MEMBER:'instr-arrow',-90,0,64,0,5,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-output',-1,1,128,1,6,0,0
MEMBER:'instr-arrow',-90,0,64,1,7,0,0
MEMBER:'instr-arrow',180,0,64,3,5,0,0
MEMBER:'instr-arrow',0,0,64,1,6,0,0
MEMBER:'instr-arrow',-90,0,64,3,6,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    r'''SOLUTION:Teleporters,Zig,1140-3-88,Cycles
COMPONENT:'drag-quantum-reactor',7,16,''
MEMBER:'instr-start',0,0,128,1,6,0,0
MEMBER:'instr-start',90,0,32,6,1,0,0
MEMBER:'feature-tunnel',-1,0,1,6,3,0,0
MEMBER:'feature-tunnel',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-sensor',-1,0,1,0,5,0,0
MEMBER:'instr-grab',-1,1,128,3,6,0,0
MEMBER:'instr-arrow',-90,0,64,4,6,0,0
MEMBER:'instr-input',-1,1,128,2,6,0,0
MEMBER:'instr-swap',-1,0,128,3,5,0,0
MEMBER:'instr-swap',-1,0,128,4,5,0,0
MEMBER:'instr-swap',-1,0,128,2,5,0,0
MEMBER:'instr-arrow',180,0,64,4,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-swap',-1,0,128,3,4,0,0
MEMBER:'instr-swap',-1,0,128,2,3,0,0
MEMBER:'instr-output',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',180,0,64,3,4,0,0
MEMBER:'instr-arrow',90,0,64,1,4,0,0
MEMBER:'instr-arrow',0,0,64,1,6,0,0
MEMBER:'instr-grab',-1,1,32,6,3,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-output',-1,1,32,7,7,0,0
MEMBER:'instr-arrow',0,0,16,6,7,0,0
MEMBER:'instr-arrow',-90,0,16,8,7,0,0
MEMBER:'instr-arrow',180,0,16,8,2,0,0
MEMBER:'instr-arrow',90,0,16,6,2,0,0
MEMBER:'instr-swap',-1,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,6,5,0,0
MEMBER:'instr-output',-1,0,32,6,6,0,0
MEMBER:'instr-output',-1,0,32,6,7,0,0
MEMBER:'instr-output',-1,0,32,8,5,0,0
MEMBER:'instr-swap',-1,0,32,8,4,0,0
MEMBER:'instr-swap',-1,0,32,8,3,0,0
MEMBER:'instr-output',-1,0,32,8,7,0,0
MEMBER:'instr-output',-1,0,32,8,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,5,4
PIPE:1,6,4
PIPE:1,7,4
PIPE:1,8,4
PIPE:1,9,4
PIPE:1,10,4
PIPE:1,11,4
PIPE:1,12,4
PIPE:1,13,4
PIPE:1,14,4
PIPE:1,15,4
PIPE:1,16,4
PIPE:1,17,4
PIPE:1,18,4
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,5,-2
ANNOTATION:0,1,-162,-219,'0,3:0,8;\n\r0,3:0,74;\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-qpipe-out',12,4,''
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
COMPONENT:'drag-quantum-reactor',18,3,''
MEMBER:'instr-start',180,0,128,8,4,0,0
MEMBER:'instr-start',180,0,32,6,7,0,0
MEMBER:'feature-tunnel',-1,0,1,0,3,0,0
MEMBER:'feature-tunnel',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-sensor',-1,0,1,9,7,0,0
MEMBER:'instr-grab',-1,1,128,5,3,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-bond',-1,0,128,6,3,0,0
MEMBER:'instr-arrow',90,0,64,7,3,0,0
MEMBER:'instr-arrow',180,0,64,7,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,4,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-bond',-1,0,32,7,3,0,0
MEMBER:'instr-input',-1,0,128,7,4,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-bond',-1,0,128,5,4,0,0
MEMBER:'instr-grab',-1,1,32,5,3,0,0
MEMBER:'instr-output',-1,0,32,8,3,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-arrow',180,0,16,9,7,0,0
MEMBER:'instr-arrow',90,0,16,9,3,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-swap',-1,0,32,5,2,0,0
MEMBER:'instr-swap',-1,0,32,0,4,0,0
MEMBER:'instr-swap',-1,0,32,4,7,0,0
MEMBER:'instr-swap',-1,0,32,9,5,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-quantum-reactor',13,12,''
MEMBER:'instr-start',0,0,128,5,0,0,0
MEMBER:'instr-start',180,0,32,8,0,0,0
MEMBER:'feature-tunnel',-1,0,1,0,7,0,0
MEMBER:'feature-tunnel',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-sensor',-1,0,1,9,5,0,0
MEMBER:'instr-input',-1,1,128,6,0,0,0
MEMBER:'instr-arrow',-90,0,64,6,6,0,0
MEMBER:'instr-swap',-1,0,32,6,6,0,0
MEMBER:'instr-arrow',-90,0,16,6,6,0,0
MEMBER:'instr-arrow',0,0,16,6,0,0,0
MEMBER:'instr-arrow',90,0,16,7,0,0,0
MEMBER:'instr-arrow',180,0,16,7,6,0,0
MEMBER:'instr-arrow',0,0,64,6,0,0,0
MEMBER:'instr-arrow',90,0,64,7,0,0,0
MEMBER:'instr-arrow',180,0,64,7,6,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
MEMBER:'instr-swap',-1,0,128,7,1,0,0
MEMBER:'instr-input',-1,1,128,7,2,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-output',-1,0,32,6,2,0,0
MEMBER:'instr-swap',-1,0,128,7,3,0,0
MEMBER:'instr-output',-1,1,32,6,1,0,0
MEMBER:'instr-input',-1,1,128,7,4,0,0
MEMBER:'instr-swap',-1,0,128,7,5,0,0
MEMBER:'instr-output',-1,1,32,6,0,0,0
MEMBER:'instr-input',-1,1,128,7,6,0,0
MEMBER:'instr-swap',-1,0,32,7,0,0,0
MEMBER:'instr-output',-1,1,32,7,1,0,0
MEMBER:'instr-input',-1,1,128,6,6,0,0
MEMBER:'instr-swap',-1,0,128,6,5,0,0
MEMBER:'instr-grab',-1,1,128,6,4,0,0
MEMBER:'instr-input',-1,1,128,7,0,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-output',-1,0,32,7,4,0,0
MEMBER:'instr-output',-1,1,32,7,6,0,0
MEMBER:'instr-swap',-1,0,32,7,5,0,0
MEMBER:'instr-input',-1,1,128,6,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,5,6
PIPE:1,6,6
PIPE:1,7,6
PIPE:1,8,6
PIPE:1,9,6
PIPE:1,10,6
PIPE:1,11,6
PIPE:1,12,6
ANNOTATION:0,1,160,-143,'0,3:0,74;\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
''',
    r'''SOLUTION:Precursor Compounds,Zig,8570-3-92,basic
COMPONENT:'drag-spaceship-input',1,9,''
PIPE:0,2,0
PIPE:0,2,1
COMPONENT:'drag-spaceship-input',4,19,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,2,-4
PIPE:0,2,-5
PIPE:0,2,-6
PIPE:0,3,-6
PIPE:0,4,-6
PIPE:0,5,-6
PIPE:0,6,-6
PIPE:0,7,-6
PIPE:0,8,-6
PIPE:0,9,-6
PIPE:0,10,-6
PIPE:0,11,-6
PIPE:0,12,-6
PIPE:0,13,-6
COMPONENT:'drag-quantum-reactor',4,9,''
MEMBER:'instr-start',-90,0,128,3,3,0,0
MEMBER:'instr-start',-90,0,32,9,7,0,0
MEMBER:'feature-tunnel',-1,0,1,2,6,0,0
MEMBER:'feature-tunnel',-1,0,1,8,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,0,6,0,0
MEMBER:'feature-bonder',-1,0,1,0,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-sensor',-1,0,1,8,4,0,0
MEMBER:'instr-grab',-1,1,128,3,1,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-grab',-1,1,128,0,0,0,0
MEMBER:'instr-input',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,1,128,1,0,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
MEMBER:'instr-rotate',-1,1,128,3,0,0,0
MEMBER:'instr-sync',-1,0,128,2,3,0,0
MEMBER:'instr-sync',-1,0,128,2,4,0,0
MEMBER:'instr-sync',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',180,0,64,2,4,0,0
MEMBER:'instr-arrow',90,0,64,1,4,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-arrow',90,0,64,4,5,0,0
MEMBER:'instr-sync',-1,0,128,1,5,0,0
MEMBER:'instr-sync',-1,0,128,4,6,0,0
MEMBER:'instr-sync',-1,0,128,3,6,0,0
MEMBER:'instr-sync',-1,0,128,2,2,0,0
MEMBER:'instr-sync',-1,0,32,9,6,0,0
MEMBER:'instr-swap',-1,0,32,8,6,0,0
MEMBER:'instr-grab',-1,1,32,8,5,0,0
MEMBER:'instr-sensor',-90,0,32,8,4,0,201
MEMBER:'instr-output',-1,1,32,9,5,0,0
MEMBER:'instr-arrow',90,0,16,9,3,0,0
MEMBER:'instr-output',-1,0,32,9,3,0,0
MEMBER:'instr-grab',-1,2,32,8,3,0,0
MEMBER:'instr-arrow',90,0,16,9,4,0,0
MEMBER:'instr-arrow',180,0,16,9,6,0,0
MEMBER:'instr-arrow',-90,0,16,8,6,0,0
MEMBER:'instr-grab',-1,2,32,9,4,0,0
MEMBER:'instr-arrow',0,0,16,8,3,0,0
MEMBER:'instr-arrow',0,0,16,8,4,0,0
MEMBER:'instr-arrow',180,0,64,4,6,0,0
MEMBER:'instr-rotate',-1,0,128,2,5,0,0
MEMBER:'instr-rotate',-1,0,128,3,5,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',-90,0,64,0,6,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-arrow',-90,0,64,3,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,5,9
PIPE:1,6,9
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,13,2
PIPE:0,13,3
ANNOTATION:0,1,117,-266,'2,3:0,201;\n\r\n\r\n\r'
ANNOTATION:1,1,242,-246,'3,0:0,6;\n\r\n\r\n\r'
COMPONENT:'drag-quantum-reactor',11,17,''
MEMBER:'instr-start',-90,0,128,5,5,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'feature-tunnel',-1,0,1,3,0,0,0
MEMBER:'feature-tunnel',-1,0,1,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,9,2,0,0
MEMBER:'feature-sensor',-1,0,1,0,7,0,0
MEMBER:'instr-input',-1,0,128,5,4,0,0
MEMBER:'instr-swap',-1,0,128,5,3,0,0
MEMBER:'instr-grab',-1,1,128,5,2,0,0
MEMBER:'instr-bond',-1,0,128,6,2,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-arrow',90,0,64,9,2,0,0
MEMBER:'instr-arrow',180,0,64,9,4,0,0
MEMBER:'instr-arrow',0,0,64,5,2,0,0
MEMBER:'instr-grab',-1,1,128,9,2,0,0
MEMBER:'instr-grab',-1,2,128,9,3,0,0
MEMBER:'instr-grab',-1,1,128,9,4,0,0
MEMBER:'instr-rotate',-1,0,128,8,4,0,0
MEMBER:'instr-bond',-1,0,128,6,4,0,0
MEMBER:'instr-arrow',90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,5,6,0,0
MEMBER:'instr-grab',-1,2,128,6,6,0,0
MEMBER:'instr-output',-1,1,128,5,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,9,2
PIPE:1,10,2
PIPE:1,11,2
COMPONENT:'drag-quantum-reactor',18,11,''
MEMBER:'instr-start',0,0,128,2,4,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-tunnel',-1,0,1,2,3,0,0
MEMBER:'feature-tunnel',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-sensor',-1,0,1,7,5,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,3,4,0,0
MEMBER:'instr-grab',-1,2,128,7,4,0,0
MEMBER:'instr-grab',-1,1,128,5,4,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',90,0,64,8,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,5,0,0
MEMBER:'instr-swap',-1,0,128,4,4,0,0
MEMBER:'instr-grab',-1,1,128,8,4,0,0
MEMBER:'instr-rotate',-1,0,128,8,5,0,0
MEMBER:'instr-grab',-1,2,128,7,5,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-sensor',180,0,128,3,5,0,201
MEMBER:'instr-arrow',0,0,64,5,6,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-swap',-1,0,128,1,3,0,0
MEMBER:'instr-input',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,6,6,0,0
MEMBER:'instr-grab',-1,2,128,2,3,0,0
MEMBER:'instr-arrow',0,0,64,6,2,0,0
MEMBER:'instr-arrow',90,0,64,5,3,0,0
MEMBER:'instr-swap',-1,0,128,3,3,0,0
MEMBER:'instr-grab',-1,1,128,6,2,0,0
MEMBER:'instr-arrow',90,0,64,7,2,0,0
MEMBER:'instr-arrow',180,0,64,7,7,0,0
MEMBER:'instr-arrow',-90,0,64,4,7,0,0
MEMBER:'instr-sensor',180,0,128,4,7,0,1
MEMBER:'instr-arrow',0,0,64,4,3,0,0
MEMBER:'instr-arrow',-90,0,64,3,7,0,0
MEMBER:'instr-output',-1,1,128,3,7,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Tunnels I,Zig,15-1-20,Cycles
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,3,0,0,0
MEMBER:'instr-start',-90,0,32,1,3,0,0
MEMBER:'feature-tunnel',-1,0,1,2,1,0,0
MEMBER:'feature-tunnel',-1,0,1,8,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-swap',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',180,0,16,3,2,0,0
MEMBER:'instr-arrow',90,0,16,3,1,0,0
MEMBER:'instr-arrow',-90,0,16,1,2,0,0
MEMBER:'instr-arrow',180,0,64,3,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
MEMBER:'instr-output',-1,0,128,3,2,0,0
MEMBER:'instr-arrow',90,0,64,3,1,0,0
MEMBER:'instr-output',-1,0,32,2,1,0,0
MEMBER:'instr-swap',-1,0,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-swap',-1,0,32,3,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-output',-1,0,32,3,2,0,0
MEMBER:'instr-output',-1,0,32,2,2,0,0
MEMBER:'instr-swap',-1,0,128,2,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    # Thetane
    r'''SOLUTION:Θne,Zig,100-1-68,Cycles
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,2,1,0,0
MEMBER:'instr-start',0,0,32,0,1,0,0
MEMBER:'feature-bonder',-1,0,1,8,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-sensor',-1,0,1,7,4,0,0
MEMBER:'feature-splitter',-1,0,1,6,1,0,0
MEMBER:'feature-fuser',-1,0,1,8,1,0,0
MEMBER:'instr-grab',-1,1,32,7,1,0,0
MEMBER:'instr-arrow',90,0,16,8,1,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-arrow',-90,0,16,7,2,0,0
MEMBER:'instr-arrow',180,0,16,8,2,0,0
MEMBER:'instr-arrow',0,0,16,7,1,0,0
MEMBER:'instr-sensor',-90,0,32,8,1,0,3
MEMBER:'instr-grab',-1,1,128,7,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-grab',-1,0,32,6,1,0,0
MEMBER:'instr-grab',-1,2,128,9,1,0,0
MEMBER:'instr-arrow',-90,0,64,9,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-split',-1,0,128,6,1,0,0
MEMBER:'instr-split',-1,0,128,8,1,0,0
MEMBER:'instr-fuse',-1,0,128,9,0,0,0
MEMBER:'instr-fuse',-1,0,128,5,4,0,0
MEMBER:'instr-arrow',90,0,16,9,0,0,0
MEMBER:'instr-arrow',90,0,16,5,0,0,0
MEMBER:'instr-arrow',0,0,16,5,1,0,0
MEMBER:'instr-grab',-1,1,128,5,2,0,0
MEMBER:'instr-fuse',-1,0,32,9,2,0,0
MEMBER:'instr-grab',-1,0,32,9,1,0,0
MEMBER:'instr-rotate',-1,1,128,5,5,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-fuse',-1,0,32,9,3,0,0
MEMBER:'instr-arrow',-90,0,64,7,7,0,0
MEMBER:'instr-output',-1,0,128,7,7,0,0
MEMBER:'instr-arrow',-90,0,16,9,3,0,0
MEMBER:'instr-toggle',180,0,32,9,0,0,0
MEMBER:'instr-sensor',0,0,32,8,0,0,25
MEMBER:'instr-arrow',0,0,64,7,3,0,0
MEMBER:'instr-arrow',-90,0,64,8,3,0,0
MEMBER:'instr-bond',-1,0,32,8,2,0,0
MEMBER:'instr-split',-1,0,128,7,2,0,0
MEMBER:'instr-toggle',180,0,128,8,3,0,0
MEMBER:'instr-arrow',90,0,64,5,0,0,0
MEMBER:'instr-toggle',90,0,32,6,0,0,0
MEMBER:'instr-split',-1,0,128,7,0,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-split',-1,0,128,5,1,0,0
MEMBER:'instr-arrow',180,0,64,9,0,0,0
MEMBER:'instr-arrow',180,0,64,7,0,0,0
MEMBER:'instr-toggle',90,0,128,8,0,0,0
MEMBER:'instr-toggle',90,0,128,6,0,0,0
MEMBER:'instr-output',-1,0,32,5,3,0,0
MEMBER:'instr-output',-1,0,32,4,2,0,0
MEMBER:'instr-toggle',0,0,128,5,7,0,0
MEMBER:'instr-arrow',-90,0,16,4,3,0,0
MEMBER:'instr-grab',-1,1,32,4,3,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,4,4,0,0
MEMBER:'instr-bond',-1,1,128,5,3,0,0
MEMBER:'instr-sync',-1,0,32,4,1,0,0
MEMBER:'instr-arrow',0,0,16,4,1,0,0
MEMBER:'instr-toggle',-90,0,128,7,3,0,0
MEMBER:'instr-sync',-1,0,128,0,1,0,0
MEMBER:'instr-sync',-1,0,128,6,3,0,0
MEMBER:'instr-split',-1,0,128,4,4,0,0
MEMBER:'instr-arrow',0,0,64,4,1,0,0
MEMBER:'instr-toggle',180,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,5,2,0,0
MEMBER:'instr-output',-1,0,32,3,2,0,0
MEMBER:'instr-split',-1,0,128,0,4,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-arrow',90,0,64,0,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r"""SOLUTION:The Gold Standard,12345ieee,800-1-48
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,0,0,0,0
MEMBER:'instr-start',-90,0,32,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-splitter',-1,0,1,5,1,0,0
MEMBER:'feature-fuser',-1,0,1,5,2,0,0
MEMBER:'instr-input',-1,1,128,0,1,0,0
MEMBER:'instr-grab',-1,0,32,1,5,0,0
MEMBER:'instr-bond',-1,0,32,2,1,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-split',-1,0,128,5,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,1,128,6,1,0,0
MEMBER:'instr-toggle',0,0,128,5,3,0,0
MEMBER:'instr-toggle',90,0,128,6,3,0,0
MEMBER:'instr-arrow',0,0,64,5,2,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-toggle',90,0,128,5,2,0,0
MEMBER:'instr-grab',-1,1,32,6,1,0,0
MEMBER:'instr-arrow',90,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,64,5,1,0,0
MEMBER:'instr-arrow',-90,0,64,6,3,0,0
MEMBER:'instr-arrow',-90,0,64,5,3,0,0
MEMBER:'instr-arrow',0,0,64,6,4,0,0
MEMBER:'instr-input',-1,0,32,3,1,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,6,2,0,0
MEMBER:'instr-fuse',-1,0,32,7,7,0,0
MEMBER:'instr-fuse',-1,0,128,7,4,0,0
MEMBER:'instr-fuse',-1,0,32,9,3,0,0
MEMBER:'instr-fuse',-1,0,32,7,1,0,0
MEMBER:'instr-split',-1,0,32,5,1,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-grab',-1,1,128,7,2,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-fuse',-1,0,32,2,2,0,0
MEMBER:'instr-output',-1,0,32,3,2,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-grab',-1,1,32,5,2,0,0
MEMBER:'instr-toggle',90,0,32,4,2,0,0
MEMBER:'instr-arrow',180,0,16,9,2,0,0
MEMBER:'instr-fuse',-1,0,32,4,4,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-bond',-1,1,32,7,4,0,0
MEMBER:'instr-output',-1,1,32,7,5,0,0
MEMBER:'instr-grab',-1,2,32,5,4,0,0
MEMBER:'instr-arrow',0,0,16,7,7,0,0
MEMBER:'instr-arrow',-90,0,16,9,7,0,0
MEMBER:'instr-arrow',90,0,16,7,4,0,0
MEMBER:'instr-toggle',-90,0,32,9,2,0,0
MEMBER:'instr-arrow',180,0,16,9,1,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    # Quotes in level name due to the comma
    r"""SOLUTION:'1,3-Dimetoxibencene',andy,922-1-27,s
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,8,4,0,0
MEMBER:'instr-start',0,0,32,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,0,4,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-fuser',-1,0,1,2,4,0,0
MEMBER:'instr-bond',-1,0,32,9,7,0,0
MEMBER:'instr-rotate',-1,0,128,4,2,0,0
MEMBER:'instr-input',-1,0,128,3,0,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
MEMBER:'instr-grab',-1,1,128,2,0,0,0
MEMBER:'instr-arrow',90,0,64,2,0,0,0
MEMBER:'instr-fuse',-1,0,128,2,3,0,0
MEMBER:'instr-fuse',-1,0,128,2,4,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',180,0,64,2,6,0,0
MEMBER:'instr-grab',-1,0,128,3,4,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-output',-1,0,128,8,6,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-toggle',0,0,128,3,2,0,0
MEMBER:'instr-grab',-1,1,128,7,5,0,0
MEMBER:'instr-rotate',-1,0,128,3,5,0,0
MEMBER:'instr-arrow',90,0,64,8,2,0,0
MEMBER:'instr-input',-1,1,128,3,6,0,0
MEMBER:'instr-grab',-1,2,128,1,3,0,0
MEMBER:'instr-arrow',90,0,64,1,3,0,0
MEMBER:'instr-grab',-1,1,128,0,5,0,0
MEMBER:'instr-arrow',-90,0,64,0,6,0,0
MEMBER:'instr-arrow',-90,0,64,3,5,0,0
MEMBER:'instr-toggle',180,0,128,8,5,0,0
MEMBER:'instr-arrow',180,0,64,8,6,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    # Valid solution that consists of only a solution line, also a fun performance test
    r'''SOLUTION:Fastest Puzzle,Zig,1-0-0,Fastest solution''',
    # 2020 Tournament level with a comma in the name and that uses pass-through counters.
    # Solution also includes moving a molecule that is held by both waldos
    r'''SOLUTION:Suddenly, Welding?,anningmay,3199-3-162,anningmay: 3R - 4 cycle save
COMPONENT:'drag-arbitrary-input',2,9,''
PIPE:0,2,1
COMPONENT:'drag-arbitrary-input',2,17,''
PIPE:0,2,1
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,2,-4
PIPE:0,2,-5
PIPE:0,2,-6
PIPE:0,2,-7
PIPE:0,2,-8
COMPONENT:'drag-arbitrary-input',5,5,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,5,3
PIPE:0,6,3
PIPE:0,7,3
PIPE:0,8,3
COMPONENT:'freeform-custom-reactor-2',14,7,''
MEMBER:'instr-start',90,0,128,2,2,0,0
MEMBER:'instr-start',180,0,32,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,0,7,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-bonder',-1,0,1,0,5,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,3,6,0,0
MEMBER:'feature-bonder',-1,0,1,2,7,0,0
MEMBER:'feature-bonder',-1,0,1,4,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,6,0,0
MEMBER:'feature-splitter',-1,0,1,7,4,0,0
MEMBER:'feature-fuser',-1,0,1,3,4,0,0
MEMBER:'instr-sync',-1,0,128,2,4,0,0
MEMBER:'instr-grab',-1,1,128,3,4,0,0
MEMBER:'instr-grab',-1,0,128,4,4,0,0
MEMBER:'instr-arrow',90,0,64,5,4,0,0
MEMBER:'instr-arrow',180,0,64,5,5,0,0
MEMBER:'instr-arrow',-90,0,64,4,5,0,0
MEMBER:'instr-arrow',0,0,64,4,4,0,0
MEMBER:'instr-toggle',0,0,128,5,4,0,0
MEMBER:'instr-input',-1,1,128,5,5,0,0
MEMBER:'instr-input',-1,1,128,4,5,0,0
MEMBER:'instr-sync',-1,0,32,4,2,0,0
MEMBER:'instr-fuse',-1,0,32,1,4,0,0
MEMBER:'instr-fuse',-1,0,32,1,3,0,0
MEMBER:'instr-arrow',90,0,16,1,2,0,0
MEMBER:'instr-grab',-1,2,128,7,4,0,0
MEMBER:'instr-grab',-1,1,32,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-fuse',-1,0,32,3,5,0,0
MEMBER:'instr-arrow',-90,0,16,3,5,0,0
MEMBER:'instr-fuse',-1,0,32,3,4,0,0
MEMBER:'instr-arrow',180,0,16,3,2,0,0
MEMBER:'instr-arrow',-90,0,64,8,4,0,0
MEMBER:'instr-split',-1,0,128,8,4,0,0
MEMBER:'instr-output',-1,1,128,8,3,0,0
MEMBER:'instr-fuse',-1,0,32,2,5,0,0
MEMBER:'instr-arrow',180,0,16,5,2,0,0
MEMBER:'instr-toggle',0,0,32,3,3,0,0
MEMBER:'instr-fuse',-1,0,32,5,3,0,0
MEMBER:'instr-fuse',-1,0,32,4,3,0,0
MEMBER:'instr-arrow',-90,0,16,5,3,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-arrow',90,0,64,5,1,0,0
MEMBER:'instr-toggle',180,0,128,8,2,0,0
MEMBER:'instr-input',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-1,5
PIPE:1,-1,6
PIPE:1,-1,7
PIPE:1,-1,8
PIPE:1,-1,9
PIPE:1,-1,10
PIPE:1,-1,11
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'freeform-custom-reactor-2',17,12,''
MEMBER:'instr-start',180,0,128,3,2,0,0
MEMBER:'instr-start',180,0,32,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-splitter',-1,0,1,0,0,0,0
MEMBER:'feature-fuser',-1,0,1,0,7,0,0
MEMBER:'instr-grab',-1,1,128,0,5,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-bond',-1,1,128,1,5,0,0
MEMBER:'instr-bond',-1,1,128,2,5,0,0
MEMBER:'instr-bond',-1,1,128,3,5,0,0
MEMBER:'instr-bond',-1,1,128,5,5,0,0
MEMBER:'instr-grab',-1,2,128,4,5,0,0
MEMBER:'instr-input',-1,1,128,0,2,0,0
MEMBER:'instr-arrow',-90,0,64,8,5,0,0
MEMBER:'instr-grab',-1,0,128,7,4,0,0
MEMBER:'instr-arrow',180,0,64,8,4,0,0
MEMBER:'instr-rotate',-1,0,128,6,4,0,0
MEMBER:'instr-rotate',-1,0,128,5,4,0,0
MEMBER:'instr-bond',-1,0,128,4,4,0,0
MEMBER:'instr-bond',-1,0,128,3,4,0,0
MEMBER:'instr-bond',-1,0,128,2,4,0,0
MEMBER:'instr-bond',-1,0,128,1,4,0,0
MEMBER:'instr-sync',-1,0,128,8,4,0,0
MEMBER:'instr-sync',-1,0,128,8,5,0,0
MEMBER:'instr-sync',-1,0,32,7,6,0,0
MEMBER:'instr-grab',-1,2,32,6,6,0,0
MEMBER:'instr-grab',-1,1,32,5,6,0,0
MEMBER:'instr-rotate',-1,1,32,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,6,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-rotate',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',90,0,16,2,5,0,0
MEMBER:'instr-toggle',0,0,32,2,6,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-arrow',0,0,64,1,0,0,0
MEMBER:'instr-grab',-1,2,128,1,0,0,0
MEMBER:'instr-grab',-1,1,128,2,0,0,0
MEMBER:'instr-arrow',90,0,64,7,0,0,0
MEMBER:'instr-bond',-1,1,128,7,0,0,0
MEMBER:'instr-bond',-1,1,128,7,1,0,0
MEMBER:'instr-bond',-1,1,128,7,2,0,0
MEMBER:'instr-bond',-1,1,128,7,3,0,0
MEMBER:'instr-output',-1,1,128,7,5,0,0
MEMBER:'instr-arrow',180,0,64,7,7,0,0
MEMBER:'instr-arrow',-90,0,64,6,7,0,0
MEMBER:'instr-grab',-1,1,128,6,6,0,0
MEMBER:'instr-arrow',0,0,64,6,6,0,0
MEMBER:'instr-grab',-1,2,128,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,9,6,0,0
MEMBER:'instr-bond',-1,0,128,8,6,0,0
MEMBER:'instr-bond',-1,0,128,9,5,0,0
MEMBER:'instr-bond',-1,0,128,9,4,0,0
MEMBER:'instr-grab',-1,0,128,9,3,0,0
MEMBER:'instr-bond',-1,0,128,9,2,0,0
MEMBER:'instr-arrow',180,0,64,9,2,0,0
MEMBER:'instr-output',-1,0,128,8,2,0,0
MEMBER:'instr-arrow',90,0,64,0,2,0,0
MEMBER:'instr-grab',-1,1,128,9,6,0,0
MEMBER:'instr-arrow',180,0,16,8,6,0,0
MEMBER:'instr-sync',-1,0,32,8,6,0,0
MEMBER:'instr-sync',-1,0,128,2,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,5,-2
PIPE:0,6,-2
PIPE:0,7,-2
PIPE:0,8,-2
PIPE:1,5,2
PIPE:1,5,3
PIPE:1,5,4
PIPE:1,5,5
PIPE:1,5,6
PIPE:1,6,6
PIPE:1,7,6
PIPE:1,8,6
COMPONENT:'freeform-custom-reactor-1',5,8,''
MEMBER:'instr-start',0,0,32,3,3,0,0
MEMBER:'instr-start',180,0,128,8,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,2,0,0
MEMBER:'feature-sensor',-1,0,1,9,4,0,0
MEMBER:'feature-sensor',-1,0,1,0,0,0,0
MEMBER:'feature-tunnel',-1,0,1,2,5,0,0
MEMBER:'feature-tunnel',-1,0,1,9,0,0,0
MEMBER:'instr-arrow',90,0,64,1,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-arrow',180,0,64,3,4,0,0
MEMBER:'instr-swap',-1,0,128,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,6,0,0
MEMBER:'instr-swap',-1,0,128,3,5,0,0
MEMBER:'instr-swap',-1,0,128,2,6,0,0
MEMBER:'instr-swap',-1,0,128,3,6,0,0
MEMBER:'instr-output',-1,0,32,6,5,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-output',-1,0,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,1,5,0,0
MEMBER:'instr-output',-1,0,32,1,5,0,0
MEMBER:'instr-output',-1,0,32,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,3,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-bond',-1,0,128,4,3,0,0
MEMBER:'instr-bond',-1,1,128,1,3,0,0
MEMBER:'instr-toggle',90,0,32,4,3,0,0
MEMBER:'instr-output',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,4,3,0,0
MEMBER:'instr-bond',-1,0,128,4,2,0,0
MEMBER:'instr-arrow',0,0,64,4,2,0,0
MEMBER:'instr-grab',-1,2,128,5,2,0,0
MEMBER:'instr-bond',-1,0,32,5,7,0,0
MEMBER:'instr-grab',-1,2,32,6,7,0,0
MEMBER:'instr-arrow',0,0,16,5,7,0,0
MEMBER:'instr-arrow',-90,0,16,9,7,0,0
MEMBER:'instr-arrow',180,0,16,9,5,0,0
MEMBER:'instr-arrow',90,0,64,9,2,0,0
MEMBER:'instr-arrow',180,0,64,9,5,0,0
MEMBER:'instr-toggle',90,0,32,5,3,0,0
MEMBER:'instr-rotate',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',-90,0,16,6,3,0,0
MEMBER:'instr-rotate',-1,0,32,6,0,0,0
MEMBER:'instr-arrow',180,0,16,6,0,0,0
MEMBER:'instr-toggle',-90,0,128,9,2,0,0
MEMBER:'instr-grab',-1,2,32,5,0,0,0
MEMBER:'instr-arrow',180,0,64,9,1,0,0
MEMBER:'instr-arrow',90,0,64,5,1,0,0
MEMBER:'instr-grab',-1,1,128,5,3,0,0
MEMBER:'instr-bond',-1,0,32,5,4,0,0
MEMBER:'instr-bond',-1,0,32,5,5,0,0
MEMBER:'instr-bond',-1,0,32,5,6,0,0
MEMBER:'instr-arrow',-90,0,64,5,7,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-arrow',90,0,16,5,4,0,0
MEMBER:'instr-arrow',90,0,16,3,0,0,0
MEMBER:'instr-arrow',0,0,16,3,4,0,0
MEMBER:'instr-arrow',90,0,64,9,4,0,0
MEMBER:'instr-toggle',0,0,128,5,4,0,0
MEMBER:'instr-sensor',-90,0,32,9,5,0,26
MEMBER:'instr-arrow',0,0,16,4,3,0,0
MEMBER:'instr-arrow',0,0,64,1,6,0,0
MEMBER:'instr-input',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-toggle',-90,0,32,4,5,0,0
MEMBER:'instr-grab',-1,1,32,9,4,0,0
MEMBER:'instr-rotate',-1,1,32,9,3,0,0
MEMBER:'instr-grab',-1,2,32,9,2,0,0
MEMBER:'instr-arrow',180,0,16,9,2,0,0
MEMBER:'instr-grab',-1,1,32,8,2,0,0
MEMBER:'instr-arrow',90,0,16,8,2,0,0
MEMBER:'instr-grab',-1,2,32,8,4,0,0
MEMBER:'instr-arrow',0,0,16,8,7,0,0
MEMBER:'instr-output',-1,1,32,8,6,0,0
MEMBER:'instr-sync',-1,0,32,7,5,0,0
MEMBER:'instr-sync',-1,0,128,4,5,0,0
MEMBER:'instr-input',-1,1,32,7,7,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,5,6
PIPE:1,6,6
PIPE:1,7,6
PIPE:1,8,6
ANNOTATION:0,0,0,0,'3,0:0,8;\n\r3,0:0,20;\n\r\n\r'
ANNOTATION:1,0,0,0,'3,0:0,8;\n\r3,0:0,20;\n\r\n\r'
''',
    # Useful test for fusing into noble elements and breaking bonds correctly
    r'''SOLUTION:Suddenly, Welding?,Astronelson,2587-3-100,Astronelson: Schedu-Weld
COMPONENT:'drag-arbitrary-input',5,5,''
PIPE:0,2,1
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-3,-1
PIPE:0,-4,-1
PIPE:0,-5,-1
PIPE:0,-5,0
PIPE:0,-5,1
PIPE:0,-5,2
PIPE:0,-5,3
PIPE:0,-5,4
PIPE:0,-5,5
PIPE:0,-5,6
PIPE:0,-5,7
PIPE:0,-5,8
PIPE:0,-4,8
PIPE:0,-3,8
PIPE:0,-2,8
COMPONENT:'drag-arbitrary-input',2,9,''
PIPE:0,2,1
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-1,0
PIPE:0,-1,1
PIPE:0,-1,2
PIPE:0,-1,3
PIPE:0,-1,4
PIPE:0,-1,5
PIPE:0,0,5
PIPE:0,1,5
COMPONENT:'drag-arbitrary-input',2,17,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,6,0
PIPE:0,6,-1
PIPE:0,6,-2
COMPONENT:'freeform-custom-reactor-2',9,13,''
MEMBER:'instr-start',0,0,128,2,0,0,0
MEMBER:'instr-start',180,0,32,8,0,0,0
MEMBER:'feature-bonder',-1,0,1,4,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,0,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,0,0,0
MEMBER:'feature-splitter',-1,0,1,8,7,0,0
MEMBER:'feature-fuser',-1,0,1,6,7,0,0
MEMBER:'instr-input',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-bond',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,0,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-arrow',0,0,64,3,3,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-rotate',-1,0,128,3,3,0,0
MEMBER:'instr-toggle',90,0,128,3,0,0,0
MEMBER:'instr-rotate',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,2,128,4,4,0,0
MEMBER:'instr-grab',-1,2,128,4,1,0,0
MEMBER:'instr-grab',-1,1,32,4,2,0,0
MEMBER:'instr-bond',-1,0,32,4,1,0,0
MEMBER:'instr-bond',-1,0,32,4,3,0,0
MEMBER:'instr-grab',-1,2,32,5,2,0,0
MEMBER:'instr-arrow',90,0,64,4,3,0,0
MEMBER:'instr-arrow',90,0,64,4,0,0,0
MEMBER:'instr-arrow',180,0,64,4,5,0,0
MEMBER:'instr-grab',-1,1,32,8,4,0,0
MEMBER:'instr-grab',-1,2,32,9,3,0,0
MEMBER:'instr-arrow',-90,0,16,5,4,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-arrow',-90,0,16,9,4,0,0
MEMBER:'instr-arrow',0,0,16,0,0,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-toggle',180,0,32,9,0,0,0
MEMBER:'instr-toggle',90,0,32,4,0,0,0
MEMBER:'instr-output',-1,0,32,9,2,0,0
MEMBER:'instr-toggle',0,0,32,5,4,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'freeform-custom-reactor-2',4,12,''
MEMBER:'instr-start',180,0,32,5,7,0,0
MEMBER:'instr-start',180,0,128,8,2,0,0
MEMBER:'feature-bonder',-1,0,1,0,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,2,0,0,0
MEMBER:'feature-bonder',-1,0,1,3,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,0,0,0
MEMBER:'feature-bonder',-1,0,1,7,0,0,0
MEMBER:'feature-bonder',-1,0,1,8,0,0,0
MEMBER:'feature-bonder',-1,0,1,9,0,0,0
MEMBER:'feature-splitter',-1,0,1,6,3,0,0
MEMBER:'feature-fuser',-1,0,1,4,3,0,0
MEMBER:'instr-input',-1,1,32,3,7,0,0
MEMBER:'instr-arrow',-90,0,16,1,7,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-rotate',-1,0,32,1,4,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-grab',-1,1,128,1,2,0,0
MEMBER:'instr-arrow',90,0,64,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-fuse',-1,0,32,4,4,0,0
MEMBER:'instr-arrow',90,0,16,5,4,0,0
MEMBER:'instr-rotate',-1,1,32,5,4,0,0
MEMBER:'instr-fuse',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',180,0,16,5,5,0,0
MEMBER:'instr-arrow',-90,0,16,3,5,0,0
MEMBER:'instr-arrow',0,0,16,3,2,0,0
MEMBER:'instr-fuse',-1,0,32,3,3,0,0
MEMBER:'instr-fuse',-1,0,32,4,2,0,0
MEMBER:'instr-fuse',-1,0,128,4,4,0,0
MEMBER:'instr-fuse',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,4,4,0,0
MEMBER:'instr-toggle',0,0,128,4,3,0,0
MEMBER:'instr-arrow',180,0,64,4,2,0,0
MEMBER:'instr-grab',-1,1,128,5,3,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-arrow',180,0,16,7,7,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-arrow',0,0,64,6,3,0,0
MEMBER:'instr-arrow',-90,0,64,7,3,0,0
MEMBER:'instr-grab',-1,1,128,7,3,0,0
MEMBER:'instr-arrow',180,0,64,7,2,0,0
MEMBER:'instr-fuse',-1,0,32,3,4,0,0
MEMBER:'instr-fuse',-1,0,32,7,6,0,0
MEMBER:'instr-output',-1,0,128,5,2,0,0
MEMBER:'instr-toggle',90,0,128,6,2,0,0
MEMBER:'instr-split',-1,0,32,6,7,0,0
MEMBER:'instr-split',-1,0,128,7,2,0,0
MEMBER:'instr-output',-1,0,32,4,7,0,0
MEMBER:'instr-output',-1,1,32,2,7,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,6,0
PIPE:0,7,0
PIPE:0,8,0
PIPE:0,9,0
PIPE:0,9,1
PIPE:0,9,2
PIPE:0,9,3
PIPE:0,9,4
PIPE:0,9,5
PIPE:0,9,6
ANNOTATION:0,0,73,-211,'1,3:0,74;\n\r\n\r\n\r'
ANNOTATION:1,0,0,0,'1,1:0,74;\n\r\n\r\n\r'
COMPONENT:'freeform-counter',14,13,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,6,1
COMPONENT:'freeform-custom-reactor-1',21,13,''
MEMBER:'instr-start',0,0,128,5,6,0,0
MEMBER:'instr-start',-90,0,32,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-sensor',-1,0,1,2,5,0,0
MEMBER:'feature-sensor',-1,0,1,8,7,0,0
MEMBER:'feature-tunnel',-1,0,1,3,4,0,0
MEMBER:'feature-tunnel',-1,0,1,9,2,0,0
MEMBER:'instr-input',-1,0,128,5,3,0,0
MEMBER:'instr-grab',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-arrow',0,0,64,2,7,0,0
MEMBER:'instr-arrow',-90,0,64,3,7,0,0
MEMBER:'instr-swap',-1,0,128,2,5,0,0
MEMBER:'instr-swap',-1,0,128,3,6,0,0
MEMBER:'instr-grab',-1,1,32,9,2,0,0
MEMBER:'instr-bond',-1,0,32,9,3,0,0
MEMBER:'instr-grab',-1,2,32,9,4,0,0
MEMBER:'instr-arrow',90,0,16,9,2,0,0
MEMBER:'instr-arrow',-90,0,16,9,4,0,0
MEMBER:'instr-arrow',0,0,64,3,5,0,0
MEMBER:'instr-grab',-1,2,128,8,3,0,0
MEMBER:'instr-arrow',180,0,64,8,3,0,0
MEMBER:'instr-output',-1,0,128,7,3,0,0
MEMBER:'instr-grab',-1,2,128,4,3,0,0
MEMBER:'instr-arrow',180,0,64,4,3,0,0
MEMBER:'instr-output',-1,1,128,5,5,0,0
MEMBER:'instr-arrow',90,0,64,6,5,0,0
MEMBER:'instr-rotate',-1,1,128,4,6,0,0
MEMBER:'instr-arrow',0,0,64,4,6,0,0
MEMBER:'instr-toggle',180,0,128,6,6,0,0
MEMBER:'instr-arrow',90,0,64,7,6,0,0
MEMBER:'instr-toggle',-90,0,128,7,7,0,0
MEMBER:'instr-toggle',-90,0,128,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,4,0,0
MEMBER:'instr-arrow',0,0,64,7,4,0,0
MEMBER:'instr-bond',-1,1,128,3,7,0,0
MEMBER:'instr-sensor',-90,0,128,4,5,0,26
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5''',
    r'''SOLUTION:TestWallCollisionsPositive,Zig,57-1-28,no_wall_collisions
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,2,0,0,0
MEMBER:'instr-start',90,0,32,3,2,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,0,0,0
MEMBER:'feature-bonder',-1,0,1,5,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-input',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-grab',-1,1,128,3,4,0,0
MEMBER:'instr-rotate',-1,0,128,4,4,0,0
MEMBER:'instr-output',-1,0,32,0,7,0,0
MEMBER:'instr-arrow',90,0,64,5,2,0,0
MEMBER:'instr-rotate',-1,0,128,5,2,0,0
MEMBER:'instr-arrow',180,0,64,5,5,0,0
MEMBER:'instr-bond',-1,1,128,7,5,0,0
MEMBER:'instr-bond',-1,1,128,7,4,0,0
MEMBER:'instr-bond',-1,1,128,7,3,0,0
MEMBER:'instr-bond',-1,1,128,7,2,0,0
MEMBER:'instr-bond',-1,1,128,7,1,0,0
MEMBER:'instr-grab',-1,2,128,7,0,0,0
MEMBER:'instr-arrow',180,0,64,7,0,0,0
MEMBER:'instr-arrow',90,0,64,2,0,0,0
MEMBER:'instr-bond',-1,0,128,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,4,4,0,0
MEMBER:'instr-arrow',0,0,64,4,2,0,0
MEMBER:'instr-rotate',-1,0,128,5,3,0,0
MEMBER:'instr-rotate',-1,0,128,4,5,0,0
MEMBER:'instr-arrow',90,0,64,4,5,0,0
MEMBER:'instr-arrow',0,0,64,4,6,0,0
MEMBER:'instr-arrow',-90,0,64,7,6,0,0
MEMBER:'instr-grab',-1,1,32,3,4,0,0
MEMBER:'instr-input',-1,1,32,3,3,0,0
MEMBER:'instr-arrow',180,0,16,3,7,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestMoleculeCollisions,Zig,76-1-33,2x2 past (1,2)
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-bond',-1,0,32,3,7,0,0
MEMBER:'instr-input',-1,0,128,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,3,2,0,0
MEMBER:'instr-arrow',180,0,64,3,3,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-rotate',-1,0,128,2,3,0,0
MEMBER:'instr-sync',-1,0,128,1,0,0,0
MEMBER:'instr-sync',-1,0,32,5,7,0,0
MEMBER:'instr-bond',-1,0,32,3,6,0,0
MEMBER:'instr-arrow',-90,0,16,3,7,0,0
MEMBER:'instr-arrow',0,0,16,3,6,0,0
MEMBER:'instr-arrow',90,0,16,6,6,0,0
MEMBER:'instr-arrow',180,0,16,6,7,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-sync',-1,0,32,4,6,0,0
MEMBER:'instr-sync',-1,0,128,4,4,0,0
MEMBER:'instr-bond',-1,1,128,5,4,0,0
MEMBER:'instr-output',-1,0,32,5,6,0,0
MEMBER:'instr-output',-1,0,32,6,6,0,0
MEMBER:'instr-bond',-1,1,128,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,0,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestMoleculeCollisions,Zig,61-1-37,2x3 past (0,3)
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-bond',-1,0,32,3,7,0,0
MEMBER:'instr-input',-1,0,128,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-arrow',180,0,64,2,4,0,0
MEMBER:'instr-arrow',90,0,64,1,4,0,0
MEMBER:'instr-rotate',-1,0,128,1,4,0,0
MEMBER:'instr-sync',-1,0,128,1,0,0,0
MEMBER:'instr-sync',-1,0,32,5,7,0,0
MEMBER:'instr-bond',-1,0,32,2,7,0,0
MEMBER:'instr-arrow',-90,0,16,2,7,0,0
MEMBER:'instr-arrow',0,0,16,2,6,0,0
MEMBER:'instr-arrow',90,0,16,6,6,0,0
MEMBER:'instr-arrow',180,0,16,6,7,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-sync',-1,0,32,3,6,0,0
MEMBER:'instr-sync',-1,0,128,4,5,0,0
MEMBER:'instr-bond',-1,1,128,5,4,0,0
MEMBER:'instr-output',-1,0,32,5,6,0,0
MEMBER:'instr-output',-1,0,32,6,6,0,0
MEMBER:'instr-bond',-1,1,128,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,0,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-bond',-1,0,32,2,6,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,4,5,0,0
MEMBER:'instr-arrow',0,0,64,4,4,0,0
MEMBER:'instr-bond',-1,1,128,4,4,0,0
MEMBER:'instr-output',-1,0,32,4,6,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestMoleculeCollisions,Zig,40-1-48,4x4 past (3,4)
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,2,0,0
MEMBER:'instr-start',180,0,32,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-input',-1,0,128,2,2,0,0
MEMBER:'instr-input',-1,0,128,1,4,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-input',-1,0,128,3,4,0,0
MEMBER:'instr-input',-1,0,128,4,4,0,0
MEMBER:'instr-grab',-1,2,32,0,1,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-arrow',90,0,64,4,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,5,0,0
MEMBER:'instr-rotate',-1,0,128,3,5,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-sync',-1,0,32,0,2,0,0
MEMBER:'instr-bond',-1,0,32,0,5,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
MEMBER:'instr-arrow',0,0,16,0,7,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',-90,0,16,5,7,0,0
MEMBER:'instr-arrow',90,0,16,0,2,0,0
MEMBER:'instr-bond',-1,0,32,1,7,0,0
MEMBER:'instr-bond',-1,0,32,2,7,0,0
MEMBER:'instr-bond',-1,0,32,0,4,0,0
MEMBER:'instr-arrow',180,0,64,4,5,0,0
MEMBER:'instr-arrow',0,0,64,3,0,0,0
MEMBER:'instr-bond',-1,1,128,3,3,0,0
MEMBER:'instr-bond',-1,1,128,3,2,0,0
MEMBER:'instr-bond',-1,1,128,3,1,0,0
MEMBER:'instr-bond',-1,1,128,5,0,0,0
MEMBER:'instr-bond',-1,1,128,4,0,0,0
MEMBER:'instr-bond',-1,1,128,3,0,0,0
MEMBER:'instr-arrow',-90,0,64,2,2,0,0
MEMBER:'instr-output',-1,0,32,5,5,0,0
MEMBER:'instr-output',-1,0,32,5,4,0,0
MEMBER:'instr-output',-1,0,32,5,3,0,0
MEMBER:'instr-output',-1,0,32,5,2,0,0
MEMBER:'instr-arrow',180,0,16,5,2,0,0
MEMBER:'instr-output',-1,0,32,4,2,0,0
MEMBER:'instr-output',-1,0,32,3,2,0,0
MEMBER:'instr-output',-1,0,32,2,2,0,0
MEMBER:'instr-arrow',90,0,64,6,0,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,0,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    # Recycler-containing ResNet level
    r'''SOLUTION:A New Beginning,whoever314,7056-3-275,Symbols
COMPONENT:'drag-arbitrary-input',1,5,''
PIPE:0,2,1
PIPE:0,3,1
COMPONENT:'drag-arbitrary-input',3,13,''
PIPE:0,2,1
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,1,-3
PIPE:0,1,-4
PIPE:0,1,-5
PIPE:0,1,-6
COMPONENT:'drag-nuclear-reactor',11,3,''
MEMBER:'instr-start',180,0,32,9,0,0,0
MEMBER:'instr-start',180,0,128,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,0,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-fuser',-1,0,1,2,7,0,0
MEMBER:'feature-splitter',-1,0,1,0,7,0,0
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-grab',-1,1,128,2,3,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-bond',-1,1,32,4,0,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-sync',-1,0,128,1,5,0,0
MEMBER:'instr-rotate',-1,0,128,1,4,0,0
MEMBER:'instr-input',-1,0,32,1,0,0,0
MEMBER:'instr-input',-1,0,32,3,0,0,0
MEMBER:'instr-input',-1,0,32,2,0,0,0
MEMBER:'instr-bond',-1,0,32,1,1,0,0
MEMBER:'instr-input',-1,0,32,2,3,0,0
MEMBER:'instr-grab',-1,1,32,1,2,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-grab',-1,2,32,1,4,0,0
MEMBER:'instr-bond',-1,1,128,0,2,0,0
MEMBER:'instr-bond',-1,0,128,1,3,0,0
MEMBER:'instr-rotate',-1,1,32,1,3,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-rotate',-1,0,128,0,1,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-arrow',-90,0,16,2,4,0,0
MEMBER:'instr-grab',-1,1,32,2,2,0,0
MEMBER:'instr-sync',-1,0,32,3,2,0,0
MEMBER:'instr-sync',-1,0,128,3,0,0,0
MEMBER:'instr-rotate',-1,1,32,2,1,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,3,1,0,0
MEMBER:'instr-arrow',180,0,16,3,2,0,0
MEMBER:'instr-grab',-1,2,32,0,2,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-arrow',180,0,64,2,5,0,0
MEMBER:'instr-arrow',180,0,64,1,3,0,0
MEMBER:'instr-arrow',-90,0,64,0,3,0,0
MEMBER:'instr-arrow',90,0,16,0,2,0,0
MEMBER:'instr-arrow',180,0,64,2,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
MEMBER:'instr-bond',-1,0,32,0,3,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,32,0,4,0,0
MEMBER:'instr-arrow',-90,0,16,0,5,0,0
MEMBER:'instr-toggle',0,0,32,0,5,0,0
MEMBER:'instr-bond',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',90,0,16,0,3,0,0
MEMBER:'instr-rotate',-1,0,32,6,5,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-arrow',-90,0,16,8,5,0,0
MEMBER:'instr-output',-1,1,32,8,5,0,0
MEMBER:'instr-toggle',0,0,128,2,4,0,0
MEMBER:'instr-toggle',-90,0,128,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-grab',-1,2,128,8,1,0,0
MEMBER:'instr-arrow',180,0,64,6,2,0,0
MEMBER:'instr-output',-1,0,128,8,2,0,0
MEMBER:'instr-arrow',90,0,64,8,1,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-input',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-arrow',180,0,64,8,3,0,0
MEMBER:'instr-toggle',90,0,128,2,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,6,3
PIPE:1,6,4
PIPE:1,6,5
PIPE:1,6,6
PIPE:1,6,7
PIPE:1,6,8
PIPE:1,6,9
PIPE:1,6,10
PIPE:1,7,10
PIPE:1,8,10
PIPE:1,9,10
PIPE:1,10,10
PIPE:1,11,10
ANNOTATION:0,1,25,105,'0,3:0,33;0,2:0,201;0,1:0,17;2,0:0,1;2,1:0,202;3,1:0,1;2,2:0,6;3,2:0,1;2,3:0,17;1,2:0,1;1,1:0,1;\n0,2,0:1;0,1,0:1;2,0,0:1;2,1,1:1;2,1,0:1;2,2,1:1;2,2,0:1;1,2,1:1;1,1,1:1;\r0,1:0,17;2,1:0,8;0,2:0,201;2,2:0,6;0,3:0,17;1,2:0,1;\n1,2,1:1;0,1,0:1;0,2,0:1;2,1,0:1;\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-nuclear-reactor',18,3,''
MEMBER:'instr-start',180,0,128,3,0,0,0
MEMBER:'instr-start',90,0,32,2,0,0,0
MEMBER:'feature-bonder',-1,0,1,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-fuser',-1,0,1,3,4,0,0
MEMBER:'feature-splitter',-1,0,1,2,6,0,0
MEMBER:'instr-input',-1,0,128,0,0,0,0
MEMBER:'instr-grab',-1,1,128,0,1,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',-90,0,64,4,2,0,0
MEMBER:'instr-grab',-1,2,128,4,4,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-fuse',-1,0,32,2,4,0,0
MEMBER:'instr-sync',-1,0,32,2,1,0,0
MEMBER:'instr-sync',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',180,0,64,4,1,0,0
MEMBER:'instr-split',-1,0,128,1,5,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,32,5,4,0,0
MEMBER:'instr-grab',-1,1,128,1,2,0,0
MEMBER:'instr-arrow',0,0,16,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-arrow',90,0,16,5,4,0,0
MEMBER:'instr-arrow',180,0,16,5,6,0,0
MEMBER:'instr-grab',-1,1,32,3,6,0,0
MEMBER:'instr-arrow',-90,0,16,3,6,0,0
MEMBER:'instr-toggle',0,0,128,1,3,0,0
MEMBER:'instr-bond',-1,0,128,3,3,0,0
MEMBER:'instr-grab',-1,2,128,4,2,0,0
MEMBER:'instr-fuse',-1,0,32,3,4,0,0
MEMBER:'instr-arrow',90,0,64,4,3,0,0
MEMBER:'instr-bond',-1,1,128,4,5,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-grab',-1,1,32,4,3,0,0
MEMBER:'instr-arrow',90,0,16,4,3,0,0
MEMBER:'instr-grab',-1,0,32,4,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,5,0,0
MEMBER:'instr-arrow',0,0,64,5,4,0,0
MEMBER:'instr-grab',-1,2,128,8,2,0,0
MEMBER:'instr-arrow',-90,0,64,8,2,0,0
MEMBER:'instr-grab',-1,0,32,4,7,0,0
MEMBER:'instr-arrow',180,0,16,4,7,0,0
MEMBER:'instr-arrow',-90,0,16,3,7,0,0
MEMBER:'instr-toggle',180,0,32,3,7,0,0
MEMBER:'instr-output',-1,0,128,8,1,0,0
MEMBER:'instr-bond',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',0,0,64,4,5,0,0
MEMBER:'instr-rotate',-1,1,128,6,4,0,0
MEMBER:'instr-rotate',-1,1,128,7,3,0,0
MEMBER:'instr-bond',-1,0,128,7,2,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-grab',-1,1,128,5,4,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-arrow',0,0,64,7,2,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-rotate',-1,0,32,5,2,0,0
MEMBER:'instr-arrow',-90,0,16,5,2,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-input',-1,0,32,0,3,0,0
MEMBER:'instr-grab',-1,1,32,0,2,0,0
MEMBER:'instr-sync',-1,0,32,3,2,0,0
MEMBER:'instr-sync',-1,0,128,4,0,0,0
MEMBER:'instr-bond',-1,1,128,1,0,0,0
MEMBER:'instr-bond',-1,1,128,2,0,0,0
MEMBER:'instr-toggle',0,0,128,4,1,0,0
MEMBER:'instr-bond',-1,0,128,5,1,0,0
MEMBER:'instr-arrow',90,0,64,5,1,0,0
MEMBER:'instr-bond',-1,1,128,5,3,0,0
MEMBER:'instr-grab',-1,1,128,5,2,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-sync',-1,0,128,9,3,0,0
MEMBER:'instr-sync',-1,0,32,6,1,0,0
MEMBER:'instr-arrow',0,0,16,5,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-bond',-1,0,32,6,2,0,0
MEMBER:'instr-bond',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-grab',-1,2,32,5,3,0,0
MEMBER:'instr-arrow',-90,0,16,5,3,0,0
MEMBER:'instr-toggle',180,0,32,5,1,0,0
MEMBER:'instr-arrow',-90,0,64,9,3,0,0
MEMBER:'instr-grab',-1,2,128,9,2,0,0
MEMBER:'instr-grab',-1,1,128,9,1,0,0
MEMBER:'instr-arrow',180,0,64,9,1,0,0
MEMBER:'instr-rotate',-1,1,128,8,3,0,0
MEMBER:'instr-toggle',90,0,128,6,3,0,0
MEMBER:'instr-bond',-1,0,32,4,1,0,0
MEMBER:'instr-arrow',90,0,16,2,1,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-output',-1,1,128,6,6,0,0
MEMBER:'instr-arrow',180,0,64,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,3,6,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:0,4,0
COMPONENT:'drag-nuclear-reactor',5,5,''
MEMBER:'instr-start',90,0,128,9,0,0,0
MEMBER:'instr-start',-90,0,32,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-fuser',-1,0,1,6,4,0,0
MEMBER:'feature-splitter',-1,0,1,8,7,0,0
MEMBER:'instr-arrow',90,0,16,5,0,0,0
MEMBER:'instr-grab',-1,1,32,1,0,0,0
MEMBER:'instr-arrow',0,0,16,5,1,0,0
MEMBER:'instr-bond',-1,1,32,7,1,0,0
MEMBER:'instr-arrow',-90,0,16,7,1,0,0
MEMBER:'instr-bond',-1,0,32,7,0,0,0
MEMBER:'instr-sync',-1,0,32,5,1,0,0
MEMBER:'instr-sync',-1,0,128,7,1,0,0
MEMBER:'instr-bond',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',180,0,16,7,0,0,0
MEMBER:'instr-arrow',90,0,16,6,0,0,0
MEMBER:'instr-bond',-1,1,128,4,1,0,0
MEMBER:'instr-bond',-1,0,32,6,2,0,0
MEMBER:'instr-arrow',0,0,16,6,2,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-fuse',-1,0,128,2,3,0,0
MEMBER:'instr-grab',-1,0,32,7,4,0,0
MEMBER:'instr-output',-1,1,128,1,3,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-output',-1,1,32,1,2,0,0
MEMBER:'instr-input',-1,1,128,2,4,0,0
MEMBER:'instr-grab',-1,1,128,1,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,7,0,0
MEMBER:'instr-rotate',-1,1,32,7,2,0,0
MEMBER:'instr-rotate',-1,1,32,7,3,0,0
MEMBER:'instr-fuse',-1,0,128,1,2,0,0
MEMBER:'instr-output',-1,1,128,2,2,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-arrow',0,0,16,6,5,0,0
MEMBER:'instr-arrow',0,0,16,6,4,0,0
MEMBER:'instr-rotate',-1,1,32,9,4,0,0
MEMBER:'instr-arrow',0,0,64,4,5,0,0
MEMBER:'instr-fuse',-1,0,128,4,5,0,0
MEMBER:'instr-arrow',-90,0,16,9,4,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-arrow',90,0,64,4,2,0,0
MEMBER:'instr-toggle',180,0,32,7,5,0,0
MEMBER:'instr-arrow',180,0,16,7,6,0,0
MEMBER:'instr-arrow',90,0,16,7,5,0,0
MEMBER:'instr-toggle',-90,0,32,6,5,0,0
MEMBER:'instr-arrow',-90,0,16,4,6,0,0
MEMBER:'instr-grab',-1,2,32,8,3,0,0
MEMBER:'instr-fuse',-1,0,128,4,2,0,0
MEMBER:'instr-fuse',-1,0,32,7,6,0,0
MEMBER:'instr-fuse',-1,0,128,5,5,0,0
MEMBER:'instr-rotate',-1,1,128,4,3,0,0
MEMBER:'instr-grab',-1,1,32,5,4,0,0
MEMBER:'instr-arrow',90,0,64,6,5,0,0
MEMBER:'instr-fuse',-1,0,128,4,4,0,0
MEMBER:'instr-fuse',-1,0,128,4,7,0,0
MEMBER:'instr-toggle',0,0,128,6,7,0,0
MEMBER:'instr-toggle',-90,0,128,7,7,0,0
MEMBER:'instr-arrow',180,0,64,7,7,0,0
MEMBER:'instr-grab',-1,0,128,7,6,0,0
MEMBER:'instr-bond',-1,1,32,4,7,0,0
MEMBER:'instr-arrow',180,0,64,6,7,0,0
MEMBER:'instr-arrow',180,0,16,9,3,0,0
MEMBER:'instr-output',-1,0,32,2,0,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-arrow',180,0,64,2,4,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-input',-1,1,128,3,7,0,0
MEMBER:'instr-grab',-1,1,128,3,6,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-toggle',-90,0,32,2,3,0,0
MEMBER:'instr-toggle',180,0,32,2,2,0,0
MEMBER:'instr-arrow',90,0,16,2,2,0,0
MEMBER:'instr-input',-1,1,32,2,4,0,0
MEMBER:'instr-grab',-1,1,32,2,6,0,0
MEMBER:'instr-arrow',90,0,16,2,3,0,0
MEMBER:'instr-output',-1,1,32,5,3,0,0
MEMBER:'instr-arrow',90,0,16,5,5,0,0
MEMBER:'instr-grab',-1,2,32,8,7,0,0
MEMBER:'instr-fuse',-1,0,128,5,3,0,0
MEMBER:'instr-arrow',-90,0,16,1,7,0,0
MEMBER:'instr-arrow',180,0,16,8,7,0,0
MEMBER:'instr-toggle',180,0,32,5,7,0,0
MEMBER:'instr-arrow',0,0,16,5,7,0,0
MEMBER:'instr-arrow',-90,0,64,9,6,0,0
MEMBER:'instr-arrow',90,0,64,8,4,0,0
MEMBER:'instr-bond',-1,0,128,8,4,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-fuse',-1,0,32,5,6,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-sync',-1,0,32,3,5,0,0
MEMBER:'instr-arrow',0,0,64,3,3,0,0
MEMBER:'instr-rotate',-1,0,128,3,5,0,0
MEMBER:'instr-toggle',-90,0,128,3,4,0,0
MEMBER:'instr-sync',-1,0,128,3,3,0,0
MEMBER:'instr-sync',-1,0,128,8,2,0,0
MEMBER:'instr-grab',-1,1,128,7,3,0,0
MEMBER:'instr-rotate',-1,1,128,8,3,0,0
MEMBER:'instr-arrow',-90,0,64,8,3,0,0
MEMBER:'instr-output',-1,0,32,3,7,0,0
MEMBER:'instr-sync',-1,0,32,2,7,0,0
MEMBER:'instr-arrow',180,0,64,8,2,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-grab',-1,1,128,6,2,0,0
MEMBER:'instr-arrow',90,0,64,5,2,0,0
MEMBER:'instr-bond',-1,0,128,5,2,0,0
MEMBER:'instr-arrow',0,0,64,5,6,0,0
MEMBER:'instr-grab',-1,2,128,8,5,0,0
MEMBER:'instr-arrow',-90,0,64,9,5,0,0
MEMBER:'instr-arrow',180,0,64,9,1,0,0
MEMBER:'instr-bond',-1,1,32,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,0,0,0
MEMBER:'instr-input',-1,0,32,1,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-toggle',-90,0,128,6,3,0,0
MEMBER:'instr-arrow',90,0,64,7,0,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-output',-1,0,128,6,0,0,0
MEMBER:'instr-rotate',-1,0,32,9,3,0,0
MEMBER:'instr-bond',-1,1,128,7,4,0,0
MEMBER:'instr-arrow',0,0,64,7,4,0,0
MEMBER:'instr-arrow',0,0,64,8,5,0,0
MEMBER:'instr-arrow',0,0,64,6,0,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-toggle',0,0,32,2,5,0,0
MEMBER:'instr-output',-1,1,32,5,5,0,0
MEMBER:'instr-sync',-1,0,128,7,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,4,12
PIPE:1,4,13
PIPE:1,5,13
PIPE:1,6,13
PIPE:1,7,13
PIPE:1,8,13
PIPE:1,9,13
PIPE:1,10,13
PIPE:1,11,13
PIPE:1,12,13
PIPE:1,13,13
PIPE:1,14,13
PIPE:1,15,13
PIPE:1,16,13
PIPE:1,17,13
PIPE:1,18,13
PIPE:0,4,-1
PIPE:0,5,-1
ANNOTATION:0,1,-103,107,'2,2:0,201;2,3:0,33;2,1:0,17;\n2,1,0:1;2,2,0:1;\r0,2:0,1;1,1:0,1;1,3:0,1;\n\r1,2:0,6;1,3:0,1;1,1:0,1;2,2:0,17;\n1,1,0:1;1,2,0:1;1,2,1:1;\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
''',
    r'''SOLUTION:Overbond test,joe,9-1-5
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-bond',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-output',-1,0,128,9,1,0,0''',
    r"""SOLUTION:Exploding Head Syndrome,stephen46,3482-4-123,Unencountered CTRL cmd
COMPONENT:'drag-fusion-reactor',1,12,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',90,0,32,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-fuser',-1,0,1,4,2,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-grab',-1,0,128,7,4,0,0
MEMBER:'instr-arrow',90,0,64,8,4,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,5,0,0
MEMBER:'instr-bond',-1,1,128,8,4,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-output',-1,0,128,6,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-bond',-1,0,32,6,5,0,0
MEMBER:'instr-arrow',0,0,16,6,5,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-arrow',-90,0,16,7,5,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-arrow',90,0,16,6,2,0,0
MEMBER:'instr-output',-1,1,32,7,2,0,0
MEMBER:'instr-sync',-1,0,32,6,3,0,0
MEMBER:'instr-sync',-1,0,128,7,3,0,0
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,5,-2
PIPE:0,6,-2
PIPE:0,7,-2
PIPE:0,7,-3
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
COMPONENT:'drag-oceanic-input',5,18,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,0,-2
PIPE:0,-1,-2
PIPE:0,-2,-2
PIPE:0,-3,-2
PIPE:0,-4,-2
PIPE:0,-5,-2
PIPE:0,-5,-3
PIPE:0,-5,-4
PIPE:0,-5,-5
COMPONENT:'drag-fusion-reactor',14,3,''
MEMBER:'instr-start',180,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-fuser',-1,0,1,1,1,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-arrow',180,0,64,3,2,0,0
MEMBER:'instr-fuse',-1,0,128,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-arrow',90,0,64,3,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,2,128,2,1,0,0
MEMBER:'instr-arrow',-90,0,64,0,2,0,0
MEMBER:'instr-sync',-1,0,32,4,3,0,0
MEMBER:'instr-sync',-1,0,32,4,4,0,0
MEMBER:'instr-sync',-1,0,32,3,5,0,0
MEMBER:'instr-sync',-1,0,32,4,5,0,0
MEMBER:'instr-sync',-1,0,32,5,3,0,0
MEMBER:'instr-sync',-1,0,32,6,4,0,0
MEMBER:'instr-sync',-1,0,32,6,5,0,0
MEMBER:'instr-sync',-1,0,32,3,4,0,0
MEMBER:'instr-sync',-1,0,32,5,5,0,0
MEMBER:'instr-sync',-1,0,32,3,3,0,0
MEMBER:'instr-arrow',180,0,16,6,5,0,0
MEMBER:'instr-sync',-1,0,128,3,1,0,0
MEMBER:'instr-sync',-1,0,32,5,4,0,0
MEMBER:'instr-input',-1,1,32,2,5,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,1,5,0,0
MEMBER:'instr-fuse',-1,0,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,0,0,0
MEMBER:'instr-arrow',90,0,16,2,0,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-grab',-1,2,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',90,0,16,3,3,0,0
MEMBER:'instr-arrow',0,0,16,3,4,0,0
MEMBER:'instr-arrow',90,0,16,6,4,0,0
MEMBER:'instr-arrow',90,0,16,6,2,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-control',180,0,32,5,1,0,0
PIPE:0,4,1
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,4,4
PIPE:0,3,4
PIPE:0,3,5
PIPE:0,3,6
PIPE:0,3,7
PIPE:0,3,8
PIPE:0,3,9
PIPE:0,3,10
PIPE:0,2,10
PIPE:0,2,11
PIPE:0,2,12
PIPE:0,2,13
PIPE:0,2,14
PIPE:1,4,2
COMPONENT:'drag-fusion-reactor',9,13,''
MEMBER:'instr-start',-90,0,128,0,3,0,0
MEMBER:'instr-start',180,0,32,6,6,0,0
MEMBER:'feature-bonder',-1,0,1,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-fuser',-1,0,1,4,1,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-sync',-1,0,128,3,1,0,0
MEMBER:'instr-sync',-1,0,32,5,6,0,0
MEMBER:'instr-fuse',-1,0,32,4,6,0,0
MEMBER:'instr-sync',-1,0,32,3,6,0,0
MEMBER:'instr-fuse',-1,0,32,2,6,0,0
MEMBER:'instr-arrow',90,0,64,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,3,0,0
MEMBER:'instr-arrow',-90,0,64,0,3,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-sync',-1,0,32,1,6,0,0
MEMBER:'instr-fuse',-1,0,32,0,6,0,0
MEMBER:'instr-sync',-1,0,32,0,5,0,0
MEMBER:'instr-fuse',-1,0,32,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,0,6,0,0
MEMBER:'instr-arrow',0,0,16,0,5,0,0
MEMBER:'instr-sync',-1,0,32,2,5,0,0
MEMBER:'instr-fuse',-1,0,32,3,5,0,0
MEMBER:'instr-sync',-1,0,32,4,5,0,0
MEMBER:'instr-fuse',-1,0,32,5,5,0,0
MEMBER:'instr-arrow',-90,0,16,5,5,0,0
MEMBER:'instr-arrow',0,0,16,5,1,0,0
MEMBER:'instr-arrow',-90,0,16,7,1,0,0
MEMBER:'instr-arrow',180,0,16,7,0,0,0
MEMBER:'instr-grab',-1,2,32,7,1,0,0
MEMBER:'instr-output',-1,0,32,7,0,0,0
MEMBER:'instr-grab',-1,1,32,5,1,0,0
MEMBER:'instr-arrow',90,0,16,4,0,0,0
MEMBER:'instr-sync',-1,0,32,6,0,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-grab',-1,2,128,4,1,0,0
MEMBER:'instr-grab',-1,1,32,4,1,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-arrow',90,0,16,6,4,0,0
MEMBER:'instr-arrow',180,0,16,6,6,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
PIPE:0,4,1
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,5,-1
PIPE:0,6,-1
PIPE:0,7,-1
PIPE:0,7,-2
PIPE:0,7,-3
PIPE:0,7,-4
PIPE:0,7,-5
PIPE:0,7,-6
PIPE:0,6,-6
PIPE:0,5,-6
PIPE:0,4,-6
PIPE:0,3,-6
PIPE:0,2,-6
PIPE:0,1,-6
PIPE:0,0,-6
PIPE:0,0,-7
PIPE:0,1,-7
PIPE:0,2,-7
PIPE:0,2,-8
PIPE:0,1,-8
PIPE:0,0,-8
PIPE:0,-1,-8
PIPE:0,-1,-9
PIPE:0,-1,-10
PIPE:0,-1,-11
PIPE:0,0,-11
PIPE:0,0,-10
PIPE:0,0,-9
PIPE:0,1,-9
PIPE:0,1,-10
PIPE:0,1,-11
PIPE:0,2,-11
PIPE:0,3,-11
PIPE:0,3,-10
PIPE:0,2,-10
PIPE:0,2,-9
PIPE:0,3,-9
PIPE:0,3,-8
PIPE:0,4,-8
PIPE:1,4,2
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
COMPONENT:'drag-fusion-reactor',9,8,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,4,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,0,1,0,0
MEMBER:'feature-bonder',-1,0,1,0,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-fuser',-1,0,1,4,2,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',-90,0,64,1,1,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-arrow',180,0,64,1,0,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-bond',-1,0,128,0,1,0,0
MEMBER:'instr-bond',-1,0,128,0,2,0,0
MEMBER:'instr-arrow',-90,0,64,6,2,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-sync',-1,0,128,1,2,0,0
MEMBER:'instr-input',-1,0,32,2,1,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,7,5,0,0
MEMBER:'instr-arrow',180,0,16,7,1,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-output',-1,0,128,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-sync',-1,0,32,3,1,0,0
MEMBER:'instr-sync',-1,0,128,5,1,0,0
MEMBER:'instr-sync',-1,0,32,5,1,0,0
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,5,2
PIPE:0,5,3
PIPE:0,5,4
PIPE:0,5,5
PIPE:0,5,6
PIPE:0,5,7
PIPE:0,5,8
PIPE:0,6,8
PIPE:0,7,8
PIPE:1,4,2
PIPE:1,4,1
PIPE:1,4,0
PIPE:1,4,-1
PIPE:1,4,-2
PIPE:1,4,-3
PIPE:1,4,-4""",
    r"""SOLUTION:More than Machine,cearn,1797-3-69,double-crystal discharges
COMPONENT:'drag-superlaser-reactor',10,8,''
MEMBER:'instr-start',0,0,128,0,3,0,0
MEMBER:'instr-start',0,0,32,2,0,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,1,0,0
MEMBER:'feature-bonder',-1,0,1,3,1,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-sensor',-1,0,1,7,6,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-grab',-1,1,128,3,3,0,0
MEMBER:'instr-rotate',-1,0,128,4,3,0,0
MEMBER:'instr-arrow',-90,0,64,6,3,0,0
MEMBER:'instr-arrow',180,0,64,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,5,2,0,0
MEMBER:'instr-arrow',180,0,64,5,1,0,0
MEMBER:'instr-bond',-1,1,128,6,2,0,0
MEMBER:'instr-sync',-1,0,128,5,1,0,0
MEMBER:'instr-sync',-1,0,128,6,3,0,0
MEMBER:'instr-sync',-1,0,32,3,1,0,0
MEMBER:'instr-input',-1,0,32,3,2,0,0
MEMBER:'instr-grab',-1,1,32,3,3,0,0
MEMBER:'instr-rotate',-1,1,32,4,3,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-arrow',-90,0,16,8,3,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-arrow',90,0,16,3,0,0,0
MEMBER:'instr-grab',-1,2,32,8,2,0,0
MEMBER:'instr-input',-1,1,32,8,1,0,0
MEMBER:'instr-bond',-1,0,32,8,0,0,0
MEMBER:'instr-sync',-1,0,32,7,0,0,0
MEMBER:'instr-bond',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-input',-1,0,128,4,1,0,0
MEMBER:'instr-grab',-1,2,128,1,5,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-sensor',90,0,128,1,7,0,24
MEMBER:'instr-sensor',90,0,128,1,4,0,24
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',90,0,64,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-arrow',180,0,64,6,7,0,0
MEMBER:'instr-arrow',0,0,64,1,7,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
COMPONENT:'drag-mining-input',2,14,''
PIPE:0,3,0
COMPONENT:'drag-silo-input',0,1,''
PIPE:0,5,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,6,-1
PIPE:0,6,0
PIPE:0,6,1
PIPE:0,6,2
PIPE:0,6,3
PIPE:0,7,3
PIPE:0,7,2
PIPE:0,7,1
PIPE:0,7,0
PIPE:0,7,-1
PIPE:0,8,-1
PIPE:0,8,0
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,9,0
PIPE:0,9,-1
PIPE:0,10,-1
PIPE:0,10,0
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,11,0
PIPE:0,11,-1
PIPE:0,12,-1
PIPE:0,12,0
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,14,1
PIPE:0,14,2
PIPE:0,15,2
PIPE:0,15,3
PIPE:0,16,3
PIPE:0,16,4
PIPE:0,17,4
PIPE:0,17,5
PIPE:0,18,5
PIPE:0,18,6
PIPE:0,19,6
PIPE:0,19,7
PIPE:0,20,7
PIPE:0,20,8
PIPE:0,21,8
PIPE:0,21,9
PIPE:0,21,10
PIPE:0,21,11
PIPE:0,21,12
PIPE:0,21,13
PIPE:0,21,14
PIPE:0,21,15
PIPE:0,21,16
PIPE:0,21,17
PIPE:0,21,18
PIPE:0,21,19
PIPE:0,21,20
PIPE:0,20,20
PIPE:0,20,19
PIPE:0,20,18
PIPE:0,20,17
PIPE:0,20,16
PIPE:0,20,15
PIPE:0,20,14
PIPE:0,20,13
PIPE:0,20,12
PIPE:0,20,11
PIPE:0,20,10
PIPE:0,20,9
PIPE:0,19,9
PIPE:0,18,9
PIPE:0,17,9
PIPE:0,16,9
PIPE:0,15,9
PIPE:0,15,8
PIPE:0,15,7
PIPE:0,15,6
PIPE:0,15,5
PIPE:0,15,4
PIPE:0,14,4
PIPE:0,13,4
PIPE:0,13,3
PIPE:0,13,2
PIPE:0,12,2
PIPE:0,11,2
PIPE:0,10,2
PIPE:0,9,2
PIPE:0,8,2
PIPE:0,8,3
PIPE:0,9,3
PIPE:0,9,4
PIPE:0,9,5
PIPE:0,9,6
PIPE:0,9,7
PIPE:0,9,8
PIPE:0,9,9
COMPONENT:'drag-advanced-reactor',6,13,''
MEMBER:'instr-start',180,0,128,5,1,0,0
MEMBER:'instr-start',180,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,5,0,0
MEMBER:'feature-sensor',-1,0,1,1,2,0,0
MEMBER:'instr-grab',-1,1,128,3,1,0,0
MEMBER:'instr-input',-1,0,128,4,1,0,0
MEMBER:'instr-sensor',180,0,128,3,2,0,24
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-output',-1,0,128,7,1,0,0
MEMBER:'instr-output',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',-90,0,64,8,2,0,0
MEMBER:'instr-rotate',-1,1,128,8,2,0,0
MEMBER:'instr-arrow',90,0,64,3,1,0,0
MEMBER:'instr-grab',-1,2,128,8,1,0,0
MEMBER:'instr-arrow',0,0,64,3,2,0,0
MEMBER:'instr-grab',-1,1,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-bond',-1,1,128,7,4,0,0
MEMBER:'instr-arrow',90,0,64,1,2,0,0
MEMBER:'instr-bond',-1,1,32,0,0,0,0
MEMBER:'instr-arrow',90,0,64,7,4,0,0
MEMBER:'instr-output',-1,1,128,7,5,0,0
MEMBER:'instr-arrow',0,0,64,7,5,0,0
MEMBER:'instr-arrow',-90,0,64,8,5,0,0
MEMBER:'instr-rotate',-1,0,128,5,4,0,0
MEMBER:'instr-bond',-1,1,128,8,4,0,0
MEMBER:'instr-grab',-1,2,128,8,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,3,-1
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-3,-1
PIPE:0,-4,-1
PIPE:0,-4,-2
PIPE:0,-4,-3
PIPE:0,-4,-4
PIPE:0,-4,-5
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,9,2
PIPE:1,10,2
PIPE:1,11,2
PIPE:1,12,2
PIPE:1,13,2
PIPE:1,14,2
PIPE:1,15,2
PIPE:1,16,2
PIPE:1,17,2
PIPE:1,18,2
PIPE:1,18,3
PIPE:1,18,4
PIPE:1,18,5
PIPE:1,18,6
PIPE:1,19,6
COMPONENT:'drag-advanced-reactor',3,7,''
MEMBER:'instr-start',0,0,128,0,3,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-sensor',-1,0,1,6,3,0,0
MEMBER:'instr-output',-1,1,128,7,6,0,0
MEMBER:'instr-grab',-1,2,128,6,6,0,0
MEMBER:'instr-sensor',90,0,128,6,3,0,24
MEMBER:'instr-grab',-1,2,128,8,3,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-output',-1,0,128,7,3,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-grab',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',180,0,64,8,3,0,0
MEMBER:'instr-arrow',0,0,64,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:1,5,2
PIPE:1,6,2""",
    r"""SOLUTION:Freedom of Choice,BobThePumpkin,4260-3-99
COMPONENT:'drag-starter-reactor',5,7,''
MEMBER:'instr-start',180,0,128,4,0,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'instr-bond',-1,1,128,1,0,0,0
MEMBER:'instr-input',-1,0,128,2,0,0,0
MEMBER:'instr-toggle',90,0,128,3,0,0,0
MEMBER:'instr-arrow',180,0,64,3,1,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-toggle',0,0,128,1,2,0,0
MEMBER:'instr-toggle',0,0,128,2,2,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-arrow',180,0,64,3,3,0,0
MEMBER:'instr-arrow',-90,0,64,3,4,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-bond',-1,0,128,2,4,0,0
MEMBER:'instr-rotate',-1,1,128,3,4,0,0
MEMBER:'instr-rotate',-1,1,128,3,3,0,0
MEMBER:'instr-input',-1,1,128,2,3,0,0
MEMBER:'instr-toggle',-90,0,128,1,3,0,0
MEMBER:'instr-arrow',0,0,64,2,5,0,0
MEMBER:'instr-grab',-1,2,128,8,5,0,0
MEMBER:'instr-output',-1,1,128,8,4,0,0
MEMBER:'instr-arrow',-90,0,64,8,5,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-arrow',90,0,64,7,2,0,0
MEMBER:'instr-arrow',0,0,64,7,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
COMPONENT:'drag-starter-reactor',4,14,''
MEMBER:'instr-start',-90,0,128,1,3,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-bonder',-1,0,1,8,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-bond',-1,1,128,7,1,0,0
MEMBER:'instr-output',-1,0,128,7,2,0,0
MEMBER:'instr-grab',-1,2,128,7,5,0,0
MEMBER:'instr-arrow',180,0,64,7,5,0,0
MEMBER:'instr-output',-1,1,128,6,5,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-arrow',-90,0,64,8,3,0,0
MEMBER:'instr-arrow',-90,0,64,6,3,0,0
MEMBER:'instr-toggle',0,0,128,6,3,0,0
MEMBER:'instr-toggle',90,0,128,8,3,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-arrow',0,0,64,6,1,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-toggle',180,0,128,7,3,0,0
MEMBER:'instr-rotate',-1,0,128,6,1,0,0
MEMBER:'instr-rotate',-1,0,128,8,1,0,0
MEMBER:'instr-rotate',-1,0,128,8,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,3,-2
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,0,-2
PIPE:0,0,-3
PIPE:0,0,-4
PIPE:0,0,-5
PIPE:1,5,2
COMPONENT:'drag-starter-reactor',10,14,''
MEMBER:'instr-start',0,0,128,2,3,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,4,2,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,5,2,0,0
MEMBER:'instr-bond',-1,0,128,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-toggle',90,0,128,1,1,0,0
MEMBER:'instr-toggle',0,0,128,1,2,0,0
MEMBER:'instr-toggle',-90,0,128,2,2,0,0
MEMBER:'instr-bond',-1,0,128,3,2,0,0
MEMBER:'instr-arrow',180,0,64,1,2,0,0
MEMBER:'instr-arrow',-90,0,64,0,2,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,4,2,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,6,0,0,0
MEMBER:'instr-arrow',0,0,64,6,1,0,0
MEMBER:'instr-arrow',-90,0,64,8,1,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-arrow',90,0,64,9,0,0,0
MEMBER:'instr-toggle',0,0,128,8,0,0,0
MEMBER:'instr-output',-1,0,128,9,1,0,0
MEMBER:'instr-toggle',0,0,128,8,1,0,0
MEMBER:'instr-arrow',90,0,64,9,1,0,0
MEMBER:'instr-arrow',90,0,64,9,3,0,0
MEMBER:'instr-arrow',90,0,64,9,6,0,0
MEMBER:'instr-arrow',180,0,64,9,7,0,0
MEMBER:'instr-arrow',180,0,64,9,5,0,0
MEMBER:'instr-toggle',90,0,128,9,5,0,0
MEMBER:'instr-toggle',90,0,128,6,3,0,0
MEMBER:'instr-toggle',90,0,128,7,3,0,0
MEMBER:'instr-toggle',90,0,128,8,3,0,0
MEMBER:'instr-toggle',90,0,128,4,3,0,0
MEMBER:'instr-toggle',180,0,128,5,3,0,0
MEMBER:'instr-toggle',90,0,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-input',-1,0,128,0,4,0,0
MEMBER:'instr-input',-1,1,128,0,6,0,0
MEMBER:'instr-grab',-1,1,128,0,5,0,0
MEMBER:'instr-arrow',180,0,64,3,5,0,0
MEMBER:'instr-arrow',180,0,64,4,5,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-arrow',180,0,64,7,5,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-toggle',0,0,128,0,7,0,0
MEMBER:'instr-arrow',-90,0,64,0,7,0,0
MEMBER:'instr-toggle',-90,0,128,2,7,0,0
MEMBER:'instr-toggle',-90,0,128,3,7,0,0
MEMBER:'instr-arrow',0,0,64,2,6,0,0
MEMBER:'instr-arrow',0,0,64,3,6,0,0
MEMBER:'instr-toggle',-90,0,128,4,7,0,0
MEMBER:'instr-arrow',0,0,64,4,6,0,0
MEMBER:'instr-toggle',0,0,128,6,7,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,5,-2
PIPE:0,4,-2
PIPE:0,3,-2
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,1,-3
PIPE:0,1,-4
PIPE:0,1,-5
PIPE:0,1,-6
PIPE:0,1,-7
PIPE:0,1,-8
PIPE:0,2,-8""",
    r"""SOLUTION:Collapsar,Zig,6445-3-78
COMPONENT:'drag-quantum-reactor',21,8,''
MEMBER:'instr-start',0,0,128,5,7,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-tunnel',-1,0,1,3,3,0,0
MEMBER:'feature-tunnel',-1,0,1,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-sensor',-1,0,1,6,0,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-arrow',-90,0,64,6,7,0,0
MEMBER:'instr-input',-1,0,128,6,7,0,0
MEMBER:'instr-swap',-1,0,128,6,6,0,0
MEMBER:'instr-grab',-1,1,128,6,5,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-sensor',-90,0,128,6,2,0,6
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-grab',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,2,128,5,1,0,0
MEMBER:'instr-arrow',-90,0,64,4,1,0,0
MEMBER:'instr-sensor',90,0,128,4,1,0,201
MEMBER:'instr-arrow',0,0,64,4,0,0,0
MEMBER:'instr-arrow',0,0,64,4,3,0,0
MEMBER:'instr-grab',-1,1,128,5,3,0,0
MEMBER:'instr-arrow',-90,0,64,7,3,0,0
MEMBER:'instr-arrow',0,0,64,7,1,0,0
MEMBER:'instr-arrow',90,0,64,8,1,0,0
MEMBER:'instr-arrow',180,0,64,8,7,0,0
MEMBER:'instr-arrow',180,0,64,9,7,0,0
MEMBER:'instr-arrow',90,0,64,9,0,0,0
MEMBER:'instr-rotate',-1,0,128,9,3,0,0
MEMBER:'instr-rotate',-1,0,128,8,0,0,0
MEMBER:'instr-grab',-1,1,128,7,1,0,0
MEMBER:'instr-output',-1,1,128,8,6,0,0
MEMBER:'instr-grab',-1,2,128,8,5,0,0
MEMBER:'instr-grab',-1,1,128,5,0,0,0
MEMBER:'instr-grab',-1,2,128,7,7,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-quantum-reactor',4,7,''
MEMBER:'instr-start',-90,0,128,0,5,0,0
MEMBER:'instr-start',-90,0,32,7,5,0,0
MEMBER:'feature-tunnel',-1,0,1,4,1,0,0
MEMBER:'feature-tunnel',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,7,0,0
MEMBER:'feature-sensor',-1,0,1,0,7,0,0
MEMBER:'instr-input',-1,0,128,0,3,0,0
MEMBER:'instr-grab',-1,1,128,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-grab',-1,1,32,6,3,0,0
MEMBER:'instr-swap',-1,0,128,1,1,0,0
MEMBER:'instr-swap',-1,0,128,2,1,0,0
MEMBER:'instr-swap',-1,0,128,3,1,0,0
MEMBER:'instr-swap',-1,0,128,4,1,0,0
MEMBER:'instr-arrow',180,0,64,4,7,0,0
MEMBER:'instr-arrow',-90,0,64,0,7,0,0
MEMBER:'instr-output',-1,0,32,5,4,0,0
MEMBER:'instr-output',-1,0,32,5,7,0,0
MEMBER:'instr-grab',-1,2,32,7,7,0,0
MEMBER:'instr-bond',-1,0,32,6,7,0,0
MEMBER:'instr-arrow',-90,0,16,7,7,0,0
MEMBER:'instr-arrow',180,0,16,7,3,0,0
MEMBER:'instr-arrow',90,0,16,5,3,0,0
MEMBER:'instr-output',-1,1,128,0,4,0,0
MEMBER:'instr-sync',-1,0,32,7,4,0,0
MEMBER:'instr-sync',-1,0,128,4,4,0,0
MEMBER:'instr-sync',-1,0,128,0,2,0,0
MEMBER:'instr-output',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,4,0,0,0
MEMBER:'instr-arrow',0,0,64,3,0,0,0
MEMBER:'instr-arrow',0,0,16,5,7,0,0
MEMBER:'instr-arrow',-90,0,64,3,2,0,0
MEMBER:'instr-output',-1,0,128,3,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,4,12
PIPE:1,4,13
PIPE:1,5,13
PIPE:1,6,13
PIPE:1,7,13
PIPE:1,8,13
PIPE:1,9,13
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,3,-1
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-3,-1
PIPE:0,-3,-2
PIPE:0,-3,-3
PIPE:0,-3,-4
PIPE:1,10,13
ANNOTATION:0,1,23,-85,'0,3:0,201;\n\r\n\r\n\r'
ANNOTATION:1,1,42,165,'\n\r\n\r\n\r'
COMPONENT:'drag-quantum-reactor',2,2,''
MEMBER:'instr-start',180,0,128,3,6,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-tunnel',-1,0,1,0,3,0,0
MEMBER:'feature-tunnel',-1,0,1,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,6,6,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,6,0,0
MEMBER:'feature-sensor',-1,0,1,0,4,0,0
MEMBER:'instr-output',-1,0,32,0,7,0,0
MEMBER:'instr-input',-1,1,128,2,6,0,0
MEMBER:'instr-grab',-1,1,128,1,6,0,0
MEMBER:'instr-swap',-1,0,128,0,3,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-swap',-1,0,128,1,3,0,0
MEMBER:'instr-sensor',-90,0,128,0,5,0,6
MEMBER:'instr-arrow',180,0,64,2,6,0,0
MEMBER:'instr-arrow',-90,0,64,0,6,0,0
MEMBER:'instr-grab',-1,2,128,0,6,0,0
MEMBER:'instr-grab',-1,1,128,0,4,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',180,0,64,1,6,0,0
MEMBER:'instr-grab',-1,2,128,1,4,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-arrow',90,0,64,2,5,0,0
MEMBER:'instr-output',-1,0,128,0,2,0,0
MEMBER:'instr-output',-1,0,128,1,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
ANNOTATION:0,1,568,-66,'3,3:0,6;\n\r3,3:0,201;\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-spaceship-input',1,14,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-1,-2
PIPE:0,-1,-3
PIPE:0,-1,-4
PIPE:0,-1,-5
PIPE:0,-1,-6
PIPE:0,-1,-7
PIPE:0,-1,-8
PIPE:0,-1,-9
PIPE:0,-1,-10
PIPE:0,0,-10
COMPONENT:'drag-spaceship-input',1,7,''
PIPE:0,2,0
PIPE:0,2,1""",
    """SOLUTION:Collapsar,ToughThought,3297-2-74,depends on quantum pipe rate limit
COMPONENT:'drag-quantum-reactor',21,8,''
MEMBER:'instr-start',90,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,8,2,0,0
MEMBER:'feature-tunnel',-1,0,1,5,3,0,0
MEMBER:'feature-tunnel',-1,0,1,0,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-sensor',-1,0,1,7,7,0,0
MEMBER:'instr-grab',-1,1,32,5,3,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-grab',-1,1,128,5,3,0,0
MEMBER:'instr-bond',-1,0,128,6,3,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-arrow',-90,0,16,7,3,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-arrow',-90,0,64,5,5,0,0
MEMBER:'instr-input',-1,0,128,5,5,0,0
MEMBER:'instr-swap',-1,0,128,5,4,0,0
MEMBER:'instr-input',-1,0,32,6,2,0,0
MEMBER:'instr-swap',-1,0,32,5,2,0,0
MEMBER:'instr-sensor',90,0,128,6,5,0,201
MEMBER:'instr-output',-1,1,128,5,6,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-grab',-1,1,128,0,3,0,0
MEMBER:'instr-grab',-1,2,128,1,3,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-arrow',180,0,64,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,5,6,0,0
MEMBER:'instr-bond',-1,0,128,6,6,0,0
MEMBER:'instr-sensor',180,0,32,6,3,0,201
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-swap',-1,0,128,4,3,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-quantum-reactor',7,2,''
MEMBER:'instr-start',180,0,128,5,2,0,0
MEMBER:'instr-start',-90,0,32,9,5,0,0
MEMBER:'feature-tunnel',-1,0,1,1,2,0,0
MEMBER:'feature-tunnel',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-sensor',-1,0,1,1,1,0,0
MEMBER:'instr-grab',-1,1,32,6,3,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-sync',-1,0,32,9,3,0,0
MEMBER:'instr-swap',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',-90,0,16,5,4,0,0
MEMBER:'instr-swap',-1,0,128,2,0,0,0
MEMBER:'instr-swap',-1,0,128,0,1,0,0
MEMBER:'instr-arrow',-90,0,16,9,4,0,0
MEMBER:'instr-arrow',90,0,64,0,2,0,0
MEMBER:'instr-grab',-1,1,128,0,5,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-rotate',-1,1,128,1,5,0,0
MEMBER:'instr-input',-1,1,128,0,4,0,0
MEMBER:'instr-sync',-1,0,128,0,3,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-swap',-1,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,5,4,0,0
MEMBER:'instr-output',-1,0,32,5,3,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-sensor',90,0,128,2,1,0,6
MEMBER:'instr-arrow',-90,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,2,0,0,0
MEMBER:'instr-input',-1,0,32,8,3,0,0
MEMBER:'instr-grab',-1,1,128,1,0,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-grab',-1,2,128,0,0,0,0
MEMBER:'instr-arrow',180,0,64,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-output',-1,1,32,8,2,0,0
MEMBER:'instr-arrow',180,0,64,2,2,0,0
MEMBER:'instr-arrow',180,0,16,6,4,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-arrow',0,0,16,7,4,0,0
MEMBER:'instr-swap',-1,0,128,1,4,0,0
MEMBER:'instr-output',-1,0,32,8,4,0,0
MEMBER:'instr-swap',-1,0,128,1,3,0,0
MEMBER:'instr-swap',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',180,0,16,9,2,0,0
MEMBER:'instr-arrow',90,0,16,6,2,0,0
MEMBER:'instr-grab',-1,2,32,7,4,0,0
MEMBER:'instr-sensor',90,0,32,7,3,0,6
MEMBER:'instr-bond',-1,0,32,9,2,0,0
MEMBER:'instr-arrow',180,0,16,8,3,0,0
MEMBER:'instr-output',-1,0,32,9,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,4,12
PIPE:1,4,13
PIPE:1,4,14
PIPE:1,4,15
PIPE:1,4,16
PIPE:1,4,17
PIPE:1,4,18
PIPE:1,5,18
PIPE:0,5,1
PIPE:0,6,1
PIPE:1,6,18
PIPE:1,7,18
COMPONENT:'drag-spaceship-input',1,7,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,3,-3
PIPE:0,4,-3
PIPE:0,5,-3
COMPONENT:'drag-spaceship-input',1,14,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,5,-1
PIPE:0,5,-2
PIPE:0,5,-3
PIPE:0,5,-4
PIPE:0,5,-5
PIPE:0,5,-6
PIPE:0,5,-7
PIPE:0,5,-8
PIPE:0,5,-9
PIPE:0,5,-10
PIPE:0,5,-11""",
    r"""SOLUTION:Head or Tails?,Team 89.1 bugfix,185-1-17,Double 0-count outputs
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,32,2,7,0,0
MEMBER:'instr-start',180,0,128,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,6,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-sensor',-1,0,1,6,7,0,0
MEMBER:'feature-tunnel',-1,0,1,9,0,0,0
MEMBER:'feature-tunnel',-1,0,1,0,0,0,0
MEMBER:'instr-grab',-1,0,32,2,1,0,0
MEMBER:'instr-input',-1,1,32,2,3,0,0
MEMBER:'instr-arrow',180,0,16,9,1,0,0
MEMBER:'instr-arrow',-90,0,16,9,7,0,0
MEMBER:'instr-grab',-1,2,32,9,7,0,0
MEMBER:'instr-arrow',0,0,16,2,7,0,0
MEMBER:'instr-rotate',-1,1,32,3,6,0,0
MEMBER:'instr-rotate',-1,1,32,2,6,0,0
MEMBER:'instr-bond',-1,0,128,0,7,0,0
MEMBER:'instr-arrow',90,0,16,2,1,0,0
MEMBER:'instr-grab',-1,0,32,3,5,0,0
MEMBER:'instr-input',-1,0,32,3,1,0,0
MEMBER:'instr-sensor',180,0,32,9,6,0,6
MEMBER:'instr-output',-1,1,32,8,6,0,0
MEMBER:'instr-arrow',180,0,16,3,1,0,0
MEMBER:'instr-toggle',-90,0,32,3,7,0,0
MEMBER:'instr-rotate',-1,1,32,6,7,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    r"""SOLUTION:Continuous Flow Test,Zig,4-0-0""",

    r'''SOLUTION:Exploding Head Syndrome,vpumeyyv,4106-3-36,success
COMPONENT:'drag-fusion-reactor',5,12,''
MEMBER:'instr-start',180,0,128,2,4,0,0
MEMBER:'instr-start',-90,0,32,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,0,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-fuser',-1,0,1,5,4,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-input',-1,1,128,0,4,0,0
MEMBER:'instr-grab',-1,1,128,1,4,0,0
MEMBER:'instr-arrow',180,0,64,5,4,0,0
MEMBER:'instr-fuse',-1,0,128,5,4,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-grab',-1,1,32,2,2,0,0
MEMBER:'instr-input',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',-90,0,16,2,4,0,0
MEMBER:'instr-output',-1,1,32,4,4,0,0
MEMBER:'instr-output',-1,0,32,5,4,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-bond',-1,1,32,7,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,4,-4
PIPE:0,4,-5
PIPE:0,4,-6
PIPE:0,4,-7
PIPE:0,4,-8
PIPE:0,4,-9
PIPE:0,5,-9
PIPE:0,6,-9
PIPE:0,7,-9
PIPE:0,8,-9
PIPE:0,9,-9
PIPE:0,10,-9
PIPE:0,11,-9
PIPE:0,12,-9
PIPE:0,12,-8
PIPE:0,11,-8
PIPE:0,10,-8
PIPE:0,9,-8
PIPE:0,8,-8
PIPE:0,7,-8
PIPE:0,6,-8
PIPE:0,5,-8
PIPE:0,5,-7
PIPE:0,6,-7
PIPE:0,7,-7
PIPE:0,8,-7
PIPE:0,9,-7
PIPE:0,10,-7
PIPE:0,11,-7
PIPE:0,12,-7
PIPE:0,12,-6
PIPE:0,11,-6
PIPE:0,10,-6
PIPE:0,9,-6
PIPE:0,8,-6
PIPE:0,7,-6
PIPE:0,6,-6
PIPE:0,5,-6
PIPE:0,5,-5
PIPE:0,5,-4
PIPE:0,6,-4
ANNOTATION:0,1,-413,-201,'1,3:0,8;0,3:0,1;\n0,3,1:1;\r\n\r\n\r'
ANNOTATION:1,1,-419,-256,'0,0:0,0;\n\r\n\r\n\r'
COMPONENT:'drag-oceanic-input',5,18,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-2,-2
PIPE:0,-2,-3
PIPE:0,-2,-4
PIPE:0,-2,-5
PIPE:0,-1,-5
COMPONENT:'drag-advanced-reactor',10,12,''
MEMBER:'instr-start',180,0,128,1,7,0,0
MEMBER:'instr-start',180,0,32,8,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,7,0,0
MEMBER:'feature-bonder',-1,0,1,4,7,0,0
MEMBER:'feature-bonder',-1,0,1,3,7,0,0
MEMBER:'feature-sensor',-1,0,1,6,4,0,0
MEMBER:'instr-input',-1,1,128,0,7,0,0
MEMBER:'instr-arrow',90,0,16,0,3,0,0
MEMBER:'instr-arrow',0,0,16,0,4,0,0
MEMBER:'instr-grab',-1,1,32,0,4,0,0
MEMBER:'instr-output',-1,0,32,5,3,0,0
MEMBER:'instr-output',-1,1,32,5,4,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-sensor',-90,0,32,6,4,0,94
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-grab',-1,2,32,7,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,2
PIPE:0,5,3
PIPE:0,5,4
PIPE:0,5,5
PIPE:0,6,5
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-2,4
PIPE:1,-3,4
PIPE:1,-4,4
PIPE:1,-5,4
PIPE:1,-6,4
PIPE:1,-6,3
PIPE:1,-6,2
ANNOTATION:0,1,-419,-358,'1,1:0,1;\n\r\n\r\n\r'
ANNOTATION:1,1,189,-40,'1,0:0,0;\n\r\n\r\n\r'
COMPONENT:'drag-fusion-reactor',12,7,''
MEMBER:'instr-start',90,0,128,8,2,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-fuser',-1,0,1,4,0,0,0
MEMBER:'instr-arrow',0,0,64,0,3,0,0
MEMBER:'instr-grab',-1,1,128,0,3,0,0
MEMBER:'instr-rotate',-1,0,128,1,3,0,0
MEMBER:'instr-output',-1,0,128,2,3,0,0
MEMBER:'instr-output',-1,1,128,3,3,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-arrow',180,0,64,8,3,0,0
MEMBER:'instr-input',-1,0,128,8,3,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,4,4
PIPE:0,4,5
PIPE:0,4,6
PIPE:0,4,7
PIPE:0,4,8
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,8,3
PIPE:1,8,4
PIPE:1,8,5
PIPE:1,8,6
PIPE:1,8,7
PIPE:1,8,8
PIPE:1,8,9
PIPE:1,8,10
PIPE:1,8,11
PIPE:1,7,11
PIPE:1,6,11
PIPE:1,5,11
PIPE:1,4,11
PIPE:1,4,10
PIPE:1,4,9
''',

r'''SOLUTION:A Most Unfortunate Malfunction,Ephedra,2713-2-55
COMPONENT:'drag-oceanic-input',1,16,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
COMPONENT:'drag-starter-reactor',22,17,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,2,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-sync',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,8,2,0,0
MEMBER:'instr-output',-1,0,128,8,1,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,8,1,0,0
MEMBER:'instr-arrow',180,0,16,8,6,0,0
MEMBER:'instr-sync',-1,0,32,2,6,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-grab',-1,2,32,8,5,0,0
MEMBER:'instr-output',-1,1,32,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,6,0,0
MEMBER:'instr-rotate',-1,0,128,2,3,0,0
MEMBER:'instr-rotate',-1,1,32,5,1,0,0
MEMBER:'instr-rotate',-1,1,128,4,6,0,0
MEMBER:'instr-rotate',-1,0,128,5,6,0,0
MEMBER:'instr-rotate',-1,0,32,6,1,0,0
MEMBER:'instr-arrow',90,0,16,3,1,0,0
MEMBER:'instr-arrow',0,0,16,3,5,0,0
MEMBER:'instr-arrow',-90,0,16,4,5,0,0
MEMBER:'instr-arrow',0,0,16,4,1,0,0
MEMBER:'instr-arrow',0,0,16,6,1,0,0
MEMBER:'instr-sync',-1,0,32,5,6,0,0
MEMBER:'instr-sync',-1,0,128,6,6,0,0
MEMBER:'instr-arrow',90,0,16,5,1,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-arrow',-90,0,16,6,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,3,-2
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,0,-2
PIPE:0,-1,-2
PIPE:0,-2,-2
PIPE:0,-2,-1
PIPE:0,-2,0
PIPE:0,-2,1
PIPE:0,-2,2
PIPE:0,-3,2
PIPE:0,-4,2
PIPE:0,-5,2
PIPE:0,-5,1
PIPE:0,-5,0
PIPE:0,-5,-1
PIPE:0,-5,-2
PIPE:0,-5,-3
PIPE:0,-5,-4
PIPE:1,5,2
PIPE:1,5,1
PIPE:1,5,0
PIPE:1,5,-1
PIPE:1,4,-1
PIPE:1,3,-1
PIPE:1,2,-1
PIPE:1,1,-1
PIPE:1,0,-1
PIPE:1,-1,-1
PIPE:1,-2,-1
PIPE:1,-3,-1
PIPE:1,-4,-1
PIPE:1,-4,-2
PIPE:1,-5,-2
PIPE:1,-6,-2
PIPE:1,-7,-2
PIPE:1,-8,-2
PIPE:1,-9,-2
PIPE:1,-10,-2
PIPE:1,-11,-2
PIPE:1,-11,-3
PIPE:1,-11,-4
COMPONENT:'drag-starter-reactor',7,15,''
MEMBER:'instr-start',180,0,128,5,1,0,0
MEMBER:'instr-start',180,0,32,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,8,1,0,0
MEMBER:'instr-output',-1,0,128,7,1,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,8,1,0,0
MEMBER:'instr-arrow',180,0,16,8,5,0,0
MEMBER:'instr-input',-1,0,32,2,4,0,0
MEMBER:'instr-sync',-1,0,32,2,5,0,0
MEMBER:'instr-sync',-1,0,128,6,1,0,0
MEMBER:'instr-sync',-1,0,32,4,5,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-grab',-1,2,32,8,5,0,0
MEMBER:'instr-output',-1,1,32,7,5,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',180,0,16,6,5,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,8,3,0,0
MEMBER:'instr-sync',-1,0,128,6,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,9,2
PIPE:0,9,3
PIPE:0,10,3
PIPE:0,11,3
PIPE:0,12,3
PIPE:0,13,3
PIPE:0,14,3
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,9,2
PIPE:1,10,2
PIPE:1,11,2
PIPE:1,12,2
PIPE:1,13,2
PIPE:1,14,2
PIPE:1,14,1
PIPE:1,14,0
PIPE:1,14,-1
PIPE:1,14,-2
PIPE:1,15,-2
PIPE:1,16,-2
''',

r'''SOLUTION:No Need for Introductions,darkid stole this from someone but doesn't remember who,3785-2-26,Speedrun Solution
COMPONENT:'drag-advanced-reactor',11,10,''
MEMBER:'instr-start',180,0,128,5,1,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,3,2,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-sensor',-1,0,1,4,4,0,0
MEMBER:'instr-grab',-1,0,128,4,1,0,0
MEMBER:'instr-grab',-1,0,128,8,1,0,0
MEMBER:'instr-arrow',90,0,64,8,1,0,0
MEMBER:'instr-output',-1,0,128,8,2,0,0
MEMBER:'instr-input',-1,1,128,8,4,0,0
MEMBER:'instr-arrow',180,0,64,8,4,0,0
MEMBER:'instr-output',-1,1,128,7,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-sensor',-90,0,128,4,4,0,1
MEMBER:'instr-grab',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-input',-1,0,128,4,3,0,0
MEMBER:'instr-grab',-1,0,128,4,2,0,0
MEMBER:'instr-arrow',0,0,64,4,1,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-advanced-reactor',11,16,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,3,0,0
MEMBER:'feature-bonder',-1,0,1,9,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-sensor',-1,0,1,4,2,0,0
MEMBER:'instr-bond',-1,1,128,0,1,0,0
MEMBER:'instr-input',-1,1,32,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,6,0,0
MEMBER:'instr-grab',-1,0,32,1,5,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-output',-1,0,32,8,3,0,0
MEMBER:'instr-output',-1,1,32,9,3,0,0
MEMBER:'instr-arrow',90,0,16,9,3,0,0
MEMBER:'instr-grab',-1,0,32,9,4,0,0
MEMBER:'instr-output',-1,1,32,9,5,0,0
MEMBER:'instr-arrow',180,0,16,9,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,3,-1
PIPE:0,2,-1
PIPE:0,1,-1
PIPE:0,0,-1
PIPE:0,-1,-1
PIPE:0,-2,-1
PIPE:0,-2,-2
PIPE:0,-2,-3
PIPE:0,-2,-4
PIPE:0,-2,-5
PIPE:0,-1,-5
PIPE:1,5,2
PIPE:1,5,1
PIPE:1,5,0
PIPE:1,5,-1
PIPE:1,5,-2
PIPE:1,4,-2
PIPE:1,3,-2
PIPE:1,2,-2
PIPE:1,1,-2
PIPE:1,0,-2
PIPE:1,-1,-2
PIPE:1,-1,-3
PIPE:1,-1,-4
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-oceanic-input',8,18,''
PIPE:0,2,0
''',

r'''SOLUTION:No Need for Introductions,Myriadtail,4649-4-98,Myriadtail-4649-4-98
COMPONENT:'drag-oceanic-input',8,18,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,1,-2
PIPE:0,0,-2
PIPE:0,0,-3
PIPE:0,0,-4
COMPONENT:'drag-advanced-reactor',9,12,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'feature-bonder',-1,0,1,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,5,0,0
MEMBER:'feature-sensor',-1,0,1,4,3,0,0
MEMBER:'instr-input',-1,1,32,3,5,0,0
MEMBER:'instr-grab',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-sensor',90,0,32,4,2,0,92
MEMBER:'instr-arrow',0,0,16,4,3,0,0
MEMBER:'instr-sensor',90,0,32,5,3,0,92
MEMBER:'instr-arrow',0,0,16,5,4,0,0
MEMBER:'instr-arrow',90,0,16,8,4,0,0
MEMBER:'instr-bond',-1,1,32,8,5,0,0
MEMBER:'instr-arrow',0,0,16,8,5,0,0
MEMBER:'instr-arrow',-90,0,16,9,5,0,0
MEMBER:'instr-arrow',-90,0,16,9,3,0,0
MEMBER:'instr-arrow',-90,0,16,9,2,0,0
MEMBER:'instr-arrow',180,0,16,9,1,0,0
MEMBER:'instr-grab',-1,2,32,8,1,0,0
MEMBER:'instr-output',-1,1,32,9,5,0,0
MEMBER:'instr-output',-1,0,32,7,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-arrow',180,0,16,6,5,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',90,0,64,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,7,0,0
MEMBER:'instr-grab',-1,2,128,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,6,7,0,0
MEMBER:'instr-output',-1,1,128,6,5,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,4,-4
PIPE:0,3,-4
PIPE:0,2,-4
PIPE:0,1,-4
PIPE:0,0,-4
PIPE:0,-1,-4
PIPE:0,-2,-4
PIPE:0,-3,-4
PIPE:0,-3,-5
PIPE:0,-4,-5
PIPE:0,-5,-5
PIPE:0,-6,-5
PIPE:0,-6,-6
PIPE:0,-6,-7
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,6,1
PIPE:1,6,0
COMPONENT:'drag-advanced-reactor',4,3,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,8,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-sensor',-1,0,1,2,5,0,0
MEMBER:'instr-input',-1,1,32,3,5,0,0
MEMBER:'instr-grab',-1,1,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-sensor',0,0,32,2,4,0,92
MEMBER:'instr-bond',-1,1,32,8,4,0,0
MEMBER:'instr-arrow',-90,0,16,8,4,0,0
MEMBER:'instr-output',-1,1,32,8,3,0,0
MEMBER:'instr-grab',-1,2,32,8,1,0,0
MEMBER:'instr-arrow',0,0,16,8,1,0,0
MEMBER:'instr-arrow',90,0,16,9,1,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-arrow',180,0,16,9,5,0,0
MEMBER:'instr-output',-1,0,32,9,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
COMPONENT:'drag-advanced-reactor',9,3,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',0,0,32,0,6,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,6,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-sensor',-1,0,1,4,3,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,4,1,0,0
MEMBER:'instr-sensor',180,0,128,4,2,0,1
MEMBER:'instr-arrow',0,0,64,4,3,0,0
MEMBER:'instr-sensor',-90,0,128,5,3,0,1
MEMBER:'instr-arrow',0,0,64,5,1,0,0
MEMBER:'instr-arrow',-90,0,64,8,1,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,8,5,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-arrow',0,0,64,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,8,4,0,0
MEMBER:'instr-grab',-1,2,128,8,1,0,0
MEMBER:'instr-output',-1,0,128,8,0,0,0
MEMBER:'instr-bond',-1,1,128,2,5,0,0
MEMBER:'instr-sync',-1,0,32,1,6,0,0
MEMBER:'instr-sync',-1,0,128,4,5,0,0
MEMBER:'instr-grab',-1,1,32,2,6,0,0
MEMBER:'instr-arrow',-90,0,16,6,6,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-arrow',180,0,16,6,4,0,0
MEMBER:'instr-arrow',90,0,16,1,4,0,0
MEMBER:'instr-arrow',0,0,16,1,6,0,0
MEMBER:'instr-output',-1,1,32,5,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-output',-1,1,128,7,4,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-advanced-reactor',14,3,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',-90,0,32,0,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-sensor',-1,0,1,4,2,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-rotate',-1,0,128,2,2,0,0
MEMBER:'instr-grab',-1,2,128,8,2,0,0
MEMBER:'instr-arrow',-90,0,64,8,2,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-input',-1,1,32,0,5,0,0
MEMBER:'instr-grab',-1,1,32,0,4,0,0
MEMBER:'instr-arrow',0,0,16,0,4,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-arrow',90,0,16,6,4,0,0
MEMBER:'instr-arrow',180,0,16,6,5,0,0
MEMBER:'instr-arrow',-90,0,16,0,5,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-rotate',-1,1,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-bond',-1,0,128,8,3,0,0
MEMBER:'instr-output',-1,0,128,9,3,0,0
MEMBER:'instr-arrow',-90,0,64,9,3,0,0
MEMBER:'instr-arrow',180,0,64,9,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,5,2
PIPE:0,5,3
PIPE:0,5,4
PIPE:0,5,5
PIPE:0,5,6
PIPE:0,5,7
PIPE:0,4,7
PIPE:0,3,7
PIPE:0,2,7
PIPE:0,1,7
PIPE:0,1,8
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-2,4
PIPE:1,-3,4
PIPE:1,-4,4
PIPE:1,-5,4
PIPE:1,-5,5
PIPE:1,-5,6
PIPE:1,-5,7
COMPONENT:'drag-storage-tank',10,9,''
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,4,2
PIPE:0,4,3
PIPE:0,4,4
PIPE:0,4,5
PIPE:0,4,6
PIPE:0,5,6
COMPONENT:'drag-storage-tank',16,14,''
PIPE:0,3,1
PIPE:0,3,2
PIPE:0,3,3
PIPE:0,2,3
PIPE:0,1,3
PIPE:0,0,3
PIPE:0,-1,3
PIPE:0,-2,3
PIPE:0,-3,3
PIPE:0,-3,4
PIPE:0,-3,5
COMPONENT:'drag-storage-tank',14,18,''
PIPE:0,3,1
''',
]

missing_score = [
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,Valid but missing score
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,1,1,0,0
MEMBER:'instr-output',-1,0,32,0,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0''',
]

wrong_score = [
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,114-1-6,Wrong cycle count
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,1,1,0,0
MEMBER:'instr-output',-1,0,32,0,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,115-0-6,Wrong reactor count
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,1,1,0,0
MEMBER:'instr-output',-1,0,32,0,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,115-1-5,Wrong symbol count
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,1,1,0,0
MEMBER:'instr-output',-1,0,32,0,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,7,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0''',
]

infinite_loops = [
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,107-1-7,simple_infinite_loop
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r"""SOLUTION:Head or Tails?,Zig,0-0-0,Infinite loop with double 0-count outputs""",
]

invalid_outputs = [
    # Solution which completes successfully unless the disabled output correctly causes a crash
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,disabled output crash
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,0,3,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-output',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Swapite,Zig,0-0-0,invalid_isomorphism
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'feature-bonder',-1,0,1,4,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-tunnel',-1,0,1,2,4,0,0
MEMBER:'feature-tunnel',-1,0,1,3,4,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,8,1,0,0
MEMBER:'instr-output',-1,0,128,7,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
]

# TODO: Add tests for:
#     * move-collision with atoms moving into cell of moving atom
#     * rotate-collision between two rotating molecules (that wouldn't collide if rotates weren't at once)
runtime_collisions = [
    # Solution where blue causes a crash after red does the 10th output. Intended to crash in v1013+
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,last_cycle_crash
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,0,0,0,0
MEMBER:'instr-start',0,0,32,0,0,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
MEMBER:'instr-input',-1,0,32,9,3,0,0
MEMBER:'instr-input',-1,0,32,9,2,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-sync',-1,0,128,7,1,0,0
MEMBER:'instr-output',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-sync',-1,0,32,4,0,0,0
MEMBER:'instr-sync',-1,0,32,2,0,0,0
MEMBER:'instr-sync',-1,0,32,3,0,0,0
MEMBER:'instr-sync',-1,0,32,1,0,0,0
MEMBER:'instr-sync',-1,0,32,6,0,0,0
MEMBER:'instr-sync',-1,0,32,7,0,0,0
MEMBER:'instr-sync',-1,0,32,8,0,0,0
MEMBER:'instr-sync',-1,0,32,9,0,0,0
MEMBER:'instr-arrow',90,0,16,9,0,0,0
MEMBER:'instr-sync',-1,0,32,9,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    # Narrow molecule collision
    r'''SOLUTION:TestMoleculeCollisions,Zig,33-1-57,'7x3 past (5,5) (collision)'
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,0,0,0
MEMBER:'feature-bonder',-1,0,1,8,0,0,0
MEMBER:'feature-bonder',-1,0,1,9,0,0,0
MEMBER:'feature-bonder',-1,0,1,9,1,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-bond',-1,0,32,0,5,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
MEMBER:'instr-arrow',0,0,16,0,7,0,0
MEMBER:'instr-bond',-1,0,32,1,7,0,0
MEMBER:'instr-bond',-1,0,32,1,6,0,0
MEMBER:'instr-bond',-1,0,32,0,4,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-input',-1,0,128,4,3,0,0
MEMBER:'instr-input',-1,0,128,5,3,0,0
MEMBER:'instr-input',-1,0,128,6,3,0,0
MEMBER:'instr-arrow',90,0,64,8,3,0,0
MEMBER:'instr-rotate',-1,0,128,6,7,0,0
MEMBER:'instr-input',-1,0,128,7,3,0,0
MEMBER:'instr-bond',-1,0,32,1,5,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-arrow',180,0,64,8,7,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-bond',-1,0,32,0,3,0,0
MEMBER:'instr-arrow',-90,0,16,1,7,0,0
MEMBER:'instr-arrow',-90,0,64,6,7,0,0
MEMBER:'instr-arrow',180,0,16,1,0,0,0
MEMBER:'instr-arrow',90,0,16,0,0,0,0
MEMBER:'instr-toggle',0,0,32,0,2,0,0
MEMBER:'instr-grab',-1,2,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,6,1,0,0
MEMBER:'instr-arrow',0,0,64,6,6,0,0
MEMBER:'instr-grab',-1,2,128,6,6,0,0
MEMBER:'instr-grab',-1,1,128,8,6,0,0
MEMBER:'instr-arrow',-90,0,64,9,6,0,0
MEMBER:'instr-bond',-1,1,128,9,6,0,0
MEMBER:'instr-arrow',90,0,16,2,2,0,0
MEMBER:'instr-arrow',0,0,16,2,4,0,0
MEMBER:'instr-arrow',-90,0,16,6,4,0,0
MEMBER:'instr-output',-1,0,32,2,4,0,0
MEMBER:'instr-output',-1,0,32,3,4,0,0
MEMBER:'instr-output',-1,0,32,4,4,0,0
MEMBER:'instr-output',-1,0,32,5,4,0,0
MEMBER:'instr-output',-1,0,32,6,4,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-bond',-1,1,128,9,5,0,0
MEMBER:'instr-bond',-1,1,128,9,4,0,0
MEMBER:'instr-bond',-1,1,128,9,3,0,0
MEMBER:'instr-bond',-1,1,128,9,1,0,0
MEMBER:'instr-grab',-1,2,128,9,0,0,0
MEMBER:'instr-arrow',90,0,64,9,0,0,0
MEMBER:'instr-bond',-1,1,128,9,2,0,0
MEMBER:'instr-grab',-1,0,32,1,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    """SOLUTION:Collapsar,12345ieee,0-0-0,Crash during win animation
COMPONENT:'drag-quantum-reactor',21,8,''
MEMBER:'instr-start',-90,0,128,9,6,0,0
MEMBER:'instr-start',90,0,32,8,0,0,0
MEMBER:'feature-tunnel',-1,0,1,1,2,0,0
MEMBER:'feature-tunnel',-1,0,1,8,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-sensor',-1,0,1,6,7,0,0
MEMBER:'instr-grab',-1,1,32,8,3,0,0
MEMBER:'instr-arrow',180,0,16,8,3,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-arrow',-90,0,16,6,3,0,0
MEMBER:'instr-arrow',0,0,16,6,1,0,0
MEMBER:'instr-arrow',90,0,16,8,1,0,0
MEMBER:'instr-input',-1,0,32,8,1,0,0
MEMBER:'instr-swap',-1,0,32,8,2,0,0
MEMBER:'instr-grab',-1,1,128,8,3,0,0
MEMBER:'instr-arrow',180,0,64,9,3,0,0
MEMBER:'instr-input',-1,0,128,9,4,0,0
MEMBER:'instr-swap',-1,0,128,9,3,0,0
MEMBER:'instr-bond',-1,0,128,7,3,0,0
MEMBER:'instr-arrow',90,0,64,7,3,0,0
MEMBER:'instr-grab',-1,2,128,7,4,0,0
MEMBER:'instr-arrow',0,0,64,7,5,0,0
MEMBER:'instr-arrow',-90,0,64,9,5,0,0
MEMBER:'instr-sync',-1,0,32,7,3,0,0
MEMBER:'instr-sync',-1,0,128,9,5,0,0
MEMBER:'instr-sensor',90,0,128,7,5,0,201
MEMBER:'instr-arrow',0,0,64,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,9,6,0,0
MEMBER:'instr-bond',-1,0,128,7,6,0,0
MEMBER:'instr-output',-1,1,128,8,6,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-quantum-reactor',4,5,''
MEMBER:'instr-start',90,0,128,0,1,0,0
MEMBER:'instr-start',180,0,32,9,2,0,0
MEMBER:'feature-tunnel',-1,0,1,3,5,0,0
MEMBER:'feature-tunnel',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,7,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-sensor',-1,0,1,3,2,0,0
MEMBER:'instr-input',-1,1,128,0,2,0,0
MEMBER:'instr-grab',-1,0,128,0,5,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-swap',-1,0,128,1,5,0,0
MEMBER:'instr-swap',-1,0,128,2,5,0,0
MEMBER:'instr-swap',-1,0,128,3,5,0,0
MEMBER:'instr-arrow',180,0,64,3,2,0,0
MEMBER:'instr-arrow',90,0,64,0,2,0,0
MEMBER:'instr-grab',-1,0,32,7,2,0,0
MEMBER:'instr-arrow',0,0,16,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,8,4,0,0
MEMBER:'instr-arrow',180,0,16,8,2,0,0
MEMBER:'instr-bond',-1,0,32,7,3,0,0
MEMBER:'instr-grab',-1,0,32,7,4,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-output',-1,1,128,3,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-output',-1,0,128,1,4,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',90,0,64,2,4,0,0
MEMBER:'instr-arrow',0,0,64,2,6,0,0
MEMBER:'instr-output',-1,0,128,2,6,0,0
MEMBER:'instr-swap',-1,0,128,0,4,0,0
MEMBER:'instr-sync',-1,0,32,8,2,0,0
MEMBER:'instr-sync',-1,0,128,0,3,0,0
MEMBER:'instr-sync',-1,0,128,3,6,0,0
MEMBER:'instr-arrow',-90,0,64,3,6,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,4,12
PIPE:1,4,13
PIPE:1,4,14
PIPE:1,4,15
PIPE:1,5,15
PIPE:1,6,15
PIPE:1,7,15
PIPE:1,8,15
PIPE:1,9,15
PIPE:1,10,15
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,5,-3
PIPE:0,6,-3
PIPE:0,6,-2
PIPE:0,6,-1
PIPE:0,6,0
PIPE:0,6,1
ANNOTATION:0,1,114,130,'1,2:0,201;\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-quantum-reactor',11,5,''
MEMBER:'instr-start',90,0,128,1,3,0,0
MEMBER:'instr-start',180,0,32,9,6,0,0
MEMBER:'feature-tunnel',-1,0,1,1,2,0,0
MEMBER:'feature-tunnel',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,9,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,0,0,0
MEMBER:'feature-bonder',-1,0,1,8,0,0,0
MEMBER:'feature-bonder',-1,0,1,7,0,0,0
MEMBER:'feature-sensor',-1,0,1,5,0,0,0
MEMBER:'instr-input',-1,1,128,1,4,0,0
MEMBER:'instr-grab',-1,0,128,2,4,0,0
MEMBER:'instr-sync',-1,0,128,1,0,0,0
MEMBER:'instr-arrow',180,0,64,2,0,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',-90,0,64,2,4,0,0
MEMBER:'instr-swap',-1,0,32,7,3,0,0
MEMBER:'instr-input',-1,0,32,8,4,0,0
MEMBER:'instr-swap',-1,0,32,8,5,0,0
MEMBER:'instr-arrow',-90,0,16,6,4,0,0
MEMBER:'instr-arrow',90,0,16,8,3,0,0
MEMBER:'instr-output',-1,0,32,8,3,0,0
MEMBER:'instr-output',-1,0,32,8,6,0,0
MEMBER:'instr-arrow',0,0,16,6,3,0,0
MEMBER:'instr-sync',-1,0,32,6,4,0,0
MEMBER:'instr-sync',-1,0,128,2,3,0,0
MEMBER:'instr-swap',-1,0,128,2,2,0,0
MEMBER:'instr-swap',-1,0,128,2,0,0,0
MEMBER:'instr-input',-1,0,32,7,6,0,0
MEMBER:'instr-swap',-1,0,32,6,6,0,0
MEMBER:'instr-output',-1,0,32,6,5,0,0
MEMBER:'instr-arrow',180,0,16,8,6,0,0
MEMBER:'instr-arrow',-90,0,16,6,6,0,0
MEMBER:'instr-swap',-1,0,128,1,1,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,3,-1
PIPE:0,2,-1
PIPE:0,2,-2
ANNOTATION:0,1,349,-79,'1,2:0,6;\n\r1,2:0,201;\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
COMPONENT:'drag-spaceship-input',1,14,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,6,0
PIPE:0,7,0
PIPE:0,8,0
PIPE:0,9,0
PIPE:0,9,-1
PIPE:0,9,-2
PIPE:0,9,-3
PIPE:0,9,-4
PIPE:0,9,-5
PIPE:0,9,-6
PIPE:0,9,-7""",
]

# Solution which when run should raise PauseException on cycle 2 and complete successfully if run again
pause_then_complete = [
    r'''SOLUTION:A Brief History of SpaceChem,Zig,154-1-11,Pause then complete
COMPONENT:'drag-starter-reactor',2,0,''
MEMBER:'instr-start',180,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,2,6,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,9,6,0,0
MEMBER:'feature-bonder',-1,0,1,8,7,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-output',-1,1,32,0,6,0,0
MEMBER:'instr-input',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-bond',-1,0,128,1,4,0,0
MEMBER:'instr-input',-1,1,128,1,3,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-debug',-1,0,32,1,6,0,0
PIPE:0,4,1
PIPE:1,4,2''',
]

encounters_ctrl = [
    r'''SOLUTION:Exploding Head Syndrome,Zig,0-0-0,CTRL command encountered
COMPONENT:'drag-advanced-reactor',8,16,''
MEMBER:'instr-start',90,0,128,2,3,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'feature-bonder',-1,0,1,4,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-sensor',-1,0,1,4,2,0,0
MEMBER:'instr-control',-90,0,128,2,6,0,0
MEMBER:'instr-input',-1,1,128,2,4,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
PIPE:0,4,1
PIPE:1,4,2''']

slow_solutions = [
    r'''SOLUTION:Molecular Foundry,Andy,27878965-1-32,1R Symbols (bogosort)
COMPONENT:'drag-mining-input',1,7,''
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,6,0
PIPE:0,7,0
PIPE:0,8,0
PIPE:0,9,0
PIPE:0,10,0
PIPE:0,11,0
PIPE:0,12,0
PIPE:0,13,0
PIPE:0,14,0
PIPE:0,15,0
COMPONENT:'drag-advanced-reactor',17,6,''
MEMBER:'instr-start',180,0,32,3,0,0,0
MEMBER:'instr-start',90,0,128,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-sensor',-1,0,1,2,2,0,0
MEMBER:'instr-input',-1,0,32,2,0,0,0
MEMBER:'instr-grab',-1,1,32,1,0,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-arrow',-90,0,16,3,3,0,0
MEMBER:'instr-arrow',0,0,16,3,1,0,0
MEMBER:'instr-arrow',90,0,16,7,1,0,0
MEMBER:'instr-grab',-1,2,32,6,1,0,0
MEMBER:'instr-bond',-1,0,32,2,3,0,0
MEMBER:'instr-bond',-1,1,32,3,3,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-grab',-1,2,32,3,5,0,0
MEMBER:'instr-grab',-1,2,128,8,4,0,0
MEMBER:'instr-output',-1,1,32,3,1,0,0
MEMBER:'instr-sensor',-90,0,128,8,7,0,6
MEMBER:'instr-grab',-1,1,128,8,1,0,0
MEMBER:'instr-arrow',90,0,16,3,4,0,0
MEMBER:'instr-arrow',180,0,16,3,7,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-grab',-1,1,32,1,7,0,0
MEMBER:'instr-rotate',-1,0,32,0,2,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,6,2,0,0
MEMBER:'instr-arrow',180,0,16,6,0,0,0
MEMBER:'instr-sensor',90,0,128,8,5,0,26
MEMBER:'instr-output',-1,0,32,3,2,0,0
MEMBER:'instr-sensor',-90,0,128,8,3,0,6
MEMBER:'instr-sensor',90,0,128,8,0,0,6
MEMBER:'instr-arrow',90,0,64,8,3,0,0
MEMBER:'instr-sensor',90,0,32,1,2,0,26
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,4,12
PIPE:1,4,13
PIPE:1,5,13
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,0,0,'\n\r\n\r\n\r'
''',
]

# Solutions that should raise an exception upon initialization of a Solution object
import_errors = [
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,trailing spaces
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',0,0,32,0,2,0,0
PIPE:0,4,1
PIPE:1,4,2
    ''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,invalid pipe idx
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',0,0,32,0,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:2,4,3'''
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,Doubly-defined component
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',0,0,32,0,2,0,0
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',0,0,32,0,2,0,0''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,Missing Start cmd
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,Duplicate Start cmd
COMPONENT:'empty-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,1,0,0
MEMBER:'instr-start',0,0,128,0,2,0,0
MEMBER:'instr-start',0,0,32,0,3,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,Conflicting arrows
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,Conflicting non-arrow cmds
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-grab',-1,0,128,1,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,illegal bond instruction
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-bond',-1,1,32,0,0,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,illegal flip-flop
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-toggle',0,0,64,0,0,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,illegal CTRL instruction
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',-90,0,128,1,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-control',0,0,16,0,0,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:An Introduction to Pipelines,Zig,0-0-0,pipe out of bounds
COMPONENT:'drag-silo-input',9,4,''
PIPE:0,5,2
PIPE:0,6,2
PIPE:0,7,2
PIPE:0,8,2
PIPE:0,9,2
PIPE:0,9,3
PIPE:0,9,4
PIPE:0,9,5
PIPE:0,9,6
PIPE:0,9,7
PIPE:0,9,8
PIPE:0,9,9
PIPE:0,10,9
PIPE:0,11,9
PIPE:0,12,9
PIPE:0,13,9
COMPONENT:'drag-silo-input',8,12,''
PIPE:0,5,2
PIPE:0,6,2
PIPE:0,7,2
PIPE:0,8,2
PIPE:0,9,2
PIPE:0,10,2
PIPE:0,11,2
PIPE:0,11,1
PIPE:0,11,0
PIPE:0,11,-1
PIPE:0,11,-2
PIPE:0,11,-3
PIPE:0,11,-4
PIPE:0,11,-5
PIPE:0,11,-6
PIPE:0,11,-7
PIPE:0,11,-8
PIPE:0,11,-9
PIPE:0,11,-10
PIPE:0,11,-11
PIPE:0,11,-12
PIPE:0,11,-13
PIPE:0,12,-13
PIPE:0,12,-12
PIPE:0,12,-11
PIPE:0,12,-10
PIPE:0,12,-9
PIPE:0,12,-8
PIPE:0,12,-7
PIPE:0,12,-6
PIPE:0,12,-5
PIPE:0,13,-5
PIPE:0,14,-5''',
    r'''SOLUTION:An Introduction to Pipelines,Zig,0-0-0,terrain collision
COMPONENT:'drag-silo-input',9,4,''
PIPE:0,5,2
COMPONENT:'drag-silo-input',8,12,''
PIPE:0,5,2
PIPE:0,6,2
PIPE:0,6,3
PIPE:0,6,4
PIPE:0,6,5
''',
    r'''SOLUTION:There's Something in the Fishcake,Zig,0-0-0,Reactor out of bounds
COMPONENT:'drag-starter-reactor',-1,8,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Settling into the Routine,Zig,1613-3-26,illegal flip-flop
COMPONENT:'drag-disassembly-reactor',12,2,''
MEMBER:'instr-start',-90,0,128,2,3,0,0
MEMBER:'instr-start',180,0,32,1,6,0,0
MEMBER:'instr-toggle',0,0,64,0,0,0,0
MEMBER:'feature-bonder-minus',-1,0,1,8,1,0,0
MEMBER:'feature-bonder-minus',-1,0,1,9,1,0,0
MEMBER:'feature-bonder-minus',-1,0,1,8,7,0,0
MEMBER:'feature-bonder-minus',-1,0,1,9,6,0,0
PIPE:0,4,1
PIPE:1,4,2'''
]

wall_collisions = [
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,top_wall_move_collision
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,2,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,2,0,0
MEMBER:'instr-rotate',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',-90,0,64,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,0,0,0
MEMBER:'instr-arrow',90,0,64,3,0,0,0
MEMBER:'instr-arrow',0,0,64,3,1,0,0
MEMBER:'instr-output',-1,0,128,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,right_wall_move_collision
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,2,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',90,0,64,9,1,0,0
MEMBER:'instr-grab',-1,2,128,8,2,0,0
MEMBER:'instr-arrow',180,0,64,9,2,0,0
MEMBER:'instr-arrow',-90,0,64,1,2,0,0
MEMBER:'instr-output',-1,0,128,7,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,bottom_wall_move_collision
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',90,0,64,2,1,0,0
MEMBER:'instr-rotate',-1,1,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,7,0,0
MEMBER:'instr-arrow',-90,0,64,3,7,0,0
MEMBER:'instr-arrow',0,0,64,3,6,0,0
MEMBER:'instr-arrow',-90,0,64,6,6,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-output',-1,0,128,6,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:Of Pancakes and Spaceships,Zig,0-0-0,left_wall_move_collision
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,4,1,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-arrow',90,0,64,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-arrow',-90,0,64,7,2,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-output',-1,0,128,7,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestWallCollisionsNegative,Zig,0-0-0,rotate_collide_top_wall
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,1,3,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-grab',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-arrow',180,0,64,6,3,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-rotate',-1,0,128,4,3,0,0
MEMBER:'instr-output',-1,0,128,5,3,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestWallCollisionsNegative,Zig,0-0-0,rotate_collide_right_wall
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',180,0,64,6,0,0,0
MEMBER:'instr-grab',-1,2,128,6,0,0,0
MEMBER:'instr-rotate',-1,0,128,3,4,0,0
MEMBER:'instr-output',-1,0,128,5,0,0,0
MEMBER:'instr-rotate',-1,0,128,6,3,0,0
MEMBER:'instr-arrow',-90,0,64,6,4,0,0
MEMBER:'instr-arrow',90,0,64,3,0,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestWallCollisionsNegative,Zig,0-0-0,rotate_collide_bottom_wall
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,4,2,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',180,0,64,9,2,0,0
MEMBER:'instr-grab',-1,2,128,9,2,0,0
MEMBER:'instr-rotate',-1,0,128,3,4,0,0
MEMBER:'instr-output',-1,0,128,8,2,0,0
MEMBER:'instr-rotate',-1,0,128,4,4,0,0
MEMBER:'instr-arrow',-90,0,64,9,4,0,0
MEMBER:'instr-arrow',90,0,64,3,2,0,0
MEMBER:'instr-rotate',-1,0,128,5,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:TestWallCollisionsNegative,Zig,0-0-0,rotate_collide_left_wall
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',90,0,128,3,1,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,3,2,0,0
MEMBER:'instr-grab',-1,1,128,3,3,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-rotate',-1,1,128,4,3,0,0
MEMBER:'instr-output',-1,0,128,7,2,0,0
MEMBER:'instr-arrow',90,0,64,4,3,0,0
MEMBER:'instr-arrow',180,0,64,4,4,0,0
MEMBER:'instr-rotate',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',90,0,64,3,4,0,0
MEMBER:'instr-arrow',0,0,64,3,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,5,0,0
MEMBER:'instr-arrow',90,0,64,3,2,0,0
MEMBER:'instr-arrow',0,0,64,3,3,0,0
MEMBER:'instr-arrow',180,0,64,7,2,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    # An extreme molecule collision check that must collide with a wall after it successfully avoids a molecule collision
    r'''SOLUTION:TestMoleculeCollisions,Zig,0-0-0,'9x3 past (9,0) (wall collision)'
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,5,1,0,0
MEMBER:'instr-start',180,0,32,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,2,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'feature-bonder',-1,0,1,9,5,0,0
MEMBER:'feature-bonder',-1,0,1,8,6,0,0
MEMBER:'feature-bonder',-1,0,1,7,7,0,0
MEMBER:'feature-bonder',-1,0,1,9,7,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-input',-1,0,128,1,3,0,0
MEMBER:'instr-bond',-1,0,32,0,5,0,0
MEMBER:'instr-bond',-1,0,32,0,6,0,0
MEMBER:'instr-arrow',0,0,16,0,7,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-bond',-1,0,32,1,7,0,0
MEMBER:'instr-bond',-1,0,32,2,7,0,0
MEMBER:'instr-bond',-1,0,32,0,4,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-input',-1,0,128,2,3,0,0
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-input',-1,0,128,4,3,0,0
MEMBER:'instr-input',-1,0,128,5,3,0,0
MEMBER:'instr-input',-1,0,128,6,3,0,0
MEMBER:'instr-arrow',-90,0,64,9,3,0,0
MEMBER:'instr-rotate',-1,1,128,9,2,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-grab',-1,2,32,0,2,0,0
MEMBER:'instr-input',-1,0,128,4,1,0,0
MEMBER:'instr-input',-1,0,128,7,3,0,0
MEMBER:'instr-input',-1,0,128,8,3,0,0
MEMBER:'instr-input',-1,0,128,9,3,0,0
MEMBER:'instr-bond',-1,0,32,3,7,0,0
MEMBER:'instr-bond',-1,0,32,4,7,0,0
MEMBER:'instr-bond',-1,0,32,5,7,0,0
MEMBER:'instr-bond',-1,0,32,6,7,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:QT-1,Zig,0-0-0,Quantum wall collision
COMPONENT:'drag-quantum-reactor-x',2,0,''
MEMBER:'instr-start',-90,0,128,1,3,0,0
MEMBER:'instr-start',180,0,32,0,7,0,0
MEMBER:'feature-tunnel',-1,0,1,8,7,0,0
MEMBER:'feature-tunnel',-1,0,1,9,7,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-arrow',90,0,64,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-output',-1,1,128,5,4,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r'''SOLUTION:QT-1,Zig,0-0-0,Quantum wall collision while other molecule rotates
COMPONENT:'drag-quantum-reactor-x',2,0,''
MEMBER:'instr-start',180,0,128,2,0,0,0
MEMBER:'instr-start',-90,0,32,1,4,0,0
MEMBER:'feature-tunnel',-1,0,1,3,5,0,0
MEMBER:'feature-tunnel',-1,0,1,6,5,0,0
MEMBER:'instr-arrow',0,0,16,1,1,0,0
MEMBER:'instr-grab',-1,0,32,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-grab',-1,0,128,1,1,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-rotate',-1,1,128,1,5,0,0
PIPE:0,4,1
PIPE:1,4,2''']

# Solutions to levels for which there are two or more matching levels in SpaceChem
# Currently "Sulfuric Acid", "Pyridine", "Breakdown", and "Vitamin B3"
duplicate_level_name_solutions = [
    # 1-8-2
    r'''SOLUTION:Sulfuric Acid,Andy,1273-1-21,Symbols
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',0,0,128,0,7,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-splitter',-1,0,1,0,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-split',-1,0,128,0,1,0,0
MEMBER:'instr-arrow',90,0,64,0,1,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-input',-1,0,128,1,7,0,0
MEMBER:'instr-arrow',0,0,64,1,7,0,0
MEMBER:'instr-toggle',-90,0,128,2,7,0,0
MEMBER:'instr-toggle',180,0,128,3,7,0,0
MEMBER:'instr-arrow',-90,0,64,7,7,0,0
MEMBER:'instr-arrow',-90,0,64,7,5,0,0
MEMBER:'instr-arrow',180,0,64,7,0,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-toggle',90,0,128,2,3,0,0
MEMBER:'instr-bond',-1,0,32,0,7,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-output',-1,0,128,7,2,0,0
MEMBER:'instr-rotate',-1,1,128,1,5,0,0
MEMBER:'instr-grab',-1,2,128,2,5,0,0
MEMBER:'instr-grab',-1,1,128,2,4,0,0
MEMBER:'instr-input',-1,1,128,3,5,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    r"""SOLUTION:Sulfuric Acid,Zig,7208-1-36,ResNet 3-7-1
COMPONENT:'drag-starter-reactor',18,7,''
MEMBER:'instr-start',180,0,128,3,0,0,0
MEMBER:'instr-start',180,0,32,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'instr-output',-1,1,32,0,7,0,0
MEMBER:'instr-input',-1,1,128,0,3,0,0
MEMBER:'instr-grab',-1,1,128,0,4,0,0
MEMBER:'instr-bond',-1,1,128,6,4,0,0
MEMBER:'instr-bond',-1,0,128,7,4,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-input',-1,0,128,9,3,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-toggle',0,0,128,2,3,0,0
MEMBER:'instr-rotate',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-arrow',-90,0,64,6,5,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,1,0,0
MEMBER:'instr-toggle',90,0,128,2,0,0,0
MEMBER:'instr-toggle',0,0,128,0,1,0,0
MEMBER:'instr-toggle',0,0,128,0,0,0,0
MEMBER:'instr-arrow',180,0,64,3,0,0,0
MEMBER:'instr-arrow',180,0,64,9,0,0,0
MEMBER:'instr-arrow',90,0,64,8,4,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,5,0,0
MEMBER:'instr-grab',-1,0,128,7,2,0,0
MEMBER:'instr-rotate',-1,1,128,6,3,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',90,0,64,5,1,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-arrow',0,0,64,6,3,0,0
MEMBER:'instr-toggle',90,0,128,6,1,0,0
MEMBER:'instr-toggle',0,0,128,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,9,3,0,0
MEMBER:'instr-output',-1,0,128,8,2,0,0
MEMBER:'instr-arrow',-90,0,64,9,2,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,1
PIPE:1,4,0
PIPE:1,4,-1
PIPE:1,4,-2
PIPE:1,4,-3
PIPE:1,4,-4
PIPE:1,4,-5
PIPE:1,4,-6
PIPE:1,4,-7
PIPE:1,5,-7
PIPE:1,5,-6
PIPE:1,5,-5
PIPE:1,5,-4
PIPE:1,5,-3
PIPE:1,5,-2
PIPE:1,5,-1
PIPE:1,6,-1
PIPE:1,6,-2
PIPE:1,6,-3
PIPE:1,6,-4
PIPE:1,6,-5
PIPE:1,6,-6
PIPE:1,6,-7
PIPE:1,7,-7
PIPE:1,8,-7
PIPE:1,9,-7
PIPE:1,10,-7
PIPE:1,11,-7
PIPE:1,12,-7
PIPE:1,13,-7
PIPE:1,13,-6
PIPE:1,12,-6
PIPE:1,11,-6
PIPE:1,10,-6
PIPE:1,9,-6
PIPE:1,8,-6
PIPE:1,7,-6
PIPE:1,7,-5
PIPE:1,8,-5
PIPE:1,9,-5
PIPE:1,10,-5
PIPE:1,11,-5
PIPE:1,11,-4
PIPE:1,10,-4
PIPE:1,9,-4
PIPE:1,8,-4
PIPE:1,7,-4
PIPE:1,7,-3
PIPE:1,8,-3
PIPE:1,9,-3
PIPE:1,10,-3
PIPE:1,10,-2
PIPE:1,9,-2
PIPE:1,8,-2
PIPE:1,7,-2
PIPE:1,7,-1
PIPE:1,8,-1
PIPE:1,9,-1
PIPE:1,10,-1
PIPE:1,11,-1
PIPE:1,11,0
PIPE:1,12,0
PIPE:1,12,1
PIPE:1,11,1
PIPE:1,10,1
PIPE:1,10,0
PIPE:1,9,0
PIPE:1,8,0
PIPE:1,7,0
PIPE:1,7,1
PIPE:1,8,1
PIPE:1,9,1
PIPE:1,9,2
PIPE:1,10,2
PIPE:1,11,2
PIPE:1,12,2
PIPE:1,12,3
PIPE:1,13,3
PIPE:1,13,4
PIPE:1,13,5
PIPE:1,13,6
PIPE:1,13,7
PIPE:1,13,8
PIPE:1,13,9
PIPE:1,13,10
PIPE:1,13,11
PIPE:1,13,12
PIPE:1,13,13
PIPE:1,13,14
PIPE:1,12,14
PIPE:1,12,13
PIPE:1,12,12
PIPE:1,12,11
PIPE:1,12,10
PIPE:1,12,9
PIPE:1,12,8
PIPE:1,12,7
PIPE:1,12,6
PIPE:1,12,5
PIPE:1,12,4
PIPE:1,11,4
PIPE:1,11,3
PIPE:1,10,3
PIPE:1,9,3
PIPE:1,8,3
PIPE:1,8,2
PIPE:1,7,2
PIPE:1,7,3
PIPE:1,6,3
PIPE:1,5,3
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,5,4
PIPE:1,6,4
PIPE:1,7,4
PIPE:1,8,4
PIPE:1,9,4
PIPE:1,10,4
PIPE:1,10,5
PIPE:1,11,5
PIPE:1,11,6
PIPE:1,11,7
PIPE:1,11,8
PIPE:1,11,9
PIPE:1,11,10
PIPE:1,11,11
PIPE:1,11,12
PIPE:1,11,13
PIPE:1,11,14
PIPE:1,10,14
PIPE:1,10,13
PIPE:1,10,12
PIPE:1,10,11
PIPE:1,10,10
PIPE:1,10,9
PIPE:1,10,8
PIPE:1,10,7
PIPE:1,10,6
PIPE:1,9,6
PIPE:1,9,5
PIPE:1,8,5
PIPE:1,7,5
PIPE:1,6,5
PIPE:1,5,5
PIPE:1,4,5
PIPE:1,3,5
PIPE:1,3,4
PIPE:1,2,4
PIPE:1,1,4
PIPE:1,0,4
PIPE:1,-1,4
PIPE:1,-2,4
PIPE:1,-2,5
PIPE:1,-1,5
PIPE:1,0,5
PIPE:1,1,5
PIPE:1,2,5
PIPE:1,2,6
PIPE:1,3,6
PIPE:1,4,6
PIPE:1,5,6
PIPE:1,6,6
PIPE:1,7,6
PIPE:1,8,6
PIPE:1,8,7
PIPE:1,9,7
PIPE:1,9,8
PIPE:1,9,9
PIPE:1,9,10
PIPE:1,9,11
PIPE:1,9,12
PIPE:1,9,13
PIPE:1,9,14
PIPE:1,8,14
PIPE:1,8,13
PIPE:1,8,12
PIPE:1,8,11
PIPE:1,8,10
PIPE:1,8,9
PIPE:1,8,8
PIPE:1,7,8
PIPE:1,7,7
PIPE:1,6,7
PIPE:1,5,7
PIPE:1,4,7
PIPE:1,3,7
PIPE:1,2,7
PIPE:1,1,7
PIPE:1,1,6
PIPE:1,0,6
PIPE:1,-1,6
PIPE:1,-2,6
PIPE:1,-2,7
PIPE:1,-1,7
PIPE:1,0,7
PIPE:1,0,8
PIPE:1,1,8
PIPE:1,2,8
PIPE:1,3,8
PIPE:1,4,8
PIPE:1,5,8
PIPE:1,6,8
PIPE:1,6,9
PIPE:1,7,9
PIPE:1,7,10
PIPE:1,7,11
PIPE:1,7,12
PIPE:1,7,13
PIPE:1,7,14
PIPE:1,6,14
PIPE:1,6,13
PIPE:1,6,12
PIPE:1,6,11
PIPE:1,6,10
PIPE:1,5,10
PIPE:1,5,9
PIPE:1,4,9
PIPE:1,3,9
PIPE:1,2,9
PIPE:1,1,9
PIPE:1,0,9
PIPE:1,-1,9
PIPE:1,-2,9
PIPE:1,-3,9
PIPE:1,-4,9
PIPE:1,-5,9
PIPE:1,-6,9
PIPE:1,-7,9
PIPE:1,-8,9
PIPE:1,-9,9
PIPE:1,-10,9
PIPE:1,-11,9
PIPE:1,-12,9
PIPE:1,-12,10
PIPE:1,-11,10
PIPE:1,-10,10
PIPE:1,-9,10
PIPE:1,-8,10
PIPE:1,-7,10
PIPE:1,-6,10
PIPE:1,-5,10
PIPE:1,-4,10
PIPE:1,-3,10
PIPE:1,-2,10
PIPE:1,-1,10
PIPE:1,0,10
PIPE:1,1,10
PIPE:1,2,10
PIPE:1,3,10
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,5,11
PIPE:1,5,12
PIPE:1,5,13
PIPE:1,5,14
PIPE:1,4,14
PIPE:1,4,13
PIPE:1,4,12
PIPE:1,3,12
PIPE:1,3,11
PIPE:1,2,11
PIPE:1,2,12
PIPE:1,2,13
PIPE:1,3,13
PIPE:1,3,14
PIPE:1,2,14
PIPE:1,1,14
PIPE:1,1,13
PIPE:1,1,12
PIPE:1,1,11
PIPE:1,0,11
PIPE:1,0,12
PIPE:1,0,13
PIPE:1,0,14
PIPE:1,-1,14
PIPE:1,-1,13
PIPE:1,-2,13
PIPE:1,-2,14
PIPE:1,-3,14
PIPE:1,-3,13
PIPE:1,-3,12
PIPE:1,-3,11
PIPE:1,-4,11
PIPE:1,-4,12
PIPE:1,-4,13
PIPE:1,-4,14
PIPE:1,-5,14
PIPE:1,-5,13
PIPE:1,-5,12
PIPE:1,-5,11
PIPE:1,-6,11
PIPE:1,-6,12
PIPE:1,-6,13
PIPE:1,-6,14
COMPONENT:'drag-arbitrary-input',1,5,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,14,1
PIPE:0,15,1
PIPE:0,16,1
PIPE:0,16,2
PIPE:0,16,3
COMPONENT:'drag-arbitrary-input',3,18,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,14,1
PIPE:0,14,0
PIPE:0,14,-1
PIPE:0,14,-2
PIPE:0,14,-3
PIPE:0,14,-4
PIPE:0,14,-5
PIPE:0,14,-6
PIPE:0,14,-7
PIPE:0,14,-8
PIPE:0,14,-9""",
    # 2-1-1 Pyridine
    r"""SOLUTION:Pyridine,Zig,157-1-32
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,4,3,0,0
MEMBER:'instr-start',180,0,32,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,2,0,0
MEMBER:'instr-bond',-1,1,128,2,4,0,0
MEMBER:'instr-input',-1,0,128,3,3,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-input',-1,1,32,5,5,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-grab',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',90,0,64,3,4,0,0
MEMBER:'instr-bond',-1,1,32,3,5,0,0
MEMBER:'instr-grab',-1,1,32,2,5,0,0
MEMBER:'instr-bond',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',0,0,16,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,3,6,0,0
MEMBER:'instr-bond',-1,0,32,3,3,0,0
MEMBER:'instr-rotate',-1,1,128,3,6,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-arrow',-90,0,64,6,5,0,0
MEMBER:'instr-arrow',180,0,64,6,3,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-output',-1,1,128,6,4,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-arrow',90,0,16,7,3,0,0
MEMBER:'instr-arrow',180,0,16,7,5,0,0
MEMBER:'instr-output',-1,0,32,7,4,0,0
MEMBER:'instr-bond',-1,1,128,3,4,0,0
MEMBER:'instr-toggle',0,0,128,3,5,0,0
MEMBER:'instr-bond',-1,0,32,4,3,0,0
MEMBER:'instr-rotate',-1,0,32,6,3,0,0
MEMBER:'instr-bond',-1,0,32,5,3,0,0
MEMBER:'instr-bond',-1,0,128,4,5,0,0
MEMBER:'instr-rotate',-1,1,128,5,5,0,0
MEMBER:'instr-sync',-1,0,128,5,3,0,0
MEMBER:'instr-sync',-1,0,32,7,5,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    # 2-1-2
    r'''SOLUTION:Breakdown,Zig,43-1-55,Cycles
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,7,1,0,0
MEMBER:'instr-start',0,0,32,0,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,1,0,0
MEMBER:'feature-sensor',-1,0,1,2,3,0,0
MEMBER:'instr-grab',-1,1,32,1,3,0,0
MEMBER:'instr-bond',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,4,0,0
MEMBER:'instr-rotate',-1,0,32,5,4,0,0
MEMBER:'instr-output',-1,0,32,6,4,0,0
MEMBER:'instr-arrow',-90,0,16,5,4,0,0
MEMBER:'instr-arrow',180,0,16,5,2,0,0
MEMBER:'instr-bond',-1,0,32,4,2,0,0
MEMBER:'instr-arrow',0,0,16,4,2,0,0
MEMBER:'instr-toggle',0,0,32,5,2,0,0
MEMBER:'instr-output',-1,0,32,7,2,0,0
MEMBER:'instr-grab',-1,2,32,6,2,0,0
MEMBER:'instr-arrow',-90,0,16,7,2,0,0
MEMBER:'instr-arrow',180,0,16,7,0,0,0
MEMBER:'instr-grab',-1,1,128,1,3,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-rotate',-1,0,128,5,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,4,0,0
MEMBER:'instr-arrow',180,0,64,5,2,0,0
MEMBER:'instr-bond',-1,0,128,4,2,0,0
MEMBER:'instr-arrow',0,0,64,4,2,0,0
MEMBER:'instr-toggle',0,0,128,5,2,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-arrow',-90,0,64,6,2,0,0
MEMBER:'instr-arrow',180,0,64,6,0,0,0
MEMBER:'instr-bond',-1,1,128,2,3,0,0
MEMBER:'instr-arrow',90,0,64,2,3,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,4,0,0
MEMBER:'instr-arrow',0,0,64,3,3,0,0
MEMBER:'instr-bond',-1,0,128,2,4,0,0
MEMBER:'instr-output',-1,0,128,3,4,0,0
MEMBER:'instr-bond',-1,0,128,3,3,0,0
MEMBER:'instr-bond',-1,0,128,4,3,0,0
MEMBER:'instr-bond',-1,0,32,7,0,0,0
MEMBER:'instr-output',-1,0,32,6,0,0,0
MEMBER:'instr-bond',-1,0,128,6,4,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-bond',-1,1,32,2,0,0,0
MEMBER:'instr-bond',-1,0,32,1,0,0,0
MEMBER:'instr-output',-1,0,32,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-input',-1,0,128,6,1,0,0
MEMBER:'instr-bond',-1,1,128,2,0,0,0
MEMBER:'instr-bond',-1,0,128,1,0,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-bond',-1,0,128,6,0,0,0
MEMBER:'instr-bond',-1,0,32,1,2,0,0
MEMBER:'instr-output',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,6,1,0,0
PIPE:0,4,1
PIPE:1,4,2''',
    # 2-1-3
    r'''SOLUTION:Vitamin B3,cactus/12345ieee,296-1-31,Symbols
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,2,5,0,0
MEMBER:'instr-start',0,0,32,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,3,5,0,0
MEMBER:'feature-bonder',-1,0,1,3,6,0,0
MEMBER:'feature-fuser',-1,0,1,6,1,0,0
MEMBER:'instr-toggle',-90,0,128,0,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-bond',-1,1,128,0,4,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-bond',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',90,0,64,4,4,0,0
MEMBER:'instr-arrow',180,0,64,4,6,0,0
MEMBER:'instr-toggle',-90,0,128,0,6,0,0
MEMBER:'instr-rotate',-1,0,128,4,4,0,0
MEMBER:'instr-fuse',-1,0,128,4,5,0,0
MEMBER:'instr-rotate',-1,1,128,7,5,0,0
MEMBER:'instr-arrow',180,0,64,7,5,0,0
MEMBER:'instr-bond',-1,1,128,3,5,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-input',-1,1,32,5,4,0,0
MEMBER:'instr-arrow',-90,0,16,6,4,0,0
MEMBER:'instr-output',-1,0,32,6,1,0,0
MEMBER:'instr-bond',-1,1,32,6,2,0,0
MEMBER:'instr-arrow',180,0,16,6,0,0,0
MEMBER:'instr-arrow',0,0,16,1,0,0,0
MEMBER:'instr-toggle',90,0,32,4,0,0,0
MEMBER:'instr-toggle',180,0,32,4,1,0,0
MEMBER:'instr-arrow',-90,0,16,4,3,0,0
MEMBER:'instr-rotate',-1,1,32,4,3,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-bond',-1,0,32,3,0,0,0
MEMBER:'instr-input',-1,0,32,5,0,0,0
MEMBER:'instr-grab',-1,1,32,1,0,0,0
MEMBER:'instr-grab',-1,2,128,3,6,0,0
PIPE:0,4,1
PIPE:1,4,2''',
]

sandbox_solutions = [
    r"""SOLUTION:as54,12345ieee,0-0-0,all sandbox components
COMPONENT:'drag-printer-output',19,13,''
COMPONENT:'drag-sandbox-reactor',5,12,''
MEMBER:'instr-start',180,0,128,5,2,0,0
MEMBER:'instr-start',180,0,32,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,3,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,4,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-splitter',-1,0,1,5,5,0,0
MEMBER:'feature-fuser',-1,0,1,3,5,0,0
MEMBER:'feature-sensor',-1,0,1,4,2,0,0
MEMBER:'instr-input',-1,1,32,0,5,0,0
MEMBER:'instr-grab',-1,0,32,1,5,0,0
MEMBER:'instr-arrow',0,0,16,0,5,0,0
MEMBER:'instr-arrow',180,0,16,7,5,0,0
MEMBER:'instr-grab',-1,0,32,7,5,0,0
MEMBER:'instr-output',-1,1,32,6,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:1,5,2
PIPE:1,6,2
COMPONENT:'drag-programmed-input',1,13,''
PIPE:0,2,1
PIPE:0,3,1
COMPONENT:'drag-storage-tank-infinite',12,13,''
PIPE:0,3,1
COMPONENT:'drag-printer-passthrough',16,13,''
PIPE:0,2,1""",
]

non_precog_solutions = [
    r"""SOLUTION:Accidents Happen,Zig,275-1-88,non-precog research
COMPONENT:'drag-advanced-reactor',2,0,''
MEMBER:'instr-start',0,0,128,4,1,0,0
MEMBER:'instr-start',90,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,2,6,0,0
MEMBER:'feature-sensor',-1,0,1,1,1,0,0
MEMBER:'instr-arrow',180,0,64,1,4,0,0
MEMBER:'instr-arrow',90,0,64,0,4,0,0
MEMBER:'instr-arrow',0,0,64,0,5,0,0
MEMBER:'instr-grab',-1,1,128,0,5,0,0
MEMBER:'instr-grab',-1,1,128,1,5,0,0
MEMBER:'instr-grab',-1,2,128,1,4,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,2,128,7,4,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-bond',-1,1,128,7,2,0,0
MEMBER:'instr-bond',-1,0,128,6,2,0,0
MEMBER:'instr-bond',-1,0,128,3,2,0,0
MEMBER:'instr-bond',-1,0,128,4,3,0,0
MEMBER:'instr-rotate',-1,0,128,2,4,0,0
MEMBER:'instr-grab',-1,2,128,2,3,0,0
MEMBER:'instr-grab',-1,1,128,3,4,0,0
MEMBER:'instr-sensor',90,0,128,4,2,0,14
MEMBER:'instr-arrow',180,0,64,7,2,0,0
MEMBER:'instr-arrow',-90,0,64,7,4,0,0
MEMBER:'instr-arrow',180,0,64,2,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-arrow',90,0,64,1,5,0,0
MEMBER:'instr-arrow',0,0,64,1,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-sensor',0,0,128,2,5,0,14
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,5,0,0
MEMBER:'instr-arrow',-90,0,64,7,3,0,0
MEMBER:'instr-sync',-1,0,128,4,4,0,0
MEMBER:'instr-rotate',-1,1,128,6,4,0,0
MEMBER:'instr-bond',-1,0,128,2,7,0,0
MEMBER:'instr-bond',-1,0,128,1,6,0,0
MEMBER:'instr-input',-1,1,128,1,7,0,0
MEMBER:'instr-input',-1,0,128,5,1,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',0,0,16,1,6,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-sensor',0,0,32,2,5,0,15
MEMBER:'instr-sensor',180,0,32,4,5,0,14
MEMBER:'instr-bond',-1,1,32,3,5,0,0
MEMBER:'instr-arrow',180,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-bond',-1,0,32,2,6,0,0
MEMBER:'instr-input',-1,1,128,5,4,0,0
MEMBER:'instr-input',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',0,0,16,0,1,0,0
MEMBER:'instr-arrow',-90,0,16,0,5,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,0,5,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-input',-1,1,128,5,2,0,0
MEMBER:'instr-bond',-1,1,32,1,6,0,0
MEMBER:'instr-grab',-1,2,32,2,4,0,0
MEMBER:'instr-sync',-1,0,32,2,3,0,0
MEMBER:'instr-bond',-1,1,32,4,6,0,0
MEMBER:'instr-grab',-1,2,32,7,5,0,0
MEMBER:'instr-arrow',-90,0,16,7,5,0,0
MEMBER:'instr-toggle',0,0,32,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,9,4,0,0
MEMBER:'instr-arrow',180,0,16,9,2,0,0
MEMBER:'instr-arrow',90,0,16,4,4,0,0
MEMBER:'instr-input',-1,1,32,6,4,0,0
MEMBER:'instr-arrow',180,0,64,4,3,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-bond',-1,0,32,4,4,0,0
MEMBER:'instr-arrow',-90,0,16,3,7,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-grab',-1,1,32,4,3,0,0
MEMBER:'instr-arrow',180,0,16,4,7,0,0
MEMBER:'instr-rotate',-1,0,32,5,3,0,0
MEMBER:'instr-arrow',90,0,16,7,3,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-bond',-1,0,32,9,3,0,0
MEMBER:'instr-sensor',90,0,32,3,2,0,15
MEMBER:'instr-bond',-1,1,32,8,2,0,0
MEMBER:'instr-bond',-1,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,1,3,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-input',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,7,1,0,0
MEMBER:'instr-arrow',-90,0,64,2,2,0,0
MEMBER:'instr-bond',-1,1,32,5,4,0,0
MEMBER:'instr-output',-1,0,128,0,4,0,0
MEMBER:'instr-arrow',-90,0,16,2,2,0,0
MEMBER:'instr-output',-1,1,32,2,2,0,0
MEMBER:'instr-output',-1,1,128,2,2,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    r"""SOLUTION:No Thanks Necessary,Archiver,2508-2-167,non-precog 2 random inputs
COMPONENT:'drag-advanced-reactor',10,7,''
MEMBER:'instr-start',0,0,128,0,0,0,0
MEMBER:'instr-start',90,0,32,0,0,0,0
MEMBER:'feature-bonder',-1,0,1,4,1,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-sensor',-1,0,1,6,2,0,0
MEMBER:'instr-input',-1,0,128,2,0,0,0
MEMBER:'instr-arrow',90,0,64,2,0,0,0
MEMBER:'instr-grab',-1,1,128,2,1,0,0
MEMBER:'instr-arrow',0,0,64,2,1,0,0
MEMBER:'instr-rotate',-1,1,128,3,1,0,0
MEMBER:'instr-bond',-1,1,128,4,1,0,0
MEMBER:'instr-sensor',90,0,128,6,1,0,7
MEMBER:'instr-arrow',-90,0,64,6,1,0,0
MEMBER:'instr-arrow',180,0,64,6,0,0,0
MEMBER:'instr-grab',-1,2,128,6,0,0,0
MEMBER:'instr-output',-1,0,128,5,0,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-sync',-1,0,128,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-rotate',-1,0,128,5,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,4,0,0
MEMBER:'instr-arrow',0,0,64,5,3,0,0
MEMBER:'instr-grab',-1,2,128,7,3,0,0
MEMBER:'instr-grab',-1,1,128,9,3,0,0
MEMBER:'instr-arrow',90,0,64,9,3,0,0
MEMBER:'instr-sync',-1,0,128,9,4,0,0
MEMBER:'instr-grab',-1,2,128,9,6,0,0
MEMBER:'instr-output',-1,1,128,9,7,0,0
MEMBER:'instr-arrow',180,0,64,9,7,0,0
MEMBER:'instr-input',-1,1,128,2,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-sync',-1,0,128,2,6,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
MEMBER:'instr-rotate',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-bond',-1,1,128,4,2,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-arrow',90,0,64,7,2,0,0
MEMBER:'instr-arrow',180,0,64,7,5,0,0
MEMBER:'instr-arrow',-90,0,64,4,5,0,0
MEMBER:'instr-bond',-1,0,128,4,3,0,0
MEMBER:'instr-arrow',180,0,64,4,3,0,0
MEMBER:'instr-arrow',90,0,64,3,3,0,0
MEMBER:'instr-bond',-1,1,128,3,3,0,0
MEMBER:'instr-arrow',0,0,64,3,6,0,0
MEMBER:'instr-grab',-1,2,128,6,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,6,0,0
MEMBER:'instr-grab',-1,1,128,8,1,0,0
MEMBER:'instr-arrow',180,0,64,8,1,0,0
MEMBER:'instr-input',-1,0,32,2,0,0,0
MEMBER:'instr-arrow',90,0,16,2,0,0,0
MEMBER:'instr-grab',-1,1,32,2,1,0,0
MEMBER:'instr-arrow',0,0,16,2,1,0,0
MEMBER:'instr-rotate',-1,1,32,3,1,0,0
MEMBER:'instr-bond',-1,1,32,4,1,0,0
MEMBER:'instr-sensor',90,0,32,6,1,0,8
MEMBER:'instr-output',-1,0,32,7,1,0,0
MEMBER:'instr-grab',-1,2,32,8,1,0,0
MEMBER:'instr-arrow',-90,0,16,8,1,0,0
MEMBER:'instr-arrow',180,0,16,8,0,0,0
MEMBER:'instr-grab',-1,2,32,6,2,0,0
MEMBER:'instr-arrow',180,0,16,6,2,0,0
MEMBER:'instr-bond',-1,0,32,5,2,0,0
MEMBER:'instr-sync',-1,0,32,4,2,0,0
MEMBER:'instr-sensor',90,0,32,3,2,0,8
MEMBER:'instr-arrow',-90,0,16,2,2,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-sensor',0,0,32,5,3,0,8
MEMBER:'instr-arrow',90,0,16,5,3,0,0
MEMBER:'instr-grab',-1,1,32,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
MEMBER:'instr-grab',-1,2,32,4,4,0,0
MEMBER:'instr-arrow',180,0,16,5,4,0,0
MEMBER:'instr-input',-1,1,32,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-rotate',-1,1,32,6,5,0,0
MEMBER:'instr-arrow',-90,0,16,6,5,0,0
MEMBER:'instr-grab',-1,2,32,6,4,0,0
MEMBER:'instr-arrow',0,0,16,6,4,0,0
MEMBER:'instr-output',-1,1,32,4,6,0,0
MEMBER:'instr-arrow',90,0,16,1,4,0,0
MEMBER:'instr-output',-1,0,32,0,3,0,0
MEMBER:'instr-grab',-1,1,128,4,4,0,0
MEMBER:'instr-arrow',90,0,16,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,6,0,0
MEMBER:'instr-arrow',-90,0,16,0,6,0,0
MEMBER:'instr-sensor',0,0,32,0,1,0,7
MEMBER:'instr-arrow',180,0,16,0,1,0,0
MEMBER:'instr-input',-1,0,32,1,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,5,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,5,-3
PIPE:0,6,-3
PIPE:0,7,-3
PIPE:0,8,-3
PIPE:0,9,-3
PIPE:0,10,-3
PIPE:0,11,-3
PIPE:0,12,-3
PIPE:0,13,-3
PIPE:0,14,-3
PIPE:0,15,-3
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,-118,78,'0,0:0,8;0,1:0,8;0,2:0,7;1,2:0,7;2,2:0,8;3,2:0,8;\n0,0,0:1;0,1,0:1;0,2,1:1;1,2,1:1;2,2,1:1;\r0,0:0,11;\n\r0,0:0,1;0,1:0,8;0,2:0,8;\n0,0,0:1;0,1,0:1;\r'
COMPONENT:'drag-atmospheric-input',4,5,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,5,1
PIPE:0,5,2
PIPE:0,5,3
COMPONENT:'drag-oceanic-input',7,18,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,2,-4
PIPE:0,2,-5
PIPE:0,2,-6
PIPE:0,2,-7
PIPE:0,2,-8
PIPE:0,2,-9
COMPONENT:'drag-advanced-reactor',16,7,''
MEMBER:'instr-start',180,0,128,9,7,0,0
MEMBER:'instr-start',90,0,32,0,0,0,0
MEMBER:'feature-bonder',-1,0,1,0,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-sensor',-1,0,1,5,6,0,0
MEMBER:'instr-arrow',180,0,64,6,7,0,0
MEMBER:'instr-input',-1,1,128,2,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-grab',-1,1,128,2,6,0,0
MEMBER:'instr-sync',-1,0,128,2,5,0,0
MEMBER:'instr-bond',-1,1,128,2,4,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-rotate',-1,0,128,3,4,0,0
MEMBER:'instr-arrow',-90,0,64,3,4,0,0
MEMBER:'instr-arrow',180,0,64,3,2,0,0
MEMBER:'instr-arrow',90,0,64,2,2,0,0
MEMBER:'instr-arrow',180,0,64,2,3,0,0
MEMBER:'instr-bond',-1,0,128,2,2,0,0
MEMBER:'instr-bond',-1,1,128,1,3,0,0
MEMBER:'instr-arrow',-90,0,64,1,3,0,0
MEMBER:'instr-rotate',-1,0,128,1,2,0,0
MEMBER:'instr-sync',-1,0,128,1,1,0,0
MEMBER:'instr-arrow',0,0,64,1,1,0,0
MEMBER:'instr-bond',-1,0,128,3,1,0,0
MEMBER:'instr-rotate',-1,0,128,4,1,0,0
MEMBER:'instr-arrow',90,0,64,4,1,0,0
MEMBER:'instr-grab',-1,2,128,4,2,0,0
MEMBER:'instr-arrow',180,0,64,4,6,0,0
MEMBER:'instr-input',-1,1,128,3,6,0,0
MEMBER:'instr-sync',-1,0,128,1,6,0,0
MEMBER:'instr-grab',-1,1,128,0,6,0,0
MEMBER:'instr-arrow',-90,0,64,0,6,0,0
MEMBER:'instr-rotate',-1,0,128,0,5,0,0
MEMBER:'instr-grab',-1,2,128,0,4,0,0
MEMBER:'instr-arrow',0,0,64,0,4,0,0
MEMBER:'instr-grab',-1,1,128,1,4,0,0
MEMBER:'instr-arrow',90,0,64,1,4,0,0
MEMBER:'instr-bond',-1,0,128,1,5,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-rotate',-1,0,128,3,5,0,0
MEMBER:'instr-sensor',-90,0,128,5,5,0,1
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-arrow',90,0,64,6,5,0,0
MEMBER:'instr-arrow',0,0,64,5,2,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-output',-1,0,128,6,3,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-sync',-1,0,32,0,2,0,0
MEMBER:'instr-grab',-1,1,32,0,3,0,0
MEMBER:'instr-arrow',0,0,16,0,4,0,0
MEMBER:'instr-arrow',90,0,16,1,4,0,0
MEMBER:'instr-bond',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',180,0,16,1,5,0,0
MEMBER:'instr-arrow',90,0,16,0,5,0,0
MEMBER:'instr-rotate',-1,1,32,0,5,0,0
MEMBER:'instr-rotate',-1,0,32,0,6,0,0
MEMBER:'instr-arrow',0,0,16,0,6,0,0
MEMBER:'instr-input',-1,1,32,1,6,0,0
MEMBER:'instr-sync',-1,0,32,2,6,0,0
MEMBER:'instr-arrow',-90,0,16,2,6,0,0
MEMBER:'instr-rotate',-1,0,32,2,5,0,0
MEMBER:'instr-bond',-1,0,32,2,4,0,0
MEMBER:'instr-arrow',0,0,16,2,4,0,0
MEMBER:'instr-rotate',-1,1,32,3,4,0,0
MEMBER:'instr-sensor',-90,0,32,6,4,0,1
MEMBER:'instr-grab',-1,2,32,7,4,0,0
MEMBER:'instr-arrow',-90,0,16,7,4,0,0
MEMBER:'instr-rotate',-1,1,32,6,3,0,0
MEMBER:'instr-arrow',0,0,16,6,3,0,0
MEMBER:'instr-arrow',-90,0,16,7,3,0,0
MEMBER:'instr-output',-1,1,32,7,3,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-arrow',180,0,16,7,2,0,0
MEMBER:'instr-sync',-1,0,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,5,2,0,0
MEMBER:'instr-grab',-1,1,32,4,2,0,0
MEMBER:'instr-bond',-1,1,32,2,2,0,0
MEMBER:'instr-arrow',90,0,16,1,2,0,0
MEMBER:'instr-arrow',0,0,16,1,3,0,0
MEMBER:'instr-grab',-1,2,32,1,3,0,0
MEMBER:'instr-sync',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',-90,0,16,3,3,0,0
MEMBER:'instr-arrow',180,0,16,3,1,0,0
MEMBER:'instr-output',-1,1,32,1,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:0,5,1""",
    r"""SOLUTION:Eth,Leylite,2836-3-103,doesn't use random input
COMPONENT:'drag-superbonder-reactor',10,6,''
MEMBER:'instr-start',0,0,128,8,7,0,0
MEMBER:'instr-start',90,0,32,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,2,0,0
MEMBER:'feature-bonder',-1,0,1,8,5,0,0
MEMBER:'feature-bonder',-1,0,1,6,5,0,0
MEMBER:'feature-bonder',-1,0,1,0,1,0,0
MEMBER:'feature-bonder',-1,0,1,0,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,5,0,0
MEMBER:'instr-input',-1,1,32,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-arrow',-90,0,16,5,5,0,0
MEMBER:'instr-arrow',0,0,16,5,4,0,0
MEMBER:'instr-arrow',90,0,16,8,4,0,0
MEMBER:'instr-arrow',-90,0,16,8,5,0,0
MEMBER:'instr-toggle',-90,0,32,8,4,0,0
MEMBER:'instr-arrow',180,0,16,8,3,0,0
MEMBER:'instr-grab',-1,2,32,7,3,0,0
MEMBER:'instr-output',-1,0,32,6,3,0,0
MEMBER:'instr-arrow',90,0,16,1,3,0,0
MEMBER:'instr-bond',-1,1,128,9,7,0,0
MEMBER:'instr-output',-1,1,32,5,5,0,0
MEMBER:'instr-output',-1,1,32,6,4,0,0
MEMBER:'instr-output',-1,1,32,7,4,0,0
MEMBER:'instr-output',-1,1,32,8,5,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:0,4,-1
PIPE:0,4,-2
PIPE:0,4,-3
PIPE:0,5,-3
PIPE:0,6,-3
PIPE:0,7,-3
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,6,3
PIPE:1,6,4
PIPE:1,6,5
PIPE:1,6,6
PIPE:1,6,7
PIPE:1,6,8
PIPE:1,6,9
PIPE:1,6,10
PIPE:1,7,10
PIPE:1,7,9
PIPE:1,7,8
PIPE:1,7,7
PIPE:1,7,6
PIPE:1,7,5
PIPE:1,7,4
PIPE:1,7,3
PIPE:1,7,2
ANNOTATION:0,0,0,0,'1,2:0,1;2,2:0,1;1,3:0,6;2,3:0,6;\n1,2,0:1;2,2,0:1;1,3,1:1;\r\n\r\n\r'
ANNOTATION:1,0,0,0,'1,1:0,1;\n\r\n\r\n\r'
COMPONENT:'drag-arbitrary-input',3,13,''
PIPE:0,2,1
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,2,-4
PIPE:0,2,-5
PIPE:0,3,-5
PIPE:0,4,-5
PIPE:0,5,-5
PIPE:0,6,-5
COMPONENT:'drag-superbonder-reactor',18,2,''
MEMBER:'instr-start',90,0,128,1,1,0,0
MEMBER:'instr-start',-90,0,32,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,3,3,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,1,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'instr-input',-1,0,128,1,2,0,0
MEMBER:'instr-grab',-1,1,128,1,3,0,0
MEMBER:'instr-rotate',-1,0,128,1,4,0,0
MEMBER:'instr-rotate',-1,0,128,1,5,0,0
MEMBER:'instr-grab',-1,2,128,2,4,0,0
MEMBER:'instr-sync',-1,0,128,2,5,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-arrow',-90,0,64,2,5,0,0
MEMBER:'instr-sync',-1,0,32,1,5,0,0
MEMBER:'instr-input',-1,0,32,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,3,0,0
MEMBER:'instr-arrow',0,0,16,1,2,0,0
MEMBER:'instr-rotate',-1,0,32,1,2,0,0
MEMBER:'instr-grab',-1,2,32,3,3,0,0
MEMBER:'instr-arrow',90,0,16,3,2,0,0
MEMBER:'instr-arrow',180,0,16,3,3,0,0
MEMBER:'instr-bond',-1,0,32,2,4,0,0
MEMBER:'instr-arrow',90,0,16,0,3,0,0
MEMBER:'instr-grab',-1,1,32,3,4,0,0
MEMBER:'instr-arrow',0,0,16,0,4,0,0
MEMBER:'instr-sync',-1,0,128,2,2,0,0
MEMBER:'instr-arrow',180,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,1,2,0,0
MEMBER:'instr-bond',-1,0,32,2,3,0,0
MEMBER:'instr-rotate',-1,0,32,4,4,0,0
MEMBER:'instr-arrow',-90,0,16,7,4,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-arrow',90,0,16,7,2,0,0
MEMBER:'instr-output',-1,0,32,7,3,0,0
MEMBER:'instr-toggle',90,0,32,7,4,0,0
MEMBER:'instr-arrow',180,0,16,7,6,0,0
MEMBER:'instr-arrow',-90,0,16,1,6,0,0
MEMBER:'instr-sync',-1,0,32,5,4,0,0
PIPE:0,4,1
PIPE:1,4,2
COMPONENT:'drag-nuclear-reactor',18,7,''
MEMBER:'instr-start',-90,0,128,0,2,0,0
MEMBER:'instr-start',180,0,32,5,0,0,0
MEMBER:'feature-bonder',-1,0,1,1,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,4,6,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'feature-fuser',-1,0,1,1,1,0,0
MEMBER:'feature-splitter',-1,0,1,1,7,0,0
MEMBER:'instr-input',-1,0,128,0,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',0,0,64,0,1,0,0
MEMBER:'instr-input',-1,0,128,3,1,0,0
MEMBER:'instr-input',-1,0,128,5,1,0,0
MEMBER:'instr-input',-1,0,128,7,1,0,0
MEMBER:'instr-input',-1,0,128,6,0,0,0
MEMBER:'instr-input',-1,0,128,4,0,0,0
MEMBER:'instr-input',-1,0,128,8,0,0,0
MEMBER:'instr-input',-1,0,128,9,1,0,0
MEMBER:'instr-fuse',-1,0,128,2,0,0,0
MEMBER:'instr-fuse',-1,0,128,4,1,0,0
MEMBER:'instr-fuse',-1,0,128,6,1,0,0
MEMBER:'instr-fuse',-1,0,128,8,1,0,0
MEMBER:'instr-fuse',-1,0,128,9,0,0,0
MEMBER:'instr-fuse',-1,0,128,7,0,0,0
MEMBER:'instr-fuse',-1,0,128,5,0,0,0
MEMBER:'instr-arrow',-90,0,64,9,1,0,0
MEMBER:'instr-arrow',180,0,64,9,0,0,0
MEMBER:'instr-arrow',90,0,64,2,0,0,0
MEMBER:'instr-sync',-1,0,128,3,0,0,0
MEMBER:'instr-input',-1,0,32,1,0,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-sync',-1,0,32,4,0,0,0
MEMBER:'instr-arrow',90,0,16,1,0,0,0
MEMBER:'instr-bond',-1,0,32,1,3,0,0
MEMBER:'instr-arrow',0,0,16,1,5,0,0
MEMBER:'instr-rotate',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,3,3,0,0
MEMBER:'instr-rotate',-1,1,32,3,5,0,0
MEMBER:'instr-arrow',-90,0,16,3,5,0,0
MEMBER:'instr-toggle',0,0,32,1,4,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-arrow',-90,0,16,6,4,0,0
MEMBER:'instr-output',-1,0,32,6,2,0,0
MEMBER:'instr-arrow',180,0,16,3,0,0,0
MEMBER:'instr-grab',-1,2,128,2,3,0,0
MEMBER:'instr-arrow',180,0,64,2,5,0,0
MEMBER:'instr-arrow',-90,0,64,1,5,0,0
MEMBER:'instr-input',-1,0,128,1,0,0,0
MEMBER:'instr-arrow',90,0,64,1,0,0,0
MEMBER:'instr-toggle',0,0,128,1,4,0,0
MEMBER:'instr-grab',-1,2,128,6,4,0,0
MEMBER:'instr-output',-1,1,128,6,5,0,0
MEMBER:'instr-arrow',90,0,64,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-toggle',90,0,128,3,5,0,0
MEMBER:'instr-arrow',180,0,64,3,6,0,0
MEMBER:'instr-arrow',-90,0,64,0,6,0,0
MEMBER:'instr-sync',-1,0,128,1,5,0,0
MEMBER:'instr-sync',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',180,0,16,6,0,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
PIPE:1,4,6
PIPE:1,4,7
PIPE:1,4,8
PIPE:1,4,9
PIPE:1,4,10
PIPE:1,4,11
PIPE:1,5,11""",
    r"""SOLUTION:No Ordinary Headache,Zemyla,1138-1-38,non-precog but infinite loops in wrong-first-molecule seeds
COMPONENT:'drag-atmospheric-input',8,18,''
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,2,-4
PIPE:0,2,-5
COMPONENT:'drag-advanced-reactor',11,11,''
MEMBER:'instr-start',90,0,128,1,4,0,0
MEMBER:'instr-start',180,0,32,2,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-sensor',-1,0,1,3,5,0,0
MEMBER:'instr-arrow',0,0,64,1,5,0,0
MEMBER:'instr-input',-1,1,128,1,5,0,0
MEMBER:'instr-grab',-1,1,128,2,5,0,0
MEMBER:'instr-arrow',0,0,64,3,4,0,0
MEMBER:'instr-rotate',-1,1,128,3,4,0,0
MEMBER:'instr-sensor',-90,0,128,3,5,0,7
MEMBER:'instr-rotate',-1,1,128,4,4,0,0
MEMBER:'instr-rotate',-1,1,128,4,5,0,0
MEMBER:'instr-arrow',0,0,64,5,0,0,0
MEMBER:'instr-bond',-1,1,128,5,0,0,0
MEMBER:'instr-bond',-1,1,128,5,2,0,0
MEMBER:'instr-bond',-1,1,128,5,3,0,0
MEMBER:'instr-arrow',-90,0,64,5,4,0,0
MEMBER:'instr-sync',-1,0,128,5,4,0,0
MEMBER:'instr-output',-1,1,128,5,5,0,0
MEMBER:'instr-arrow',90,0,64,6,0,0,0
MEMBER:'instr-bond',-1,0,128,6,0,0,0
MEMBER:'instr-grab',-1,2,128,6,2,0,0
MEMBER:'instr-bond',-1,0,128,6,3,0,0
MEMBER:'instr-output',-1,0,128,6,4,0,0
MEMBER:'instr-arrow',180,0,64,6,5,0,0
MEMBER:'instr-grab',-1,2,128,6,5,0,0
MEMBER:'instr-arrow',90,0,16,0,2,0,0
MEMBER:'instr-grab',-1,1,32,0,2,0,0
MEMBER:'instr-arrow',0,0,16,0,3,0,0
MEMBER:'instr-rotate',-1,0,32,0,3,0,0
MEMBER:'instr-input',-1,0,32,1,2,0,0
MEMBER:'instr-sync',-1,0,32,1,3,0,0
MEMBER:'instr-bond',-1,1,32,2,3,0,0
MEMBER:'instr-arrow',90,0,16,5,3,0,0
MEMBER:'instr-bond',-1,1,32,5,3,0,0
MEMBER:'instr-arrow',0,0,16,5,4,0,0
MEMBER:'instr-bond',-1,0,32,5,4,0,0
MEMBER:'instr-arrow',180,0,16,6,2,0,0
MEMBER:'instr-bond',-1,0,32,6,2,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-arrow',-90,0,16,6,4,0,0
MEMBER:'instr-output',-1,0,32,6,4,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,11,0
PIPE:0,11,-1
PIPE:0,11,-2
PIPE:0,11,-3
PIPE:0,11,-4
PIPE:0,11,-5
PIPE:0,11,-6
PIPE:0,11,-7
PIPE:0,11,-8
PIPE:1,4,1
PIPE:1,4,0
PIPE:1,5,0
PIPE:1,6,0
PIPE:1,7,0
PIPE:1,8,0
PIPE:1,9,0
PIPE:1,9,-1
PIPE:1,8,-1
PIPE:1,7,-1
PIPE:1,6,-1
PIPE:1,5,-1
PIPE:1,5,-2
PIPE:1,5,-3
PIPE:1,5,-4
PIPE:1,5,-5
PIPE:1,5,-6
PIPE:1,5,-7
PIPE:1,5,-8
PIPE:1,5,-9
PIPE:1,4,-9
PIPE:1,3,-9
PIPE:1,2,-9
PIPE:1,1,-9
PIPE:1,0,-9
PIPE:1,-1,-9
PIPE:1,-2,-9
PIPE:1,-3,-9
PIPE:1,-3,-8
PIPE:1,-3,-7
PIPE:1,-3,-6
PIPE:1,-3,-5
PIPE:1,-3,-4
PIPE:1,-3,-3
PIPE:1,-3,-2
PIPE:1,-3,-1
PIPE:1,-3,0
PIPE:1,-3,1
PIPE:1,-2,1
PIPE:1,-1,1"""
]

precog_solutions = [
    r"""SOLUTION:Freon,Archiver,112-1-63,fully precog research
COMPONENT:'custom-research-reactor',2,0,''
MEMBER:'instr-start',180,0,128,9,2,0,0
MEMBER:'instr-start',0,0,32,0,1,0,0
MEMBER:'feature-bonder',-1,0,1,4,2,0,0
MEMBER:'feature-bonder',-1,0,1,5,2,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-bonder',-1,0,1,3,2,0,0
MEMBER:'instr-input',-1,0,128,8,2,0,0
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-arrow',90,0,16,4,2,0,0
MEMBER:'instr-bond',-1,1,32,4,2,0,0
MEMBER:'instr-arrow',0,0,16,1,2,0,0
MEMBER:'instr-input',-1,0,32,4,3,0,0
MEMBER:'instr-arrow',90,0,16,1,1,0,0
MEMBER:'instr-arrow',0,0,16,4,4,0,0
MEMBER:'instr-arrow',-90,0,16,5,4,0,0
MEMBER:'instr-arrow',0,0,16,5,2,0,0
MEMBER:'instr-bond',-1,0,32,5,2,0,0
MEMBER:'instr-rotate',-1,0,32,6,2,0,0
MEMBER:'instr-grab',-1,2,32,7,2,0,0
MEMBER:'instr-arrow',-90,0,16,7,2,0,0
MEMBER:'instr-arrow',180,0,16,7,1,0,0
MEMBER:'instr-sync',-1,0,32,3,2,0,0
MEMBER:'instr-sync',-1,0,32,5,0,0,0
MEMBER:'instr-arrow',-90,0,16,5,1,0,0
MEMBER:'instr-arrow',90,0,16,4,0,0,0
MEMBER:'instr-arrow',180,0,16,4,1,0,0
MEMBER:'instr-grab',-1,1,32,5,1,0,0
MEMBER:'instr-grab',-1,2,32,4,1,0,0
MEMBER:'instr-arrow',180,0,64,7,1,0,0
MEMBER:'instr-arrow',-90,0,64,5,1,0,0
MEMBER:'instr-arrow',90,0,64,4,0,0,0
MEMBER:'instr-arrow',180,0,64,4,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-arrow',90,0,64,4,2,0,0
MEMBER:'instr-arrow',0,0,64,4,4,0,0
MEMBER:'instr-arrow',-90,0,64,5,4,0,0
MEMBER:'instr-arrow',0,0,64,5,2,0,0
MEMBER:'instr-arrow',-90,0,64,7,2,0,0
MEMBER:'instr-sync',-1,0,128,7,1,0,0
MEMBER:'instr-sync',-1,0,128,4,4,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,5,1,0,0
MEMBER:'instr-grab',-1,2,128,4,1,0,0
MEMBER:'instr-input',-1,0,128,4,3,0,0
MEMBER:'instr-bond',-1,1,128,4,2,0,0
MEMBER:'instr-bond',-1,0,128,5,2,0,0
MEMBER:'instr-rotate',-1,0,128,6,2,0,0
MEMBER:'instr-grab',-1,2,128,7,2,0,0
MEMBER:'instr-arrow',0,0,64,1,3,0,0
MEMBER:'instr-arrow',-90,0,64,7,3,0,0
MEMBER:'instr-rotate',-1,1,128,7,3,0,0
MEMBER:'instr-sync',-1,0,128,3,3,0,0
MEMBER:'instr-toggle',90,0,32,2,2,0,0
MEMBER:'instr-arrow',-90,0,16,2,3,0,0
MEMBER:'instr-output',-1,0,32,7,1,0,0
MEMBER:'instr-sync',-1,0,32,3,3,0,0
MEMBER:'instr-arrow',-90,0,16,7,3,0,0
MEMBER:'instr-rotate',-1,1,32,7,3,0,0
MEMBER:'instr-toggle',0,0,32,2,3,0,0
MEMBER:'instr-toggle',90,0,128,1,2,0,0
MEMBER:'instr-arrow',0,0,64,2,3,0,0
MEMBER:'instr-toggle',90,0,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,1,2,0,0
MEMBER:'instr-toggle',90,0,128,3,2,0,0
MEMBER:'instr-arrow',0,0,64,3,3,0,0
MEMBER:'instr-arrow',180,0,16,5,0,0,0
MEMBER:'instr-arrow',0,0,16,2,2,0,0
MEMBER:'instr-output',-1,0,32,1,2,0,0
MEMBER:'instr-arrow',180,0,64,5,0,0,0
PIPE:0,4,1
PIPE:1,4,2""",
    r"""SOLUTION:Smelting Iron,andy,25314-2-206,No Nth mol assumptions but 99% fail rate
COMPONENT:'drag-superbonder-reactor',6,7,''
MEMBER:'instr-start',180,0,128,9,1,0,0
MEMBER:'instr-start',-90,0,32,2,6,0,0
MEMBER:'feature-bonder',-1,0,1,6,0,0,0
MEMBER:'feature-bonder',-1,0,1,7,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,1,0,0
MEMBER:'feature-bonder',-1,0,1,1,7,0,0
MEMBER:'feature-bonder',-1,0,1,2,7,0,0
MEMBER:'feature-bonder',-1,0,1,5,4,0,0
MEMBER:'feature-bonder',-1,0,1,5,5,0,0
MEMBER:'feature-bonder',-1,0,1,5,6,0,0
MEMBER:'instr-input',-1,0,128,0,2,0,0
MEMBER:'instr-grab',-1,1,128,3,2,0,0
MEMBER:'instr-grab',-1,2,128,8,4,0,0
MEMBER:'instr-output',-1,1,128,8,5,0,0
MEMBER:'instr-grab',-1,1,128,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,0,0,0
MEMBER:'instr-grab',-1,1,128,2,0,0,0
MEMBER:'instr-arrow',0,0,64,7,0,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-output',-1,0,128,5,0,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-grab',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,0,1,0,0
MEMBER:'instr-toggle',0,0,128,3,1,0,0
MEMBER:'instr-toggle',0,0,128,2,1,0,0
MEMBER:'instr-grab',-1,2,128,3,0,0,0
MEMBER:'instr-grab',-1,1,128,4,0,0,0
MEMBER:'instr-bond',-1,1,128,7,0,0,0
MEMBER:'instr-toggle',0,0,128,8,0,0,0
MEMBER:'instr-toggle',-90,0,128,4,1,0,0
MEMBER:'instr-arrow',0,0,64,4,0,0,0
MEMBER:'instr-arrow',180,0,64,6,1,0,0
MEMBER:'instr-input',-1,1,32,1,4,0,0
MEMBER:'instr-grab',-1,1,32,1,5,0,0
MEMBER:'instr-grab',-1,2,32,2,7,0,0
MEMBER:'instr-sync',-1,0,128,7,3,0,0
MEMBER:'instr-sync',-1,0,32,3,7,0,0
MEMBER:'instr-arrow',0,0,16,1,7,0,0
MEMBER:'instr-bond',-1,0,32,1,7,0,0
MEMBER:'instr-toggle',-90,0,32,2,5,0,0
MEMBER:'instr-arrow',-90,0,16,4,7,0,0
MEMBER:'instr-toggle',180,0,32,4,5,0,0
MEMBER:'instr-toggle',180,0,32,4,6,0,0
MEMBER:'instr-arrow',180,0,16,4,4,0,0
MEMBER:'instr-arrow',180,0,16,2,4,0,0
MEMBER:'instr-arrow',90,0,16,1,4,0,0
MEMBER:'instr-arrow',90,0,16,1,5,0,0
MEMBER:'instr-arrow',90,0,16,1,6,0,0
MEMBER:'instr-arrow',90,0,64,5,3,0,0
MEMBER:'instr-bond',-1,0,128,5,4,0,0
MEMBER:'instr-arrow',0,0,64,5,4,0,0
MEMBER:'instr-arrow',180,0,64,6,4,0,0
MEMBER:'instr-toggle',0,0,128,6,4,0,0
MEMBER:'instr-grab',-1,0,128,7,4,0,0
MEMBER:'instr-arrow',90,0,64,7,4,0,0
MEMBER:'instr-arrow',0,0,64,7,6,0,0
MEMBER:'instr-grab',-1,1,128,7,6,0,0
MEMBER:'instr-grab',-1,2,128,8,6,0,0
MEMBER:'instr-arrow',-90,0,64,9,6,0,0
MEMBER:'instr-arrow',180,0,64,9,4,0,0
MEMBER:'instr-toggle',180,0,128,7,5,0,0
MEMBER:'instr-arrow',90,0,64,1,5,0,0
MEMBER:'instr-bond',-1,0,128,1,7,0,0
MEMBER:'instr-arrow',180,0,64,1,7,0,0
MEMBER:'instr-bond',-1,1,128,0,7,0,0
MEMBER:'instr-arrow',-90,0,64,0,7,0,0
MEMBER:'instr-rotate',-1,1,128,0,6,0,0
MEMBER:'instr-arrow',0,0,64,0,6,0,0
MEMBER:'instr-grab',-1,2,128,5,6,0,0
MEMBER:'instr-arrow',180,0,64,5,6,0,0
MEMBER:'instr-toggle',-90,0,128,4,6,0,0
MEMBER:'instr-toggle',0,0,128,5,3,0,0
MEMBER:'instr-toggle',-90,0,128,6,3,0,0
MEMBER:'instr-arrow',0,0,64,4,3,0,0
MEMBER:'instr-output',-1,1,128,6,5,0,0
MEMBER:'instr-bond',-1,1,128,4,3,0,0
MEMBER:'instr-rotate',-1,1,128,8,2,0,0
MEMBER:'instr-arrow',90,0,64,9,0,0,0
MEMBER:'instr-arrow',180,0,64,9,3,0,0
MEMBER:'instr-arrow',90,0,64,8,2,0,0
MEMBER:'instr-arrow',180,0,64,8,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-arrow',180,0,64,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,1,4,0,0
MEMBER:'instr-toggle',90,0,32,3,5,0,0
MEMBER:'instr-arrow',180,0,16,3,6,0,0
MEMBER:'instr-sync',-1,0,128,7,1,0,0
MEMBER:'instr-sync',-1,0,128,8,1,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,11,0
PIPE:0,11,-1
PIPE:0,11,-2
PIPE:0,11,-3
PIPE:0,11,-4
PIPE:0,12,-4
PIPE:0,13,-4
PIPE:0,14,-4
PIPE:0,15,-4
PIPE:0,16,-4
PIPE:1,5,2
PIPE:1,6,2
PIPE:1,7,2
PIPE:1,8,2
PIPE:1,9,2
PIPE:1,10,2
PIPE:1,11,2
ANNOTATION:0,1,0,0,'\n\r\n\r\n\r'
ANNOTATION:1,1,336,196,'3,2:0,14;1,2:0,14;1,0:0,14;3,0:0,14;3,1:0,8;2,0:0,8;1,3:0,8;0,2:0,8;0,0:0,8;1,1:0,8;3,3:0,8;2,2:0,8;\n2,0,1:1;1,1,0:1;3,1,0:1;1,2,1:1;0,0,1:1;0,2,1:1;1,0,1:1;1,0,0:1;2,2,1:1;3,2,0:1;1,2,0:1;3,0,0:1;\r2,1:0,6;2,0:0,8;2,2:0,8;\n2,0,0:2;2,1,0:2;\r\n\r'
COMPONENT:'drag-arbitrary-input',1,5,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,4,2
PIPE:0,4,3
COMPONENT:'drag-arbitrary-input',3,13,''
PIPE:0,2,1
PIPE:0,2,0
PIPE:0,2,-1
PIPE:0,2,-2
PIPE:0,2,-3
PIPE:0,2,-4
COMPONENT:'drag-superbonder-reactor',18,8,''
MEMBER:'instr-start',180,0,32,6,4,0,0
MEMBER:'instr-start',-90,0,128,9,4,0,0
MEMBER:'feature-bonder',-1,0,1,2,3,0,0
MEMBER:'feature-bonder',-1,0,1,2,4,0,0
MEMBER:'feature-bonder',-1,0,1,1,5,0,0
MEMBER:'feature-bonder',-1,0,1,1,6,0,0
MEMBER:'feature-bonder',-1,0,1,3,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,2,0,0
MEMBER:'feature-bonder',-1,0,1,7,3,0,0
MEMBER:'feature-bonder',-1,0,1,8,3,0,0
MEMBER:'instr-grab',-1,1,32,2,0,0,0
MEMBER:'instr-rotate',-1,0,32,3,0,0,0
MEMBER:'instr-arrow',0,0,16,2,0,0,0
MEMBER:'instr-grab',-1,2,32,8,0,0,0
MEMBER:'instr-arrow',90,0,16,8,0,0,0
MEMBER:'instr-output',-1,0,32,8,1,0,0
MEMBER:'instr-grab',-1,1,32,3,3,0,0
MEMBER:'instr-grab',-1,2,32,9,4,0,0
MEMBER:'instr-sync',-1,0,32,7,4,0,0
MEMBER:'instr-arrow',90,0,16,9,3,0,0
MEMBER:'instr-arrow',180,0,16,9,5,0,0
MEMBER:'instr-bond',-1,1,32,0,6,0,0
MEMBER:'instr-arrow',-90,0,16,0,7,0,0
MEMBER:'instr-grab',-1,1,32,0,5,0,0
MEMBER:'instr-arrow',0,0,16,0,5,0,0
MEMBER:'instr-bond',-1,1,32,1,5,0,0
MEMBER:'instr-arrow',180,0,16,8,7,0,0
MEMBER:'instr-arrow',-90,0,16,2,5,0,0
MEMBER:'instr-rotate',-1,0,32,2,3,0,0
MEMBER:'instr-arrow',0,0,16,3,3,0,0
MEMBER:'instr-input',-1,0,128,3,0,0,0
MEMBER:'instr-input',-1,1,128,0,4,0,0
MEMBER:'instr-sync',-1,0,128,2,1,0,0
MEMBER:'instr-arrow',0,0,64,0,0,0,0
MEMBER:'instr-bond',-1,0,32,2,4,0,0
MEMBER:'instr-sync',-1,0,128,0,5,0,0
MEMBER:'instr-sync',-1,0,128,3,1,0,0
MEMBER:'instr-sync',-1,0,128,0,6,0,0
MEMBER:'instr-grab',-1,1,128,7,4,0,0
MEMBER:'instr-arrow',90,0,64,7,4,0,0
MEMBER:'instr-bond',-1,1,128,5,4,0,0
MEMBER:'instr-arrow',180,0,64,7,7,0,0
MEMBER:'instr-grab',-1,1,128,1,6,0,0
MEMBER:'instr-arrow',-90,0,64,1,6,0,0
MEMBER:'instr-rotate',-1,0,128,1,4,0,0
MEMBER:'instr-grab',-1,2,128,3,4,0,0
MEMBER:'instr-arrow',0,0,64,0,6,0,0
MEMBER:'instr-arrow',0,0,64,1,4,0,0
MEMBER:'instr-bond',-1,0,128,2,5,0,0
MEMBER:'instr-sync',-1,0,128,7,6,0,0
MEMBER:'instr-arrow',180,0,64,9,0,0,0
MEMBER:'instr-arrow',0,0,64,0,7,0,0
MEMBER:'instr-bond',-1,0,128,2,4,0,0
MEMBER:'instr-arrow',0,0,64,2,4,0,0
MEMBER:'instr-input',-1,1,128,8,7,0,0
MEMBER:'instr-arrow',-90,0,64,9,5,0,0
MEMBER:'instr-toggle',180,0,128,9,1,0,0
MEMBER:'instr-toggle',180,0,128,9,3,0,0
MEMBER:'instr-rotate',-1,0,128,4,7,0,0
MEMBER:'instr-grab',-1,2,128,0,7,0,0
MEMBER:'instr-grab',-1,1,128,1,7,0,0
MEMBER:'instr-toggle',-90,0,128,2,7,0,0
MEMBER:'instr-grab',-1,0,128,8,3,0,0
MEMBER:'instr-grab',-1,2,128,6,3,0,0
MEMBER:'instr-grab',-1,1,128,3,5,0,0
MEMBER:'instr-grab',-1,2,128,4,5,0,0
MEMBER:'instr-arrow',-90,0,64,8,7,0,0
MEMBER:'instr-arrow',180,0,64,8,5,0,0
MEMBER:'instr-toggle',0,0,128,8,5,0,0
MEMBER:'instr-sync',-1,0,32,5,4,0,0
MEMBER:'instr-arrow',0,0,16,1,4,0,0
MEMBER:'instr-bond',-1,0,32,1,4,0,0
MEMBER:'instr-arrow',0,0,16,3,6,0,0
MEMBER:'instr-arrow',180,0,16,9,6,0,0
MEMBER:'instr-grab',-1,2,32,8,6,0,0
MEMBER:'instr-output',-1,1,32,9,6,0,0
MEMBER:'instr-arrow',180,0,16,6,3,0,0
MEMBER:'instr-toggle',-90,0,32,6,6,0,0
MEMBER:'instr-toggle',180,0,32,8,4,0,0
MEMBER:'instr-toggle',0,0,32,6,3,0,0
MEMBER:'instr-toggle',0,0,128,1,5,0,0
MEMBER:'instr-sync',-1,0,128,7,5,0,0
MEMBER:'instr-sync',-1,0,128,9,5,0,0
MEMBER:'instr-grab',-1,1,32,4,4,0,0
MEMBER:'instr-toggle',90,0,32,3,4,0,0
MEMBER:'instr-rotate',-1,0,32,3,5,0,0
MEMBER:'instr-grab',-1,1,128,6,1,0,0
MEMBER:'instr-arrow',90,0,64,3,0,0,0
MEMBER:'instr-arrow',-90,0,64,2,1,0,0
MEMBER:'instr-arrow',180,0,64,3,1,0,0
MEMBER:'instr-toggle',180,0,128,2,0,0,0
MEMBER:'instr-arrow',0,0,64,2,0,0,0
MEMBER:'instr-toggle',90,0,128,0,0,0,0
MEMBER:'instr-toggle',90,0,128,4,0,0,0
MEMBER:'instr-arrow',180,0,64,4,0,0,0
MEMBER:'instr-toggle',90,0,128,4,2,0,0
MEMBER:'instr-arrow',-90,0,64,4,1,0,0
MEMBER:'instr-toggle',90,0,128,4,1,0,0
MEMBER:'instr-grab',-1,1,128,4,4,0,0
MEMBER:'instr-arrow',-90,0,64,4,2,0,0
MEMBER:'instr-toggle',0,0,128,4,3,0,0
MEMBER:'instr-input',-1,0,128,9,0,0,0
MEMBER:'instr-sync',-1,0,128,8,0,0,0
MEMBER:'instr-sync',-1,0,128,7,0,0,0
MEMBER:'instr-arrow',0,0,64,6,1,0,0
MEMBER:'instr-toggle',90,0,128,8,1,0,0
MEMBER:'instr-arrow',180,0,64,8,3,0,0
MEMBER:'instr-toggle',180,0,128,1,0,0,0
MEMBER:'instr-arrow',0,0,64,1,0,0,0
MEMBER:'instr-toggle',0,0,128,1,2,0,0
MEMBER:'instr-input',-1,1,128,5,6,0,0
MEMBER:'instr-arrow',90,0,64,6,3,0,0
MEMBER:'instr-sync',-1,0,128,4,6,0,0
MEMBER:'instr-sync',-1,0,128,3,6,0,0
MEMBER:'instr-arrow',180,0,64,6,6,0,0
MEMBER:'instr-toggle',0,0,128,1,3,0,0
MEMBER:'instr-toggle',0,0,128,2,2,0,0
MEMBER:'instr-toggle',0,0,128,2,3,0,0
MEMBER:'instr-arrow',180,0,64,2,2,0,0
MEMBER:'instr-toggle',0,0,128,7,7,0,0
MEMBER:'instr-sync',-1,0,128,8,6,0,0
MEMBER:'instr-toggle',90,0,128,0,1,0,0
MEMBER:'instr-arrow',-90,0,64,0,1,0,0
MEMBER:'instr-arrow',-90,0,64,4,3,0,0
MEMBER:'instr-arrow',90,0,64,1,2,0,0
MEMBER:'instr-arrow',90,0,64,0,3,0,0
MEMBER:'instr-arrow',180,0,64,2,3,0,0
MEMBER:'instr-arrow',-90,0,64,3,3,0,0
MEMBER:'instr-arrow',-90,0,64,3,2,0,0
MEMBER:'instr-toggle',0,0,128,0,2,0,0
MEMBER:'instr-arrow',180,0,64,1,3,0,0
MEMBER:'instr-toggle',-90,0,128,5,3,0,0
MEMBER:'instr-input',-1,0,128,5,2,0,0
MEMBER:'instr-arrow',0,0,64,5,2,0,0
MEMBER:'instr-sync',-1,0,128,6,2,0,0
MEMBER:'instr-sync',-1,0,128,7,2,0,0
MEMBER:'instr-arrow',90,0,64,7,2,0,0
MEMBER:'instr-arrow',180,0,64,7,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,4,0
PIPE:1,4,3
PIPE:1,4,4
PIPE:1,4,5
COMPONENT:'drag-arbitrary-input',3,18,''
PIPE:0,2,1
PIPE:0,3,1
PIPE:0,4,1
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,14,1
PIPE:0,14,0
PIPE:0,14,-1
PIPE:0,14,-2
PIPE:0,14,-3
PIPE:0,14,-4
PIPE:0,14,-5
PIPE:0,14,-6
PIPE:0,14,-7
PIPE:0,14,-8""",
    r'''SOLUTION:Challenge: Going Green,Zig,3578-1-103,assumes 2nd input
COMPONENT:'drag-powerplant-input',-7,4,''
PIPE:0,14,7
PIPE:0,14,6
PIPE:0,14,5
PIPE:0,14,4
COMPONENT:'drag-advanced-reactor',8,7,''
MEMBER:'instr-start',-90,0,128,2,5,0,0
MEMBER:'instr-start',0,0,32,1,0,0,0
MEMBER:'feature-bonder',-1,0,1,6,3,0,0
MEMBER:'feature-bonder',-1,0,1,6,4,0,0
MEMBER:'feature-bonder',-1,0,1,7,4,0,0
MEMBER:'feature-bonder',-1,0,1,6,2,0,0
MEMBER:'feature-sensor',-1,0,1,2,1,0,0
MEMBER:'instr-input',-1,0,128,2,4,0,0
MEMBER:'instr-arrow',-90,0,64,2,4,0,0
MEMBER:'instr-sensor',180,0,128,2,3,0,6
MEMBER:'instr-arrow',90,0,64,1,3,0,0
MEMBER:'instr-arrow',0,0,64,1,7,0,0
MEMBER:'instr-arrow',-90,0,64,2,7,0,0
MEMBER:'instr-grab',-1,0,128,1,3,0,0
MEMBER:'instr-grab',-1,0,128,1,4,0,0
MEMBER:'instr-grab',-1,0,128,1,5,0,0
MEMBER:'instr-grab',-1,0,128,1,6,0,0
MEMBER:'instr-grab',-1,0,128,1,7,0,0
MEMBER:'instr-grab',-1,2,128,4,7,0,0
MEMBER:'instr-sensor',0,0,128,2,7,0,6
MEMBER:'instr-arrow',-90,0,64,4,7,0,0
MEMBER:'instr-arrow',180,0,64,4,1,0,0
MEMBER:'instr-arrow',90,0,64,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,1,0,0
MEMBER:'instr-grab',-1,1,128,1,2,0,0
MEMBER:'instr-grab',-1,1,128,2,2,0,0
MEMBER:'instr-arrow',0,0,64,2,2,0,0
MEMBER:'instr-arrow',90,0,64,3,2,0,0
MEMBER:'instr-sensor',0,0,128,3,2,0,1
MEMBER:'instr-arrow',180,0,64,3,4,0,0
MEMBER:'instr-bond',-1,0,128,3,3,0,0
MEMBER:'instr-bond',-1,0,128,4,2,0,0
MEMBER:'instr-sync',-1,0,128,5,2,0,0
MEMBER:'instr-rotate',-1,1,128,6,2,0,0
MEMBER:'instr-arrow',90,0,64,6,2,0,0
MEMBER:'instr-arrow',0,0,64,6,3,0,0
MEMBER:'instr-arrow',90,0,64,7,3,0,0
MEMBER:'instr-arrow',0,0,64,7,4,0,0
MEMBER:'instr-sensor',90,0,128,9,4,0,8
MEMBER:'instr-arrow',180,0,64,9,7,0,0
MEMBER:'instr-arrow',-90,0,64,5,7,0,0
MEMBER:'instr-arrow',0,0,64,5,4,0,0
MEMBER:'instr-arrow',90,0,64,6,4,0,0
MEMBER:'instr-arrow',0,0,64,6,5,0,0
MEMBER:'instr-arrow',90,0,64,7,5,0,0
MEMBER:'instr-arrow',0,0,64,7,6,0,0
MEMBER:'instr-arrow',-90,0,64,8,6,0,0
MEMBER:'instr-arrow',180,0,64,8,0,0,0
MEMBER:'instr-arrow',90,0,64,0,0,0,0
MEMBER:'instr-arrow',0,0,64,0,2,0,0
MEMBER:'instr-bond',-1,1,128,0,0,0,0
MEMBER:'instr-bond',-1,1,128,0,1,0,0
MEMBER:'instr-sensor',180,0,128,3,0,0,8
MEMBER:'instr-arrow',-90,0,64,3,0,0,0
MEMBER:'instr-bond',-1,1,128,9,7,0,0
MEMBER:'instr-bond',-1,1,128,8,7,0,0
MEMBER:'instr-bond',-1,1,128,6,3,0,0
MEMBER:'instr-bond',-1,0,128,7,4,0,0
MEMBER:'instr-grab',-1,2,128,8,4,0,0
MEMBER:'instr-rotate',-1,1,128,8,5,0,0
MEMBER:'instr-rotate',-1,1,128,7,5,0,0
MEMBER:'instr-grab',-1,1,128,6,5,0,0
MEMBER:'instr-sync',-1,0,128,7,6,0,0
MEMBER:'instr-bond',-1,0,128,5,5,0,0
MEMBER:'instr-input',-1,0,32,3,0,0,0
MEMBER:'instr-sync',-1,0,32,2,0,0,0
MEMBER:'instr-arrow',90,0,16,3,0,0,0
MEMBER:'instr-arrow',0,0,16,3,1,0,0
MEMBER:'instr-grab',-1,0,32,3,1,0,0
MEMBER:'instr-sensor',0,0,32,4,1,0,8
MEMBER:'instr-arrow',90,0,16,4,1,0,0
MEMBER:'instr-rotate',-1,1,32,5,1,0,0
MEMBER:'instr-arrow',90,0,16,6,1,0,0
MEMBER:'instr-arrow',180,0,16,6,2,0,0
MEMBER:'instr-arrow',90,0,16,5,2,0,0
MEMBER:'instr-arrow',0,0,16,5,3,0,0
MEMBER:'instr-arrow',90,0,16,6,3,0,0
MEMBER:'instr-arrow',180,0,16,6,4,0,0
MEMBER:'instr-arrow',90,0,16,5,4,0,0
MEMBER:'instr-arrow',0,0,16,5,5,0,0
MEMBER:'instr-arrow',90,0,16,6,5,0,0
MEMBER:'instr-arrow',180,0,16,6,7,0,0
MEMBER:'instr-arrow',180,0,16,4,6,0,0
MEMBER:'instr-arrow',180,0,16,4,2,0,0
MEMBER:'instr-sensor',90,0,32,4,2,0,6
MEMBER:'instr-arrow',-90,0,16,2,2,0,0
MEMBER:'instr-arrow',180,0,16,2,1,0,0
MEMBER:'instr-arrow',90,0,16,0,1,0,0
MEMBER:'instr-arrow',0,0,16,0,2,0,0
MEMBER:'instr-sensor',0,0,32,2,1,0,6
MEMBER:'instr-grab',-1,1,32,1,1,0,0
MEMBER:'instr-grab',-1,2,32,0,1,0,0
MEMBER:'instr-input',-1,0,32,2,2,0,0
MEMBER:'instr-bond',-1,0,32,6,1,0,0
MEMBER:'instr-bond',-1,1,32,6,2,0,0
MEMBER:'instr-output',-1,0,32,5,2,0,0
MEMBER:'instr-bond',-1,0,32,5,3,0,0
MEMBER:'instr-grab',-1,2,32,6,3,0,0
MEMBER:'instr-grab',-1,1,32,6,4,0,0
MEMBER:'instr-bond',-1,0,32,5,4,0,0
MEMBER:'instr-grab',-1,2,32,6,5,0,0
MEMBER:'instr-output',-1,1,32,6,6,0,0
MEMBER:'instr-arrow',-90,0,16,3,7,0,0
MEMBER:'instr-arrow',-90,0,16,3,6,0,0
MEMBER:'instr-sync',-1,0,32,4,7,0,0
MEMBER:'instr-grab',-1,1,32,3,7,0,0
MEMBER:'instr-grab',-1,0,32,3,6,0,0
MEMBER:'instr-grab',-1,0,32,3,5,0,0
MEMBER:'instr-grab',-1,0,32,3,4,0,0
MEMBER:'instr-grab',-1,0,32,3,3,0,0
PIPE:0,4,1
PIPE:1,4,2
PIPE:0,5,1
PIPE:0,6,1
PIPE:0,7,1
PIPE:0,8,1
PIPE:0,9,1
PIPE:0,10,1
PIPE:0,11,1
PIPE:0,12,1
PIPE:0,13,1
PIPE:0,14,1
PIPE:0,14,2
PIPE:0,14,3
PIPE:0,14,4
PIPE:0,14,5
PIPE:0,14,6
PIPE:0,14,7
PIPE:0,14,8
PIPE:0,14,9
PIPE:0,14,10
PIPE:0,14,11
PIPE:0,14,12
PIPE:1,4,1
PIPE:1,4,0
PIPE:1,4,-1
PIPE:1,4,-2
PIPE:1,4,-3
PIPE:1,4,-4
PIPE:1,5,-4
PIPE:1,6,-4
PIPE:1,7,-4
PIPE:1,8,-4
PIPE:1,9,-4
PIPE:1,10,-4
PIPE:1,11,-4
PIPE:1,12,-4
PIPE:1,13,-4
PIPE:1,14,-4
''',
]


death_solutions = [
r'''SOLUTION:Exploding Head Syndrome,darkid,6979-0-0,Death
COMPONENT:'drag-oceanic-input',5,18,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
''',

r'''SOLUTION:A Most Unfortunate Malfunction,darkid,3720-0-0,Death
COMPONENT:'drag-oceanic-input',1,16,''
PIPE:0,2,0
PIPE:0,3,0
PIPE:0,4,0
PIPE:0,5,0
PIPE:0,6,0
PIPE:0,7,0
PIPE:0,8,0
PIPE:0,9,0
PIPE:0,10,0
PIPE:0,11,0
PIPE:0,12,0
PIPE:0,13,0
PIPE:0,14,0
PIPE:0,15,0
PIPE:0,16,0
PIPE:0,17,0
PIPE:0,18,0
PIPE:0,19,0
PIPE:0,20,0
PIPE:0,21,0
PIPE:0,22,0
PIPE:0,22,-1
PIPE:0,22,-2
PIPE:0,22,-3
''',

'''SOLUTION:No Need for Introductions,darkid,5105-0-0,Death''',

]
